proc my_create_aduser {dn upn sam pw} {
	#a select_object is performed before delete_sub_tree, since it will prompt the user if in interactive mode
	if { [catch {select_object $dn}]==0 } {delete_sub_tree $dn}
	create_aduser $dn $upn $sam $pw
}
proc my_create_adgroup {dn sam gtype} {
	catch {select_object $dn; dlo}
	create_adgroup $dn $sam $gtype
}

proc my_create_ad_computer {dn sam} {
	catch {select_object $dn; dlo}
    new_object $dn
    sof samaccountname $sam
    sof useraccountcontrol [expr 0x1000]
    sof objectclass computer 
    svo
}

package require ade_lib
set domain [lindex $argv 0]
set user [lindex $argv 1]
set password [lindex $argv 2]
set dcdom [dn_from_domain $domain]
set hostname [exec hostname]
#make sure we have a long machine name

if {[string last "." $hostname] == -1} {
	append hostname "." $domain
}

# Display usage if not all required parameters are provided
if {$argc > 3} {
   set cnt "many"
}

if {$argc < 3} {
   set cnt "few"
}

if {$argc != 3} {
   puts "Error: Fail to setup Centrify DirectControl evaluation."
   puts "       Too $cnt ($argc) parameters were entered."
   puts "Usage: eval_setup.tcl <domain> <user name> <password>"
   puts "Notes: The order of parameters is strictly required."
   puts "       User must have create/modify-writes/delete privileges on the "
   puts "       \"program data\", \"users\", and \"computers\" containers."
   exit 1
}

puts "Starting to bind computer $hostname to domain $dcdom by $user"
bind $domain $user $password

puts "Beginning to create zones, users, groups and roles"

# delete zones if they exist
catch {select_zone "cn=global,cn=zones,cn=centrify,cn=program data,$dcdom"; dlz}
catch {select_zone "cn=cz1,cn=zones,cn=centrify,cn=program data,$dcdom"; dlz}
catch {select_zone "cn=cz2,cn=zones,cn=centrify,cn=program data,$dcdom"; dlz}

#create tree zones. Parent and 2 children
create_zone tree "cn=global,cn=zones,cn=centrify,cn=program data,$dcdom" rfc
create_zone tree "cn=cz1,cn=zones,cn=centrify,cn=program data,$dcdom" std
create_zone tree "cn=cz2,cn=zones,cn=centrify,cn=program data,$dcdom" std

#and we want machine overrides
create_zone computer "$hostname@cn=cz1,cn=zones,cn=centrify,cn=program data,$dcdom" std

#link the children to parent
select_zone "cn=cz1,cn=zones,cn=centrify,cn=program data,$dcdom"
set_zone_field parent "cn=global,cn=zones,cn=centrify,cn=program data,$dcdom"
save_zone
select_zone  "cn=cz2,cn=zones,cn=centrify,cn=program data,$dcdom"
set_zone_field parent "cn=global,cn=zones,cn=centrify,cn=program data,$dcdom"
save_zone

# create all AD users
my_create_aduser "cn=adam avery,cn=users,$dcdom" "adam.avery@$domain" adam.avery testTEST1234
my_create_aduser "cn=brenda butler,cn=users,$dcdom" "brenda.butler@$domain" brenda.butler testTEST1234
my_create_aduser "cn=chris.carter,cn=users,$dcdom" "chris.carter@$domain" chris.carter testTEST1234
my_create_aduser "cn=denise davies,cn=users,$dcdom" "denise.davies@$domain" denise.davies testTEST1234
my_create_aduser "cn=eric epstein,cn=users,$dcdom" "eric.epstein@$domain" eric.epstein testTEST1234
my_create_aduser "cn=frances fitch,cn=users,$dcdom" "frances.fitch@$domain" frances.fitch testTEST1234
my_create_aduser "cn=george griffin,cn=users,$dcdom" "george.griffin@$domain" george.griffin testTEST1234
my_create_aduser "cn=holly hunt,cn=users,$dcdom" "holly.hunt@$domain" holly.hunt testTEST1234
my_create_aduser "cn=ian isley,cn=users,$dcdom" "ian.isley@$domain" ian.isley testTEST1234
my_create_aduser "cn=janet jones,cn=users,$dcdom" "janet.jones@$domain" janet.jones testTEST1234
my_create_aduser "cn=keith kraft,cn=users,$dcdom" "keith.kraft@$domain" keith.kraft testTEST1234
my_create_aduser "cn=liz lemon,cn=users,$dcdom" "liz.lemon@$domain" liz.lemon testTEST1234
my_create_aduser "cn=martin moore,cn=users,$dcdom" "martin.moore@$domain" martin.moore testTEST1234
my_create_aduser "cn=nina norris,cn=users,$dcdom" "nina.norris@$domain" nina.norris testTEST1234
my_create_aduser "cn=oscar oberto,cn=users,$dcdom" "oscar.oberto@$domain" oscar.oberto testTEST1234
my_create_aduser "cn=petula piper,cn=users,$dcdom" "petula.piper@$domain" petula.piper testTEST1234
my_create_aduser "cn=quincy quine,cn=users,$dcdom" "quincy.quine@$domain" quincy.quine testTEST1234
my_create_aduser "cn=rachel roberts,cn=users,$dcdom" "rachel.roberts@$domain" rachel.roberts testTEST1234
my_create_aduser "cn=simon schuster,cn=users,$dcdom" "simon.schuster@$domain" simon.schuster testTEST1234
my_create_aduser "cn=tina troy,cn=users,$dcdom" "tina.troy@$domain" tina.troy testTEST1234

# global is our global zone. Load all users into it
select_zone "cn=global,cn=zones,cn=centrify,cn=program data,$dcdom"
set j 10000 

create_user "adam.avery@$domain" adam [incr j] $j  %{u:samaccountname} %{home}/%{user} %{shell} -
create_user "brenda.butler@$domain" brenda [incr j] $j  %{u:samaccountname} %{home}/%{user} %{shell} -
create_user "chris.carter@$domain" chris [incr j] $j  %{u:samaccountname} %{home}/%{user} %{shell} -
create_user "denise.davies@$domain" denise [incr j] $j  %{u:samaccountname} %{home}/%{user} %{shell} -
create_user "eric.epstein@$domain" eric [incr j] $j  %{u:samaccountname} %{home}/%{user} %{shell} -
create_user "frances.fitch@$domain" frances [incr j] $j  %{u:samaccountname} %{home}/%{user} %{shell} -
create_user "george.griffin@$domain" george [incr j] $j  %{u:samaccountname} %{home}/%{user} %{shell} -
create_user "holly.hunt@$domain" holly [incr j] $j  %{u:samaccountname} %{home}/%{user} %{shell} -
create_user "ian.isley@$domain" ian [incr j] $j  %{u:samaccountname} %{home}/%{user} %{shell} -
create_user "janet.jones@$domain" janet [incr j] $j  %{u:samaccountname} %{home}/%{user} %{shell} -
create_user "keith.kraft@$domain" keith [incr j] $j  %{u:samaccountname} %{home}/%{user} %{shell} -
create_user "liz.lemon@$domain" liz [incr j] $j  %{u:samaccountname} %{home}/%{user} %{shell} -
create_user "martin.moore@$domain" martin [incr j] $j  %{u:samaccountname} %{home}/%{user} %{shell} -
create_user "nina.norris@$domain" nina [incr j] $j  %{u:samaccountname} %{home}/%{user} %{shell} -
create_user "oscar.oberto@$domain" oscar [incr j] $j  %{u:samaccountname} %{home}/%{user} %{shell} -
create_user "petula.piper@$domain" petula [incr j] $j  %{u:samaccountname} %{home}/%{user} %{shell} -
create_user "quincy.quine@$domain" quincy [incr j] $j  %{u:samaccountname} %{home}/%{user} %{shell} -
create_user "rachel.roberts@$domain" rachel [incr j] $j  %{u:samaccountname} %{home}/%{user} %{shell} -
create_user "simon.schuster@$domain" simon [incr j] $j  %{u:samaccountname} %{home}/%{user} %{shell} -
create_user "tina.troy@$domain" tina [incr j] $j  %{u:samaccountname} %{home}/%{user} %{shell} -

# a group for all our users
my_create_adgroup "cn=projectx_users,cn=users,$dcdom" projectx_users global
add_user_to_group "adam.avery@$domain" projectx_users@$domain
add_user_to_group "brenda.butler@$domain" projectx_users@$domain
add_user_to_group "chris.carter@$domain" projectx_users@$domain
add_user_to_group "denise.davies@$domain" projectx_users@$domain
add_user_to_group "eric.epstein@$domain" projectx_users@$domain
add_user_to_group "frances.fitch@$domain" projectx_users@$domain
add_user_to_group "george.griffin@$domain" projectx_users@$domain
add_user_to_group "holly.hunt@$domain" projectx_users@$domain
add_user_to_group "ian.isley@$domain" projectx_users@$domain
add_user_to_group "janet.jones@$domain" projectx_users@$domain
add_user_to_group "keith.kraft@$domain" projectx_users@$domain
add_user_to_group "liz.lemon@$domain" projectx_users@$domain
add_user_to_group "martin.moore@$domain" projectx_users@$domain
add_user_to_group "nina.norris@$domain" projectx_users@$domain
add_user_to_group "oscar.oberto@$domain" projectx_users@$domain
add_user_to_group "petula.piper@$domain" projectx_users@$domain
add_user_to_group "quincy.quine@$domain" projectx_users@$domain
add_user_to_group "rachel.roberts@$domain" projectx_users@$domain
add_user_to_group "simon.schuster@$domain" projectx_users@$domain
add_user_to_group "tina.troy@$domain" projectx_users@$domain

#everybody is visible
#create_assignment projects_users@$domain listed

# oracle servers access zone
my_create_adgroup "cn=oracle_machines,cn=users,$dcdom" oracle_machines global
create_computer_role "cn=global,cn=zones,cn=centrify,cn=program data,$dcdom/oracle_servers" oracle_machines@$domain


# add this machine to oracle servers access zone
regexp {^(.+?)(\.|$)} $hostname m shorthost
my_create_ad_computer "cn=$shorthost,cn=computers,$dcdom" "$shorthost\$" 
add_user_to_group "$shorthost\$@$domain" oracle_machines@$domain

# oracle administrators
my_create_adgroup "cn=ora_admins,cn=users,$dcdom" ora_admins global
add_user_to_group tina.troy@$domain ora_admins@$domain
add_user_to_group oscar.oberto@$domain ora_admins@$domain

# create zag for oracle in oracle_servers access zone
push
slz "cn=global,cn=zones,cn=centrify,cn=program data,$dcdom/oracle_servers"
create_assignment ora_admins@$domain login/global
pop

#project 1 team
my_create_adgroup "cn=project1,cn=users,$dcdom" project1 global
add_user_to_group ian.isley@$domain project1@$domain
add_user_to_group holly.hunt@$domain project1@$domain
add_user_to_group frances.fitch@$domain project1@$domain
add_user_to_group chris.carter@$domain project1@$domain
add_user_to_group adam.avery@$domain project1@$domain

#project 2 team
my_create_adgroup "cn=project2,cn=users,$dcdom" project2 global
add_user_to_group petula.piper@$domain project2@$domain
add_user_to_group george.griffin@$domain project2@$domain
add_user_to_group brenda.butler@$domain project2@$domain
add_user_to_group holly.hunt@$domain project2@$domain
add_user_to_group denise.davies@$domain project2@$domain
add_user_to_group janet.jones@$domain project2@$domain
add_user_to_group keith.kraft@$domain project2@$domain


#project admins - can use any project machine
my_create_adgroup "cn=proj_admins,cn=users,$dcdom" proj_admins global
add_user_to_group simon.schuster@$domain proj_admins@$domain
add_user_to_group adam.avery@$domain proj_admins@$domain
add_user_to_group george.griffin@$domain proj_admins@$domain


# poweradmins are root everywhere
my_create_adgroup "cn=poweradmins,cn=users,$dcdom" poweradmins global
add_user_to_group martin.moore@$domain poweradmins@$domain
add_user_to_group rachel.roberts@$domain poweradmins@$domain

# create root role
select_zone "cn=global,cn=zones,cn=centrify,cn=program data,$dcdom"
new_dz_command root_any
set_dzc_field cmd "*"
set_dzc_field description "Run any command as root"
set_dzc_field dzdo_runas root
save_dz_command

new_role root
add_command_to_role root_any
add_pamapp_to_role login-all
set_role_field sysrights [expr 0x0000000b] #login | shell
save_role

new_role service
add_pamapp_to_role login-all
set_role_field sysrights [expr 0x0000000e] #allow_disabled | sso | shell
save_role

new_role nopass
add_pamapp_to_role login-all
set_role_field sysrights [expr 0x0000000a] # sso | shell
save_role

create_assignment poweradmins@$domain root

# managers are allowed to login to any system
create_assignment proj_admins@$domain login

# project 1 uses cz1
select_zone "cn=cz1,cn=zones,cn=centrify,cn=program data,$dcdom"
create_assignment project1@$domain login

# on this machine holly has uid 333
select_zone "$hostname@cn=cz1,cn=zones,cn=centrify,cn=program data,$dcdom"
create_user holly.hunt@$domain - 333 - - - - -

puts "Centrify DirectControl evalation setup is complete"
exit 0
