#!/bin/sh /usr/share/centrifydc/perl/run

##############################################################################
#
# Copyright (C) 2010 Centrify Corporation.
#
# Machine mapper script to configure DirectAudit.
#
#  Map:     Copy DirectAudit settings to /var/centrifyda
#
#  Unmap:   Remove DirectAudit settings.
#
# Parameters: <map|unmap> [username] mode
#   map|unmap   action to take
#   username    username (not used)
#   mode        mode (not used)
#
# Exit value:
#   0   Normal
#   1   Error
#   2   usage
#
##############################################################################

# Note: this mapper script is necessary because it is not safe for
# DirectAudit to read the policy file directly -- during policy updates
# the CDC GP processing leaves a window open where the policy file
# may be missing or incomplete.  See bug 22852.  So, we just copy
# out the policy to a safe location.

use strict;

use lib '/usr/share/centrifydc/perl';
use File::Copy;
use CentrifyDC::GP::General qw(:debug);
use CentrifyDC::GP::Args;

my $args = CentrifyDC::GP::Args->new();

if ($args->isMap() && stat("/var/centrifydc/reg/machine/software/policies/centrify/directaudit/common/Registry.pol"))
{
    
    DEBUG_OUT("Copying Registry.pol to /var/centrifyda");

    # Copy the policy file.
    copy(
    "/var/centrifydc/reg/machine/software/policies/centrify/directaudit/common/Registry.pol",
    "/var/centrifyda/Registry.pol.new");

    # Atomically rename the new policy into place.
    rename(
    "/var/centrifyda/Registry.pol.new",
    "/var/centrifyda/Registry.pol");
}
else
{
    DEBUG_OUT("Removing /var/centrifyda/Registry.pol");

    # Remove the policy file.
    unlink(
    "/var/centrifyda/Registry.pol");
}    
