#! /bin/sh
#
# install-express.sh - Centrify Express install script.
#
# Copyright (c) Centrify 2004-2011, All Rights Reserved.
#
usage () {
    cat <<-END_USAGE

        This script installs (upgrades/uninstalls) Centrify Express.
        Only the superuser can run this script.

        Usage:
          install-express.sh [-n] [-e] [-h] [-V] [-v ver] [-l log_file]

        where:
          -n             Non-interactive mode.
          --express      Install Centrify Express in non-interactive mode.
          --ent-suite    Install Enterprise Suite in non-interactive mode.
          --std-suite    Install Standard Suite in non-interactive mode.
          --suite-config <config_file>  
                         Override default suite config file with <config_file>.
          -e             Uninstall (erase) CentrifyDC.
          -h, --help     Print out this usage and then exit.
          -V             Print out installer version and then exit.
          -v <ver>       Install CentrifyDC <ver> version.
                         Format: x.x.x or x.x.x-xxx. x is number.
          -l <log_file>  Override default log-file PATH with <log_file>. 
          --custom_rc    Return meaningful exit code.
          --adjoin_opt="<adjoin_options>"
                         Override default adjoin command line options with
                         <adjoin_options>.
          --enable-da    In non-interactive mode, once joined to a domain,
                         enable DA for all shells.

END_USAGE
}
### global variables
CDC_VER_YEAR="2012"
CDC_VER="5.0.0"
REV_YEAR="${CDC_VER_YEAR}-613"
REV="${CDC_VER}-613"

CDC_VER_MINIMUM_MAC="4"         # will bail on mac if CDC_VER is smaller than this
CDC_VER_INC_IDMAP="4.1"         # CDC_VER = or > than this will conflict with CDC-idmap
CDC_VER_INC_NIS="4.0"           # CDC_VER = or > than this will conflict with CDC-nis < 4.0
CDC_VER_INC_NIS_2="4.2"         # CDC_VER < than this will conflict with CDC-nis => 4.2
CDC_VER_INC_NIS_3="5.0"         # CDC_VER = or > than this will conflict with CDC-nis < $CDC_VER (only consider first version number of x.x.x)
CDC_VER_INC_KRB5="4.2"          # CDC_VER = or > than this will conflict with CDC-krb5 < 4.2

INSTALLED_VER=""
CUR_VER=""              ### core package currently installed version
SAMBA_VER=""
OPENSSH_OLD=""
SAMBA_PKGFILE=""
OPENSSH_PKGFILE=""

DEBUG="off"
DEBUG_OUT="/dev/null"   ### set by log_header() to =${LOG_FILE} if DEBUG=on (--debug)
TRUE=0			### shell uses negative logic.
FALSE=1
DELAY=15		### default reboot delay
REBOOT_CMD=/sbin/reboot ### reboot command
LINUX_OPTION=""
FORCE_OPTION=""
# some platforms have /bin/sh pointing to bash
ECHO_FLAG="-e" # bash
if [ -n "`echo -e "\n"`" ]; then ECHO_FLAG=""; fi
SEP="-"                 ### "." on AIX, CentrifyDC.core
TARGET_OS="unknown"
OS_REV="unknown"
ARCH="unknown"
OS_MODE=""
PKG_OS_REV="unknown"
PKG_ARCH="unknown"
PKG_FILE=""
PKG_FILE_LIST=""
PKG_I_LIST=""           ### install list
PKG_I2_LIST=""          ### second round install list
PKG_E_LIST=""           ### erase list
PKG_DIR=""
CONTINUE=""
ORG_UMASK=""
X_OPTION_LIST=""
INIT_DIR=/etc/init.d
PID=$$
VAR=/var
VAR_TMP=${VAR}/tmp/centrifydc${PID}
LOG_FILE_DEF=${VAR}/log/centrifydc-install.log
LOG_FILE=""
PKGADD_LOG=${VAR_TMP}/pkgadd.log
SWCOPY_LOG=${VAR_TMP}/swcopy.log
SWINSTALL_LOG=${VAR_TMP}/swinstall.log
ADMIN_FILE=${VAR_TMP}/centrifydc-admin    ### need on solaris only
# ADMIN_FILE default installation actions (See admin(4))
# quit - abort installation if checking fails.
# nocheck - do not check.
ADMIN_IDEPEND=quit      ### the package to be installed depends on others
ADMIN_RDEPEND=quit      ### other packages depend on the package to be removed
ADMIN_CONFLICT=quit     ### file conflict between packages
ADD_ON_LIST="nis openssh krb5 web apache ldapproxy samba idmap adbindproxy db2 cda" # add krb5lib on AIX, add adfixid on Mac
CFG_FNAME="centrifydc-install.cfg"
CFG_FNAME_SUITE_DEF="centrify-suite.cfg"
CFG_FNAME_SUITE=""
COMPAT_LINK_LIST=""
DARWIN_PKG_NAME="new"
# Signals need to be caught: 1=SIGHUP 2=SIGINT 3=SIGQUIT 15=SIGTERM
SIGNAL_LIST="1 2 3 15"
#CHECK_ADCLIENT="/usr/share/centrifydc/bin/centrifydc status | grep \"is running\""
CHECK_ADCLIENT="ps -ef | grep -w adclient | grep -w 1 | grep -v grep"

### regular defaults, set_silent_cfg() overrides some variables
SILENT="NO"
QUESTION=
INPUT=
SUPPORTED=N             ### core package available for install or upgrade
SUPPORTED_PL=$FALSE     ### platform is supported
INSTALLED=
INSTALL=
UNINSTALL=              ### Uninstall of all packages including add-on(s), works with INSTALL="E" only
GLOBAL_ZONE_ONLY="non_global"  ### Solaris 10 -G option, "Y" means install in global zone only
INSTALLED_GZ_ONLY=             ### how CDC is installed
SUITE="Custom"
OS_CHECK=               ### option to skip initial OS check
ADCHECK=""
ADCHECK_FNAME="adcheck"
ADCHECK_RC="0"
EXPRESS_PL=$FALSE       ### platform supports express mode
EXPRESS=
ADLICENSE="Y"
ADJOINED=
ADJOIN=
ADJOIN_CMD_OPTIONS=
DOMAIN=
USERID=administrator    ### default Active Directory user
PASSWD=
COMPUTER=`hostname`
CONTAINER=Computers
ZONE=default
SERVER=
DA_ENABLE=
REBOOT=
DIR_LIST=
FORCE_DA_GLOBAL=
REVERT_FORCE_DA_GLOBAL=
ENTERPRISE_PL=$FALSE

#keep track of whether the dsplugin has been enabled already
DSPLUGIN_HAS_BEEN_ENABLED=0


### return codes
CODE_SIN=0 # Successful install
CODE_SUP=0 # Successful upgrade
CODE_SUN=0 # Successful uninstall
CODE_NIN=24 # Did nothing during install
CODE_NUN=25 # Did nothing during uninstall
CODE_EIN=26 # Error during install
CODE_EUP=27 # Error during upgrade
CODE_EUN=28 # Error during uninstall
CODE_ESU=29 # Error during setup e.g. wrong UID, wrong platform, invalid number of arguments
CODE_SIG=30 # Signal received and therefore terminate

set_custom_rc ()
{
    CODE_SIN=21 # Successful install
    CODE_SUP=22 # Successful upgrade
    CODE_SUN=23 # Successful uninstall
}

list_compat_os_rev ()
{
    # return a list of compatible OS_REV
    case "$1" in
        deb5)
            echo "deb3.1 deb3" ;;
        rhel3)
            echo "rh9" ;;
        10.5)
            echo "10.4" ;;
    esac
}

add_utest ()
{
    ADD_ON_LIST="${ADD_ON_LIST} utest"
}

### Check that this script is being run by a superuser (root)
uid_check()
{
    id | grep uid=0 > /dev/null
    if [ "$?" != "0" ]; then
        echo ERROR: Only the superuser can run this script.
        echo Exiting ...
        exit $CODE_ESU
    fi
    return $TRUE
}

### make sure we are not in sparse root zone (solaris 10)
detect_sparse()
{
    case ${OS_REV} in
    sol1* | sol20* )
        if [ -x /usr/sbin/zoneadm ] && [ `/usr/sbin/zoneadm list -p | grep 0:global > /dev/null; echo $?` -ne 0 ]; then
            PART_LIST="/usr /lib /var /etc"
            ERR=0
            for i in ${PART_LIST}
            do
                if [ `mount | grep -v 'read/write' | grep $i > /dev/null; echo $?` -eq 0 ]; then
                    echo "ERROR: $i is a read-only resource" | tee -a ${LOG_FILE}
                    ERR=1
                fi
            done
            if [ "${ERR}" = "1" ];then
                echo "ERROR: This is a sparse root zone (it has read-only resource)." | tee -a ${LOG_FILE}
                echo "       Centrify DirectControl can be installed in a global or"  | tee -a ${LOG_FILE}
                echo "       whole root non-global zones only. Exiting ..."           | tee -a ${LOG_FILE}
                exit $CODE_ESU
            fi
        fi
        ;;
    esac
    return $TRUE
}

### check if CDC is installed in global zone only (solaris 10+)
is_installed_gz_only()
{
    echo "is_installed_gz_only: `date`" >> ${LOG_FILE}
    case ${OS_REV} in
        sol1* | sol20* )
            if [ -f /var/sadm/install/gz-only-packages ] && [ "${GLOBAL_ZONE_ONLY}" != "non_global" ]; then
                cat /var/sadm/install/gz-only-packages | grep -v '#' | grep -v CentrifyDC- | grep CentrifyDC > /dev/null; RC=$?
                if [ ${RC} -eq 0 ]; then
                    # installed in global zone only
                    if [ "${FORCE_DA_GLOBAL}" = "Y"  ]; then
                        echo "\nWARNING: Centrify DirectControl is installed in the global zone only."        | tee -a ${LOG_FILE}
                        echo "         As the --force-da-global option is selected, DirectAudit will"         | tee -a ${LOG_FILE}
                        echo "         be forced to install. Please note that although the package is"        | tee -a ${LOG_FILE}
                        echo "         installed, it is installed in all zones, and that is different"        | tee -a ${LOG_FILE}
                        echo "         from the DirectControl package."                                       | tee -a ${LOG_FILE}
                        
                        if [ "${SILENT}" = "NO" ]; then
                            QUESTION="\nDo you want to continue installation? (C|Y|Q|N) [N]:\c"; do_ask_YorN "N" "C"
                            if [ "${ANSWER}" != "Y" ]; then
                                do_quit
                            else
                                GLOBAL_ZONE_ONLY="Y"
                            fi
                        else
                            GLOBAL_ZONE_ONLY="Y"
                        fi
                        return $TRUE
                    else
                        if [ "${SILENT}" = "NO" ]; then
                            echo "\nWARNING: Centrify DirectControl is installed in the global zone only."        | tee -a ${LOG_FILE}
                            echo "         If you continue (C|Y), all packages will be installed (upgraded)"      | tee -a ${LOG_FILE}
                            echo "         in the global zone only. If you want to install in all zones you"      | tee -a ${LOG_FILE}
                            echo "         must remove the existing package from the global zone first and"       | tee -a ${LOG_FILE}
                            echo "         then restart installation."                                            | tee -a ${LOG_FILE}
                            QUESTION="\nDo you want to continue installation? (C|Y|Q|N) [N]:\c"; do_ask_YorN "N" "C"
                            if [ "${ANSWER}" != "Y" ]; then
                                do_quit
                            else
                                GLOBAL_ZONE_ONLY="Y"
                            fi
                        else
                            # silent mode
                            if [ "${GLOBAL_ZONE_ONLY}" = "N" ]; then
                                echo "\nERROR: Centrify DirectControl is installed in the global zone only."        | tee -a ${LOG_FILE}
                                echo "       GLOBAL_ZONE_ONLY is set to \"N\" which means to install in all zones." | tee -a ${LOG_FILE}
                                echo "       If you want to install in all zones you must remove the existing"      | tee -a ${LOG_FILE}
                                echo "       package from the global zone first and then restart installation."     | tee -a ${LOG_FILE}
                                echo "       Exiting ..."      | tee -a ${LOG_FILE}
                                do_error $CODE_ESU
                            fi
                        fi
                        return $TRUE # installed in global zone only
                    fi
                else
                    echo "\nINFO: DirectControl is installed in all zones." | tee -a ${LOG_FILE}
                fi
            fi
            ;;
    esac
    return $FALSE # installed in all zones
} # is_installed_gz_only()

### make sure umask is to 002 or 022
umask_check()
{
    if [ "${TARGET_OS}" = "solaris" ]; then 
        UMASK="`umask`"
        case "${UMASK}" in
        "000"* | "002"* | "022")
            echo ${ECHO_FLAG} "INFO: current umask: ${UMASK}" >> ${LOG_FILE}
            ORG_UMASK=""
            ;;
        *)
            echo ${ECHO_FLAG} "WARNING: current umask: ${UMASK}" >> ${LOG_FILE}
            ORG_UMASK="${UMASK}"
            ;;
        esac

    fi
    return $TRUE
}

### restore umask to the original if it was changed
umask_restore()
{
    if [ "${TARGET_OS}" = "solaris" ]; then
        if [ "${ORG_UMASK}" != "" ]; then
            umask ${ORG_UMASK}
            ORG_UMASK=""
            echo ${ECHO_FLAG} "INFO: restoring umask to the original: `umask`" >> ${LOG_FILE}
        fi 
    fi
    return $TRUE
}

debug_echo ()
{
    if [ "${DEBUG}" = "on" ]; then
        echo ${ECHO_FLAG} "DEBUG: $1" >> ${LOG_FILE}
    fi
    return $TRUE
}

remove_last_0()
{
    case "$1" in
    *.0 )
        echo "$1" | sed 's/\.0$//'
        return 0
        ;;
    esac
    echo "$1"
    return 1
}

normalize_version()
{
    REDUCED=$1
    while REDUCED="`remove_last_0 \"$REDUCED\"`" ; do :; done
    echo "$REDUCED"
}

detect_esx()
{
    if vmware -v 2> /dev/null |grep "VMware ESX Server" >/dev/null; then
        echo ${ECHO_FLAG} "DEBUG: vmware -v:\n`vmware -v`" >> ${LOG_FILE}
        REVISION=`vmware -v |awk '{print $(4)}'`
    elif vmware -v 2> /dev/null |grep "VMware ESX " >/dev/null; then
        echo ${ECHO_FLAG} "DEBUG: vmware -v:\n`vmware -v`" >> ${LOG_FILE}
        REVISION=`vmware -v |awk '{print $(3)}'`
    elif grep -s "VMware ESX Server" /etc/issue > /dev/null; then
        echo ${ECHO_FLAG} "DEBUG: /etc/issue:\n`cat /etc/issue`" >> ${LOG_FILE}
        REVISION=`awk '/^VMware ESX Server/ {seen = 1; print $(4)} END {if (seen == 1) exit 1}' /etc/issue`
    elif [ -f /etc/vmware-release ]; then
        echo ${ECHO_FLAG} "DEBUG: /etc/vmware-release:\n`cat /etc/vmware-release`" >> ${LOG_FILE}
        RELEASE="`cat /etc/vmware-release`"
        case "${RELEASE}" in
        "VMware ESX Server 3"* )
            PKG_OS_REV=rhel3
            OS_REV=esx3
            ;;
        esac
        return $TRUE
    else
        return $FALSE
    fi
    
    REVISION="`normalize_version \"$REVISION\"`"
    case "$REVISION" in
    2.1.2 | 2.5 | 2.5.* )
        ### OS_REV=esx2;;
        echo ERROR: ESX ${REVISION} is not supported anymore. Exiting... | tee -a ${LOG_FILE}
        do_error $CODE_ESU;;
    # 2 | 2.* ) :;;
    3.0.[1-2] )
        PKG_OS_REV=rhel3
        OS_REV=esx${REVISION};;
    3.5 | 3.5.* )
        PKG_OS_REV=rhel3
        OS_REV=esx3.5;;
    3 | 3.* )
        PKG_OS_REV=rhel3
        OS_REV=esx3;;           
    4 | 4.* )
        PKG_OS_REV=rhel3
        OS_REV=esx4;;
    esac
    return $TRUE
}

### Detect LINUX version (if OS kernel is unknown)
detect_linux ()
{
    if detect_esx ; then
        :
    elif [ -f /etc/enterprise-release ]; then
        echo ${ECHO_FLAG} "DEBUG: /etc/enterprise-release:\n`cat /etc/enterprise-release`" >> ${LOG_FILE}
        RELEASE="`cat /etc/enterprise-release`"
        case "${RELEASE}" in
        *"Enterprise Linux"*"release 4"*)
            PKG_OS_REV=rhel3
            OS_REV=oracle4;;
        *"Enterprise Linux"*"release 5"*)
            PKG_OS_REV=rhel3
            OS_REV=oracle5;;
        *"Enterprise Linux"*"release 6"*)
            PKG_OS_REV=rhel3
            OS_REV=oracle6;;
        esac
    elif [ -f /etc/redhat-release ]; then
        echo ${ECHO_FLAG} "DEBUG: /etc/redhat-release:\n`cat /etc/redhat-release`" >> ${LOG_FILE}
        DESKTOP=""
        if [ -n "`cat /etc/redhat-release | grep Client`" ]; then
            DESKTOP="d"
        fi
        RELEASE="`cat /etc/redhat-release`"
        case "${RELEASE}" in
        "Red Hat Linux release 7.2"*)
            ### OS_REV=rh7.2;;
            echo ERROR: Red Hat Linux release 7.2 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        "Red Hat Linux release 7.3"*)
            ### OS_REV=rh7.3;;
            echo ERROR: Red Hat Linux release 7.3 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        "Red Hat Linux release 8"*)
            ### OS_REV=rh8;;
            echo ERROR: Red Hat Linux release 8 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        "Red Hat Linux release 9"*)
            ### OS_REV=rh9;;
            echo ERROR: Red Hat Linux release 9 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        "Red Hat Enterprise Linux"*"release 2.1"*)
            ### OS_REV=rhel2.1;;
            echo ERROR: Red Hat Enterprise Linux release 2.1 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        "Red Hat Enterprise Linux"*"release 3"*)
            OS_REV=rhel3;;
        *"Enterprise Linux"*"release 4"*" Update 8")
            PKG_OS_REV=rhel3
            OS_REV=rhel4.8;;
        *"Enterprise Linux"*"release 4"*" Update 9")
            PKG_OS_REV=rhel3
            OS_REV=rhel4.9;;
        *"Enterprise Linux"*"release 4"*)
            PKG_OS_REV=rhel3
            OS_REV=rhel4;;
        *"Enterprise Linux"*"release 5 "*)
            PKG_OS_REV=rhel3
            OS_REV=rhel${DESKTOP}5.0;;
        *"Enterprise Linux"*"release 5.1"*)
            PKG_OS_REV=rhel3
            OS_REV=rhel${DESKTOP}5.1;;
        *"Enterprise Linux"*"release 5.2"*)
            PKG_OS_REV=rhel3
            OS_REV=rhel${DESKTOP}5.2;;
        *"Enterprise Linux"*"release 5.3"*)
            PKG_OS_REV=rhel3
            OS_REV=rhel${DESKTOP}5.3;;
        *"Enterprise Linux"*"release 5.4"*)
            PKG_OS_REV=rhel3
            OS_REV=rhel${DESKTOP}5.4;;
        *"Enterprise Linux"*"release 5.5"*)
            PKG_OS_REV=rhel3
            OS_REV=rhel${DESKTOP}5.5;;
        *"Enterprise Linux"*"release 5.6"*)
            PKG_OS_REV=rhel3
            OS_REV=rhel${DESKTOP}5.6;;
        *"Enterprise Linux"*"release 5"*)
            PKG_OS_REV=rhel3
            OS_REV=rhel${DESKTOP}5;;
        *"Enterprise Linux"*"release 6.0"*)
            PKG_OS_REV=rhel3
            OS_REV=rhel${DESKTOP}6.0;;
        *"Enterprise Linux"*"release 6 "*)
            PKG_OS_REV=rhel3
            OS_REV=rhel${DESKTOP}6.0;;
        *"Enterprise Linux"*"release 6"*)
            PKG_OS_REV=rhel3
            OS_REV=rhel${DESKTOP}6;;
        "Fedora Core release 2"*)
            ### rhfc2 is still supported
            PKG_OS_REV=rhel3
            OS_REV=rhfc2;;
        "Fedora Core release 3"*)
            ### OS_REV=rhfc3;;
            echo ERROR: Fedora Core release 3 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        "Fedora Core release 4"*)
            ### PKG_OS_REV=rhel3
            ### OS_REV=rhfc4;;
            echo ERROR: Fedora Core release 4 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        "Fedora Core release 5"*)
            ### PKG_OS_REV=rhel3
            ### OS_REV=rhfc5;;
            echo ERROR: Fedora Core release 5 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        "Fedora Core release 6"*)
            ### PKG_OS_REV=rhel3
            ### OS_REV=rhfc6;;
            echo ERROR: Fedora Core release 6 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        "Fedora"*"release 7"*)
            ### PKG_OS_REV=rhel3
            ### OS_REV=rhfc7;;
            echo ERROR: Fedora Core release 7 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        "Fedora"*"release 8"*)
            ### PKG_OS_REV=rhel3
            ### OS_REV=rhfc8;;
            echo ERROR: Fedora Core release 8 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        "Fedora"*"release 9"*)
            PKG_OS_REV=rhel3
            OS_REV=rhfc9;;
        "Fedora"*"release 10"*)
            PKG_OS_REV=rhel3
            OS_REV=rhfc10;;
        "Fedora"*"release 11"*)
            PKG_OS_REV=rhel3
            OS_REV=rhfc11;;
        "Fedora"*"release 12"*)
            PKG_OS_REV=rhel3
            OS_REV=rhfc12;;
        "Fedora"*"release 13"*)
            PKG_OS_REV=rhel3
            OS_REV=rhfc13;;
        "Fedora"*"release 14"*)
            PKG_OS_REV=rhel3
            OS_REV=rhfc14;;
        "Fedora"*"release 15"*)
            PKG_OS_REV=rhel3
            OS_REV=rhfc15;;
        "Red Hat Linux Advanced Server release 2.1AS"*)
            ### OS_REV=centos2.1;;
            echo ERROR: CentOS 2.1 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        "CentOS release 3.8"*)
            ### PKG_OS_REV=rhel3
            ### OS_REV=centos3.8;;
            echo ERROR: CentOS 3.8 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        "CentOS release 3.9"*)
            ### PKG_OS_REV=rhel3
            ### OS_REV=centos3.9;;
            echo ERROR: CentOS 3.9 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        "CentOS release 4.4"*)
            PKG_OS_REV=rhel3
            OS_REV=centos4.4;;
        "CentOS release 4.5"*)
            PKG_OS_REV=rhel3
            OS_REV=centos4.5;;
        "CentOS release 4.6"*)
            PKG_OS_REV=rhel3
            OS_REV=centos4.6;;
        "CentOS release 4.7"*)
            PKG_OS_REV=rhel3
            OS_REV=centos4.7;;
        "CentOS release 4.8"*)
            PKG_OS_REV=rhel3
            OS_REV=centos4.8;;
        "CentOS release 4.9"*)
            PKG_OS_REV=rhel3
            OS_REV=centos4.9;;
        "CentOS release 5.0"*)
            PKG_OS_REV=rhel3
            OS_REV=centos5.0;;
        "CentOS release 5.1"*)
            PKG_OS_REV=rhel3
            OS_REV=centos5.1;;
        "CentOS release 5.2"*)
            PKG_OS_REV=rhel3
            OS_REV=centos5.2;;
        "CentOS release 5.3"*)
            PKG_OS_REV=rhel3
            OS_REV=centos5.3;;
        "CentOS release 5.4"*)
            PKG_OS_REV=rhel3
            OS_REV=centos5.4;;
        "CentOS release 5.5"*)
            PKG_OS_REV=rhel3
            OS_REV=centos5.5;;
        "CentOS release 5.6"*)
            PKG_OS_REV=rhel3
            OS_REV=centos5.6;;
        "CentOS release 5"*)
            PKG_OS_REV=rhel3
            OS_REV=centos5;;
        "CentOS release 6"*)
            PKG_OS_REV=rhel3
            OS_REV=centos6;;
        "Scientific Linux"*"release 3.0.8"*)
            ### PKG_OS_REV=rhel3
            ### OS_REV=scientific3.0.8;;
            echo ERROR: Scientific Linux 3.0.8 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        "Scientific Linux"*"release 3.0.9"*)
            ### PKG_OS_REV=rhel3
            ### OS_REV=scientific3.0.9;;
            echo ERROR: Scientific Linux 3.0.9 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        "Scientific Linux"*"release 4.4"*)
            PKG_OS_REV=rhel3
            OS_REV=scientific4.4;;
        "Scientific Linux"*"release 4.5"*)
            PKG_OS_REV=rhel3
            OS_REV=scientific4.5;;
        "Scientific Linux"*"release 4.6"*)
            PKG_OS_REV=rhel3
            OS_REV=scientific4.6;;
        "Scientific Linux"*"release 4.7"*)
            PKG_OS_REV=rhel3
            OS_REV=scientific4.7;;
        "Scientific Linux"*"release 4.8"*)
            PKG_OS_REV=rhel3
            OS_REV=scientific4.8;;
        "Scientific Linux"*"release 4.9"*)
            PKG_OS_REV=rhel3
            OS_REV=scientific4.9;;
        "Scientific Linux"*"release 5.0"*)
            PKG_OS_REV=rhel3
            OS_REV=scientific5.0;;
        "Scientific Linux"*"release 5.1"*)
            PKG_OS_REV=rhel3
            OS_REV=scientific5.1;;
        "Scientific Linux"*"release 5.2"*)
            PKG_OS_REV=rhel3
            OS_REV=scientific5.2;;
        "Scientific Linux"*"release 5.3"*)
            PKG_OS_REV=rhel3
            OS_REV=scientific5.3;;
        "Scientific Linux"*"release 5.4"*)
            PKG_OS_REV=rhel3
            OS_REV=scientific5.4;;
        "Scientific Linux"*"release 5.5"*)
            PKG_OS_REV=rhel3
            OS_REV=scientific5.5;;
        "Scientific Linux"*"release 5.6"*)
            PKG_OS_REV=rhel3
            OS_REV=scientific5.6;;
        "Scientific Linux"*"release 5"*)
            PKG_OS_REV=rhel3
            OS_REV=scientific5;;
        "Scientific Linux"*"release 6"*)
            PKG_OS_REV=rhel3
            OS_REV=scientific6;;
        "Mandriva Linux release 2008"*)
            ### PKG_OS_REV=rhel3
            ### OS_REV=mdv2008;;
            echo ERROR: Mandriva Linux 2008 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        "Mandriva Linux release 2009.1"*)
            PKG_OS_REV=rhel3
            OS_REV=mdv2009.1;;
        "Mandriva Linux release 2009"*)
            PKG_OS_REV=rhel3
            OS_REV=mdv2009;;
        "Mandriva Linux release 2010.1"*)
            PKG_OS_REV=rhel3
            OS_REV=mdv2010.1;;
        "Mandriva Linux release 2010.2"*)
            PKG_OS_REV=rhel3
            OS_REV=mdv2010.2;;
        "Mandriva Linux release 2010"*)
            PKG_OS_REV=rhel3
            OS_REV=mdv2010;;
        "Mandriva Linux release 2011"*)
            PKG_OS_REV=rhel3
            OS_REV=mdv2011;;
        "Mandriva Linux Enterprise Server release 5"*)
            PKG_OS_REV=rhel3
            OS_REV=mdves5;;
        "XenServer release 4.1"*"xenenterprise"*)
            PKG_OS_REV=rhel3
            OS_REV=xen4.1;;
        "XenServer release 4"*"xenenterprise"*)
            PKG_OS_REV=rhel3
            OS_REV=xen4;;
        "XenServer release 5.5"*"xenenterprise"*)
            PKG_OS_REV=rhel3
            OS_REV=xen5.5;;
        "XenServer release 5.6"*"xenenterprise"*)
            PKG_OS_REV=rhel3
            OS_REV=xen5.6;;
        "XenServer release 5"*"xenenterprise"*)
            PKG_OS_REV=rhel3
            OS_REV=xen5;;
        *)
            if [ -f /etc/system-release ]; then
                echo ${ECHO_FLAG} "DEBUG: /etc/system-release:\n`cat /etc/system-release`" >> ${LOG_FILE}
                RELEASE1="`cat /etc/system-release`"
                case "${RELEASE1}" in
                "Amazon Linux AMI release 1"*)
                    PKG_OS_REV=rhel3
                    OS_REV=amazon;;
                "Amazon Linux AMI"*)
                    PKG_OS_REV=rhel3
                    OS_REV=amazon;;
                esac
            fi
            ;;
        esac
    elif [ -f /etc/SuSE-release ]; then
        echo ${ECHO_FLAG} "DEBUG: /etc/SuSE-release:\n`cat /etc/SuSE-release`" >> ${LOG_FILE}
        OPEN=""
        DESKTOP=""
        if [ -n "`cat /etc/SuSE-release | grep open`" ]; then
            OPEN="open"
        elif [ -n "`cat /etc/SuSE-release | grep Desktop`" ]; then
            DESKTOP="d"
        fi
        RELEASE="`grep VERSION /etc/SuSE-release | sed s'/VERSION = //'`"
        RELEASE="`normalize_version \"$RELEASE\"`"
        if [ -z "$OPEN" ]; then
            if [ -n "$DESKTOP" ]; then
                case "${RELEASE}" in
                8 | 8.* | 9 | 9.* )
                    ### PKG_OS_REV=suse8
                    ### OS_REV=suse${DESKTOP}${RELEASE}
                    echo "ERROR: SuSE Desktop ${RELEASE} is not supported anymore. Exiting..." | tee -a ${LOG_FILE}
                    do_error $CODE_ESU
                    ;;
                10 | 10.* )
                    PKG_OS_REV=suse8
                    OS_REV=suse${DESKTOP}10;;
                11 | 11.* )
                    PKG_OS_REV=suse8
                    OS_REV=suse${DESKTOP}11;;
                esac
            else
                case "${RELEASE}" in
                8 | 8.* )
                    OS_REV=suse8;;
                9 | 9.* )
                    PKG_OS_REV=suse8
                    OS_REV=suse9;;
                10 | 10.* )
                    PKG_OS_REV=suse8
                    OS_REV=suse10;;
                11 | 11.* )
                    PKG_OS_REV=suse8
                    OS_REV=suse11;;
               esac
            fi
        else
            case "${RELEASE}" in
            10 | 10.* )
                ### PKG_OS_REV=suse8
                ### OS_REV=opensuse${RELEASE};;
                echo "ERROR: openSUSE ${RELEASE} are not supported anymore. Exiting..." | tee -a ${LOG_FILE}
                do_error $CODE_ESU
                ;;
            11 | 11.[1-4] )
                if [ "$RELEASE" = "11" ]; then RELEASE="11.0"; fi
                PKG_OS_REV=suse8
                OS_REV=opensuse${RELEASE};;
            11 | 11.* )
                PKG_OS_REV=suse8
                OS_REV=opensuse11;;
            esac
        fi
    elif [ -f /etc/UnitedLinux-release ]; then
        echo ${ECHO_FLAG} "DEBUG: /etc/UnitedLinux-release:\n`cat /etc/UnitedLinux-release`" >> ${LOG_FILE}
        RELEASE="`cat /etc/UnitedLinux-release | grep VERSION`"
        case "${RELEASE}" in
        "VERSION = 1."*)
            OS_REV=suse8;;
        esac
    elif [ -f /etc/lsb-release ]; then
        echo ${ECHO_FLAG} "INFO: /etc/lsb-release:\n`cat /etc/lsb-release`" >> ${LOG_FILE}
        if [ "`uname -r | grep generic >> ${LOG_FILE}; echo $?`" = "0" ]; then
            if [ "`uname -r | grep pae >> ${LOG_FILE}; echo $?`" = "0" ]; then
                KERNEL_CFG="s" # server with Physical Address Extension
            else
                KERNEL_CFG="d" # desktop
            fi
        else
            KERNEL_CFG="s" # server
        fi
        RELEASE="`grep DISTRIB_RELEASE /etc/lsb-release | sed 's/DISTRIB_RELEASE=//'`"
        RELEASE_YEAR="`echo \"$RELEASE\" | sed -e 's/\..*//'`"
        RELEASE_MONTH="`echo \"$RELEASE\" | sed -e 's/[^\.]*\.//' -e 's/\..*//'`"
        case "${RELEASE_YEAR}" in
        [6-9] | 1[0-1] )
            if [ "$RELEASE_YEAR" = 6 ]; then
                case "${RELEASE_MONTH}" in
                0[7-9] | 1[0-2] )
                    RELEASE_YEAR=`expr $RELEASE_YEAR + 1`
                    RELEASE_MONTH=04
                    ;;
                0[1-6] | * )
                    RELEASE_MONTH=06
                    ;;
                esac
            else
                case "${RELEASE_MONTH}" in
                1[1-2]* )
                    RELEASE_YEAR=`expr $RELEASE_YEAR + 1`
                    RELEASE_MONTH=04
                    ;;
                0[1-4]* )
                    RELEASE_MONTH=04
                    ;;
                0[5-9]* | 10 | * )
                    RELEASE_MONTH=10
                    ;;
                esac
            fi
            PKG_OS_REV=deb5
            OS_REV=ubuntu${KERNEL_CFG}${RELEASE_YEAR}.${RELEASE_MONTH};;
        esac

        case "${OS_REV}" in
        ubuntud7.04 | ubuntud7.10 | ubuntus7.04 | ubuntus7.10 )
            echo "ERROR: Ubuntu ${RELEASE_YEAR}.${RELEASE_MONTH} is not supported anymore. Exiting..." | tee -a ${LOG_FILE}
            do_error $CODE_ESU
            ;;
        esac
    elif [ -f /etc/debian_version ] && [ "${OS_REV}" = "unknown" ]; then
        echo ${ECHO_FLAG} "DEBUG: /etc/debian_version:\n`cat /etc/debian_version`" >> ${LOG_FILE}
        RELEASE="`cat /etc/debian_version`"
        case "${RELEASE}" in
        "3.0"*)
            ### OS_REV=deb3.0;;
            echo ERROR: Debian 3.0 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        "3.1"*)
            ### OS_REV=deb3.1;;
            echo ERROR: Debian 3.1 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        "4."*)
            ### OS_REV=deb4;;
            echo ERROR: Debian 4 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        "5."*)
            OS_REV=deb5;;
        "6."*)
            PKG_OS_REV=deb5
            OS_REV=deb6;;
        esac
    fi
    if [ "${OS_REV}" = "unknown" ]; then return $FALSE; fi
    return $TRUE
} # detect_linux()

### Check 64 bits support on Mac
darwin_support_64bits()
{
    # Check for OS version.
    version=`sw_vers -productVersion`

    case "$version" in
    10.3*|10.4*|10.5*)
        return 1
        ;;
    esac

    # Is it 64 bits architecture?
    is_64bits=`sysctl -n hw.optional.x86_64 2> /dev/null`
    if [ -n "$is_64bits" ] && [ "$is_64bits" -eq 1 ]; then
        return 0
    fi

    return 1
}

### Detect OS, OS revision, architecture (hardware-platform)
detect_os ()
{
    ### run detect_os only once, if PKG_OS_REV is set already then just return
    if [ "${PKG_OS_REV}" != "unknown" ]; then return ${TRUE}; fi
    echo Detecting local platform ...
    case "`uname -s`" in
    Linux*)
        TARGET_OS=linux
        EXPRESS_PL=$TRUE
        log_header
        case "`uname -r`" in
        2.2.20* )
            ### OS_REV=deb3.0;;
            echo ERROR: Debian 3.0 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        2.4.7*)
            ### OS_REV=rh7.2;;
            echo ERROR: Red Hat Linux release 7.2 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        2.4.9-34* | 2.4.9-vmnix2*)
            OS_REV=esx2;;
        2.4.18-3*)
            ### OS_REV=rh7.3;;
            echo ERROR: Red Hat Linux release 7.3 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        2.4.18-14*)
            ### OS_REV=rh8;;
            echo ERROR: Red Hat Linux release 8 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        2.4.19-* | 2.4.21-198*) # SLES8
            OS_REV=suse8;;
        2.4.20-6* | 2.4.20-8*) # RH9
            ### OS_REV=rh9;;
            echo ERROR: Red Hat Linux release 9 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        2.4.21-15* | 2.4.21-32*) # RHEL 3
            OS_REV=rhel3;;
        2.4.21-47*) # CentOS 3.8 or Scientific 3.0.8
            PKG_OS_REV=rhel3
            OS_REV=centos3.8;;
#            OS_REV=scientific3.0.8;;
        2.6.5-1.358*) # FC2
            ### rhfc2 is still supported
            PKG_OS_REV=rhel3
            OS_REV=rhfc2;;
        2.6.5-7* | 2.6.8-24*) # SLES9
            PKG_OS_REV=suse8
            OS_REV=suse9;;
        2.6.9-5.EL* | 2.6.9-22.* | 2.6.9-34.* | 2.6.9-42.*)
            PKG_OS_REV=rhel3
            OS_REV=rhel4;;
        2.6.9-55.*)
            PKG_OS_REV=rhel3
            OS_REV=scientific4.5;;
        2.6.11-1.*)
            PKG_OS_REV=rhel3
            OS_REV=rhfc4;;
        2.6.13-15* | 2.6.16-rc1* | 2.6.16.13* | 2.6.16.21* | 2.6.16.60* ) # SLES10
            PKG_OS_REV=suse8
            OS_REV=suse10;;
        2.6.15-1.*)
            PKG_OS_REV=rhel3
            OS_REV=rhfc5;;
        2.6.18-1.*)
            PKG_OS_REV=rhel3
            OS_REV=rhfc6;;
        2.6.18-8.* | 2.6.18-53.*)
            PKG_OS_REV=rhel3
            OS_REV=rhel5;;
        2.6.20-15*)
            PKG_OS_REV=deb5
            OS_REV=ubuntu7.04;;
        2.6.21-1.*)
            PKG_OS_REV=rhel3
            OS_REV=rhfc7;;
        2.6.23.1-*)
            PKG_OS_REV=rhel3
            OS_REV=rhfc8;;
        *)
            echo INFO: Unknown kernel: "`uname -r`". Calling detect_linux ... >> ${LOG_FILE}
            ;;
        esac
        detect_linux
        if [ "${OS_REV}" = "unknown" ]; then
            echo ERROR: Unknown OS revision: "`uname -r`". Exiting ... | tee -a ${LOG_FILE}
            do_error $CODE_ESU
        fi
        if [ "`uname -m`" = "i686" ]; then
            ARCH=i386
        elif [ "`uname -m`" = "ia64" ]; then
            ARCH=ia64
            case ${OS_REV} in
            suse* )
                PKG_OS_REV=suse9;;
            * )
                PKG_OS_REV=rhel4;;
            esac
        elif [ "`uname -m`" = "ppc" -o "`uname -m`" = "ppc64" ]; then
            ARCH=ppc
            case ${OS_REV} in
            rhel3 | rhel4 | rhel4.8 | rhel4.9 | rhel5 | rhel5.0 | rhel5.1 | rhel5.2 | rhel5.3 | rhel5.4 | rhel5.5 | rhel5.6 | rhel6 | rhel6.0 | \
            rheld5 | rheld5.0 | rheld5.1 | rheld5.2 | rheld5.3 | rheld5.4 | rheld5.5 | rheld5.6 | rheld6 | rheld6.0 )
                PKG_OS_REV=rhel3;;
            suse* )
                PKG_OS_REV=suse9;;
            esac
        elif [ "`uname -m`" = "x86_64" ]; then
            ARCH=x86_64
            case ${OS_REV} in
            rhel3 | rhel4 | rhel4.8 | rhel4.9 | rhel5 | rhel5.0 | rhel5.1 | rhel5.2 | rhel5.3 | rhel5.4 | rhel5.5 | rhel5.6 | rhel6 | rhel6.0 | \
            rheld5 | rheld5.0 | rheld5.1 | rheld5.2 | rheld5.3 | rheld5.4 | rheld5.5 | rheld5.6 | rheld6 | rheld6.0 | \
            rhfc3 | rhfc4 | rhfc5 | rhfc6 | rhfc7 | rhfc8 | rhfc9 | rhfc10 | rhfc11 | rhfc12 | rhfc13 | rhfc14 | rhfc15 | \
            oracle4 | oracle5 | oracle6 | \
            centos3.8 | centos3.9 | centos4.4 | centos4.5 | centos4.6 | centos4.7 | centos4.8 | centos4.9 | \
            centos5.0 | centos5.1 | centos5.2 | centos5.3 | centos5.4 | centos5.5 | centos5.6 | centos5 | centos6 | \
            scientific3.0.8 | scientific3.0.9 | scientific4.4 | scientific4.5 | scientific4.6 | scientific4.7 | scientific4.8 | scientific4.9 | \
            scientific5.0 | scientific5.1 | scientific5.2 | scientific5.3 | scientific5.4 | scientific5.5 | scientific5.6 | scientific5 | scientific6 | \
            mdves5 | \
            amazon )
                PKG_OS_REV=rhel3;;
            suse9* | suse10* | suse11* | sused9* | sused10* | sused11* | opensuse10* | opensuse11*)
                PKG_OS_REV=suse9;;
            esac
        elif [ "`uname -m`" = "s390x" ]; then
            ARCH=s390x
            case ${OS_REV} in
            suse10)
                PKG_OS_REV=suse10;;
            rhel5 | rhel5.0 | rhel5.1 | rhel5.2 | rhel5.3 | rhel5.4 | rhel5.5 | rhel5.6 | rhel6 | rhel6.0 )
                PKG_OS_REV=rhel5;;
            esac
        else
            echo ERROR: Unknown hardware-platform: "`uname -m`". Exiting ... | tee -a ${LOG_FILE}
            do_error $CODE_ESU
        fi
        case ${OS_REV} in
        rhfc2 )
            EXPRESS_PL=$FALSE
        esac
        ;;
    SunOS*)
        TARGET_OS=solaris
        EXPRESS_PL=$TRUE
        REBOOT_CMD=/usr/sbin/reboot
        REVISION="`uname -r`"
        log_header
        if [ "$REVISION" = "5.6" ]; then
            ### OS_REV=sol2.6
            echo ERROR: Solaris 2.6 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU
        elif [ "$REVISION" = "5.7" ]; then
            ### OS_REV=sol7
            echo ERROR: Solaris 2.7 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU
        elif [ "$REVISION" = "5.8" ]; then
            OS_REV=sol8
        elif [ "$REVISION" = "5.9" ]; then
            OS_REV=sol9
        elif [ "$REVISION" = "5.10" ]; then
            OS_REV=sol10
        elif [ -r /etc/release ]; then
            REVISION="`grep Solaris /etc/release | awk '{ print $2 }'`"
            case "$REVISION" in
            2008.* )
                OS_REV=sol2008.11;;
            2009.* )
                OS_REV=sol2009.06;;
            Express )
                REVISION="`grep Assembled /etc/release | awk '{ print $NF }'`"
                case "$REVISION" in
                2008 )
                    OS_REV=sol2008.11;;
                2009 )
                    OS_REV=sol2009.06;;
                esac
            esac
        fi
        if [ "${OS_REV}" = "unknown" ]; then
            echo ERROR: Unknown OS revision: "$REVISION". Exiting ... | tee -a ${LOG_FILE}
            do_error $CODE_ESU
        fi
        if [ "`uname -p`" = "i386" ]; then
            ARCH=x86
            case "${OS_REV}" in
            sol1* | sol20* )
                PKG_OS_REV=sol9;;
            esac
            isainfo -v | grep 64-bit >> ${LOG_FILE}
            if [ $? -eq 0 ]; then
                ARCH=x86_64
                PKG_ARCH=x86
            fi
        elif [ "`uname -p`" = "sparc" ]; then
            ARCH=sparc
            case "${OS_REV}" in
            sol9 | sol1* | sol20* )
                PKG_OS_REV=sol8;;
            esac
        else
            echo ERROR: Unknown processor: "`uname -p`". Exiting ... | tee -a ${LOG_FILE}
            do_error $CODE_ESU
        fi
        if [ -x /usr/sbin/zoneadm ] && [ "`/usr/sbin/zoneadm list -p | grep 0:global > /dev/null; echo $?`" = "0" ]; then
            ### global zone
            GLOBAL_ZONE_ONLY="N"
        fi
        ;;
    HP-UX*)
        TARGET_OS=hpux
        LOG_FILE_DEF=/var/adm/syslog/centrifydc-install.log
        REBOOT_CMD=/usr/sbin/reboot
        INIT_DIR=/sbin/init.d
        log_header
        if [ "`uname -r`" = "B.11.00" ]; then
            ### OS_REV=hp11.00
            echo ERROR: HP-UX 11.00 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU
        elif [ "`uname -r`" = "B.11.11" ]; then
            OS_REV=hp11.11
        elif [ "`uname -r`" = "B.11.22" ]; then
            ### OS_REV=hp11.22
            echo ERROR: HP-UX 11.22 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU
        elif [ "`uname -r`" = "B.11.23" ]; then
            OS_REV=hp11.23
        elif [ "`uname -r`" = "B.11.31" ]; then
            OS_REV=hp11.31
            PKG_OS_REV=hp11.23
        else
            echo ERROR: Unknown OS revision: "`uname -r`". Exiting ... | tee -a ${LOG_FILE}
            do_error $CODE_ESU
        fi
        if [ -d /tcb ]; then OS_MODE="trusted"; fi
        case "`uname -m`" in
        9000/7* | 9000/8*)
            ARCH=pa;;
        ia64)
            ARCH=ia64;;
        *)
            echo ERROR: Unknown hardware-platform: "`uname -m`". Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        esac
        ;;
    AIX*)
        TARGET_OS=aix
        SEP="."
        REBOOT_CMD=/usr/sbin/reboot
        ADD_ON_LIST=`echo ${ADD_ON_LIST} | sed 's/krb5/krb5 krb5lib/'`
        log_header
        if [ "`uname -rv`" = "3 4" ]; then
            ### OS_REV=aix4.3
            echo ERROR: AIX 4.3 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU
        elif [ "`uname -rv`" = "1 5" ]; then
            OS_REV=aix5.1
        elif [ "`uname -rv`" = "2 5" ]; then
            PKG_OS_REV=aix5.1
            OS_REV=aix5.2
        elif [ "`uname -rv`" = "3 5" ]; then
            PKG_OS_REV=aix5.1
            OS_REV=aix5.3
        elif [ "`uname -rv`" = "1 6" ]; then
            PKG_OS_REV=aix5.1
            OS_REV=aix6.1
        elif [ "`uname -rv`" = "1 7" ]; then
            PKG_OS_REV=aix5.1
            OS_REV=aix7.1
        else
            echo ERROR: unknown OS revision: "`uname -rv`". Exiting ... | tee -a ${LOG_FILE}
            do_error $CODE_ESU
        fi
        if [ "${OS_REV}" = "aix4.3" ]; then
            ARCH=ppc
        else
            if [ "`uname -p`" = "powerpc" ]; then
                ARCH=ppc
            else
                echo ERROR: Unknown hardware-platform: "`uname -p`". Exiting ... | tee -a ${LOG_FILE}
                do_error $CODE_ESU
            fi
        fi
        ;;
    IRIX*)
        ### TARGET_OS=irix
        echo ERROR: IRIX OS is not supported anymore. Exiting... 
        do_error $CODE_ESU
        ;;
    Darwin*)
        TARGET_OS=darwin
        EXPRESS_PL=$TRUE
        VAR=/private/var
        VAR_TMP=/private/var/tmp/centrifydc${PID}
        LOG_FILE_DEF=/private/var/log/centrifydc-install.log
        ADD_ON_LIST="${ADD_ON_LIST} adfixid"
        log_header
        SERVER=""
        sw_vers -productName | grep Server > /dev/null 2>&1
        if [ $? -eq 0 ]; then
            SERVER="s"
        fi
        case "`uname -r`" in
        6.8*)
            ### OS_REV=10.2;;
            echo ERROR: Mac OS version 10.2 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        7.*)
            ### OS_REV=10.3;;
            echo ERROR: Mac OS version 10.3 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        8.*)
            ### PKG_OS_REV=10.4
            ### OS_REV=10.4${SERVER};;
            echo ERROR: Mac OS version 10.4 is not supported anymore. Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        9.*)
            PKG_OS_REV=10.5
            OS_REV=10.5${SERVER};;
        10.*)
            PKG_OS_REV=10.6
            OS_REV=10.6${SERVER};;
        *)
            echo ERROR: unknown OS revision: "`uname -r`". Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        esac
        SERVER=""
        case "`uname -p`" in
        powerpc)
            ARCH=ppc;;
        i386)
            if darwin_support_64bits; then
                ARCH=x86_64
            else
                ARCH=i386
            fi
            ;;
        *)
            echo ERROR: Unknown hardware-platform: "`uname -p`". Exiting... | tee -a ${LOG_FILE}
            do_error $CODE_ESU;;
        esac
        ;;
    *)
        echo ERROR: Unknown target OS: "`uname -s`". Exiting ... | tee -a ${LOG_FILE}
        do_error $CODE_ESU;;
    esac
    if [ "${PKG_OS_REV}" = "unknown" ]; then PKG_OS_REV=${OS_REV}; fi
    if [ "${PKG_ARCH}" = "unknown" ]; then PKG_ARCH=${ARCH}; fi
    ADCHECK_FNAME="adcheck-${PKG_OS_REV}-${PKG_ARCH}"
    if [ "${TARGET_OS}" = "darwin" ]; then ADCHECK_FNAME="adcheck-mac${PKG_OS_REV}"; fi
    echo "INFO: TARGET_OS=${TARGET_OS}" >> ${LOG_FILE}
    echo "INFO: OS_REV=${OS_REV}" >> ${LOG_FILE}
    echo "INFO: ARCH=${ARCH}" >> ${LOG_FILE}
    if [ "${EXPRESS_PL}" -eq $TRUE ]; then
        echo "INFO: Express mode is supported" >> ${LOG_FILE}
    else
        echo "INFO: Express mode is not supported" >> ${LOG_FILE}
    fi
} # detect_os()

### WPAR workaround
fix_wpar()
{
    if [ "${TARGET_OS}" != "aix" ] || [ `uname -v` -lt 6 ]; then
        echo $ECHO_FLAG "\nERROR:" | tee -a ${LOG_FILE}
        echo $ECHO_FLAG "WPARs are not supported on `uname -sv` platform.\n" | tee -a ${LOG_FILE}
        do_exit ${CODE_ESU}
    elif [ ! -x /usr/bin/adinfo ]; then
        echo $ECHO_FLAG "\nERROR:" | tee -a ${LOG_FILE}
        echo $ECHO_FLAG "Could not find /usr/sbin/adjoin." | tee -a ${LOG_FILE}
        echo $ECHO_FLAG "Centrify DirectControl must be installed before using --wpar option.\n" | tee -a ${LOG_FILE}
        do_exit ${CODE_ESU}
    fi
    echo $ECHO_FLAG "\ninstall-express.sh: fix_wpar: " >> ${LOG_FILE}
    get_cur_version
    if [ "${UNINSTALL}" != "Y" ]; then
        ### install
        if [ `mount | grep " /dev/hd" > /dev/null; echo $?` -eq 0 ]; then
            ### global environment
            if [ "`compare_ver ${CUR_VER} 4.2.2; echo ${COMPARE}`" = "lt" ]; then
                echo "CDC version is less than 4.2.2 so keep /usr/lib/security/methods.cfg in place." >> ${LOG_FILE}
            else
                if [ ! -h /usr/lib/security/methods.cfg ] || \
                   [ "`ls -l /usr/lib/security/methods.cfg | grep '/etc/centrifydc/methods.cfg'`" = "" ]; then
                    echo "moving /usr/lib/security/methods.cfg to /etc/centrifydc ..." >> ${LOG_FILE}
                    cp -pf /usr/lib/security/methods.cfg /etc/centrifydc/
                    if [ ! -f /usr/lib/security/methods.cfg.pre_cdc_wpar ]; then
                        mv /usr/lib/security/methods.cfg /usr/lib/security/methods.cfg.pre_cdc_wpar
                    else
                        mv /usr/lib/security/methods.cfg /usr/lib/security/methods.cfg.pre_cdc_wpar2
                    fi
                    ln -s /etc/centrifydc/methods.cfg /usr/lib/security/methods.cfg
                else
                    echo "/usr/lib/security/methods.cfg is already a symlink pointing to /etc/centrifydc/methods.cfg" >> ${LOG_FILE}
                fi
            fi
            echo "copying /etc/centrifydc to /usr/share/centrifydc/wpar ..." >> ${LOG_FILE}
            mkdir -p /usr/share/centrifydc/wpar/etc/centrifydc
            ( cd /etc/centrifydc && tar cf - ./ ) | ( cd /usr/share/centrifydc/wpar/etc/centrifydc && tar xf - )
            cp -f /etc/centrifydc/defaults.conf /usr/share/centrifydc/wpar/etc/centrifydc/centrifydc.conf
            cp -f ${THIS_PRG} /usr/share/centrifydc/bin/fix_wpar.sh
            cp -f ${THIS_PRG} /usr/share/centrifydc/bin/uninstall.sh
            chmod 550 /usr/share/centrifydc/bin/fix_wpar.sh
            if [ ! -f /usr/lib/security/methods.cfg.pre_cdc_wpar ] && [ ! -f /usr/lib/security/methods.cfg.pre_cdc_wpar2 ]; then
                ### make a copy for WPAR
                cp -f /etc/centrifydc/methods.cfg /usr/share/centrifydc/wpar/etc/centrifydc/methods.cfg
            fi
            if [ ! -d /etc/centrifydc/openldap ]; then
                echo "/etc/centrifydc/openldap doesn't exist, relocating /usr/share/centrifydc/etc/openldap" >> ${LOG_FILE}
                mkdir /etc/centrifydc/openldap
                mv /usr/share/centrifydc/etc/openldap/ldap.conf /etc/centrifydc/openldap
                rm -Rf /usr/share/centrifydc/etc/openldap
                ln -s /etc/centrifydc/openldap /usr/share/centrifydc/etc/openldap
            fi
        elif [ -n "`mount | grep -v ' /dev/' | grep ' /usr ' | grep ro`" ]; then
            ### WPAR environment with read-only /usr
            if [ -f /etc/centrifydc/INSTALLED ]; then
                wpar_pre_rm # upgrade only
            else
                mkdir -p /etc/centrifydc/openldap
                touch /etc/centrifydc/openldap/ldap.conf
                rm -Rf /var/centrifydc/upgrade >> ${LOG_FILE} 2>> ${LOG_FILE}
            fi
            echo "copying /usr/share/centrifydc/wpar/etc/centrifydc to /etc/ ..." >> ${LOG_FILE}
            ( cd /usr/share/centrifydc/wpar/etc/centrifydc && tar cf - ./ ) | ( cd /etc/centrifydc && tar xf - )
            if [ "`compare_ver ${CUR_VER} 4.2.2; echo ${COMPARE}`" = "lt" ]; then
                ### /etc/centrifydc/methods.cfg is not needed in WPAR
                echo "CDC version is less than 4.2.2 so disable autoedit." >> ${LOG_FILE}
                cat /etc/centrifydc/centrifydc.conf | grep -v '^#' | grep 'adclient.autoedit.methods:' | grep true > /dev/null 2> /dev/null
                if [ $? -eq 0 ]; then
                    cat /etc/centrifydc/centrifydc.conf | sed '/^[ ]*adclient.autoedit.methods/d' > /etc/centrifydc/centrifydc.conf.tmp
                    mv /etc/centrifydc/centrifydc.conf.tmp /etc/centrifydc/centrifydc.conf
                fi
                cat /etc/centrifydc/centrifydc.conf | grep -v '^#' | grep 'adclient.autoedit.methods:' | grep false > /dev/null 2> /dev/null
                if [ $? -ne 0 ]; then
                    echo "adclient.autoedit.methods: false" >> /etc/centrifydc/centrifydc.conf
                fi
            else
                ### ensure there is /etc/centrifydc/methods.cfg in WPAR
                if [ -f /etc/centrifydc/methods.cfg ]; then
                    echo "found /etc/centrifydc/methods.cfg" >> ${LOG_FILE}
                else
                    echo "copying methods.cfg into /etc/centrifydc/" >> ${LOG_FILE}
                    if [ -f /usr/lib/security/methods.cfg.pre_cdc_wpar2 ]; then
                        ### the latest version
                        cp -f /usr/lib/security/methods.cfg.pre_cdc_wpar2 /etc/centrifydc/methods.cfg
                    elif [ -f /usr/lib/security/methods.cfg.pre_cdc_wpar ]; then
                        cp -f /usr/lib/security/methods.cfg.pre_cdc_wpar /etc/centrifydc/methods.cfg
                    elif [ -f /usr/share/centrifydc/wpar/etc/centrifydc/methods.cfg ]; then
                        cp -f /usr/share/centrifydc/wpar/etc/centrifydc/methods.cfg /etc/centrifydc/methods.cfg
                    else
                        echo "ERROR: could not find methods.cfg to copy into /etc/centrifydc/" | tee -a ${LOG_FILE}
                    fi
                fi
            fi
            if [ ! -f /etc/centrifydc/INSTALLED ]; then
                wpar_post_i # fresh install only
                touch /etc/centrifydc/INSTALLED
            fi
            wpar_config # install and upgrade
        fi
    else
        ### uninstall
        if [ -x /usr/sbin/lswpar ] && [ `/usr/sbin/lswpar -q -c -a name > /dev/null 2> /dev/null; echo $?` -eq 0 ]; then
            ### global environment
            WPAR_LIST="`/usr/sbin/lswpar -q -c -a name 2> /dev/null`"
            WPAR_NOT_CLEAN=""
            for WPAR_NAME in ${WPAR_LIST}
            do
                WPAR_DIR="`/usr/sbin/lswpar -q -c -a directory ${WPAR_NAME}`"
                if [ -d ${WPAR_DIR}/etc/centrifydc ] && [ `mount | grep " ${WPAR_DIR}/usr" | grep " ro" > /dev/null; echo $?` -eq 0 ]; then
                    WPAR_NOT_CLEAN="${WPAR_NOT_CLEAN} ${WPAR_NAME}"
                fi
            done
            if [ -n "${WPAR_NOT_CLEAN}" ]; then
                echo "\nERROR: Could not perform WPAR clean-up." | tee -a ${LOG_FILE}
                echo "Please run '/usr/share/centrifydc/bin/uninstall.sh --wpar' in the next WPAR(s):" | tee -a ${LOG_FILE}
                for WPAR_NAME in ${WPAR_NOT_CLEAN}
                do
                    echo "    ${WPAR_NAME}" | tee -a ${LOG_FILE}
                done
                do_error ${CODE_EUN}
            fi
            if [ -h /usr/lib/security/methods.cfg ] && 
               [ "`ls -l /usr/lib/security/methods.cfg | grep '/etc/centrifydc/methods.cfg'`" != "" ]; then
                echo "restoring /usr/lib/security/methods.cfg from /etc/centrifydc ..." >> ${LOG_FILE}
                rm /usr/lib/security/methods.cfg
                cp -p /etc/centrifydc/methods.cfg /usr/lib/security/
            else
                echo "INFO: /usr/lib/security/methods.cfg is not a symlink to /etc/centrifydc ..." >> ${LOG_FILE}
            fi
            rm -f /usr/lib/security/methods.cfg.pre_cdc_wpar*
            if [ -d /usr/share/centrifydc/wpar ]; then
                echo "removing /usr/share/centrifydc/wpar ..." >> ${LOG_FILE}
                rm -Rf /usr/share/centrifydc/wpar
            else
                echo "INFO: /usr/share/centrifydc/wpar doesn't exist" >> ${LOG_FILE}
            fi
            rm -f /usr/share/centrifydc/bin/fix_wpar.sh
        elif [ -n "`mount | grep -v ' /dev/' | grep ' /usr ' | grep ro`" ]; then
            ### WPAR environment with read-only /usr
            wpar_pre_d
            wpar_unpost_i
            echo "removing /etc/centrifydc and /var/centrifydc ..." >> ${LOG_FILE}
            rm -Rf /etc/centrifydc
            rm -Rf /var/centrifydc
            wpar_unpre_i
        fi
    fi
    if [ "${WPAR}" = "yes" ]; then do_exit 0; fi
    return $TRUE
} # fix_wpar

wpar_pre_rm()
{
    echo "wpar_pre_rm (pre-remove of the old package): `date`" >> ${LOG_FILE}

    echo "Upgrading from ${CUR_VER} ..." >> ${LOG_FILE}
    mkdir -p /var/centrifydc/upgrade/custom >> ${LOG_FILE}

    echo "preserving centrifydc.conf ..." >> ${LOG_FILE}
    cp -p /etc/centrifydc/*.* /var/centrifydc/upgrade/custom >> ${LOG_FILE}

    STATUS="off"
    if [ -f /var/centrifydc/upgrade/START ]; then
        rm /var/centrifydc/upgrade/START >> ${LOG_FILE}
    fi

    eval $CHECK_ADCLIENT >> ${LOG_FILE}
    if [ "$?" = "0" ]; then
        echo "stopping adclient ..." >> ${LOG_FILE}
        touch /var/centrifydc/upgrade/START >> ${LOG_FILE}
        /usr/bin/stopsrc -s centrifydc >> ${LOG_FILE}
    fi
    if [ -f /etc/krb5.keytab ] && [ ! -h /etc/krb5.keytab ]; then
        echo "moving /etc/krb5.* into /etc/krb5 dir ..." >> ${LOG_FILE}
        if [ ! -d /etc/krb5 ]; then
            if [ -f /etc/krb5 ]; then mv -f /etc/krb5 /etc/krb5.pre_cdc; fi
            mkdir /etc/krb5
        else
            if [ -h /etc/krb5/krb5.keytab ]; then
                mv -f /etc/krb5/krb5.keytab /etc/krb5/krb5.keytab.pre_cdc
            fi
            if [ -h /etc/krb5/krb5.ccache ]; then
                mv -f /etc/krb5/krb5.ccache /etc/krb5/krb5.ccache.pre_cdc
            fi
        fi
        mv -f /etc/krb5.* /etc/krb5
        ln -s /etc/krb5/krb5.keytab /etc/krb5.keytab
        ln -s /etc/krb5/krb5.ccache /etc/krb5.ccache
    fi

    if [ -s /etc/centrifydc/openldap/ldap.conf ]; then 
        echo "preserving /etc/centrifydc/openldap/ldap.conf ..." >> ${LOG_FILE}
        cp /etc/centrifydc/openldap/ldap.conf /etc/centrifydc/openldap/ldap.conf.cdc_upgrade >> ${LOG_FILE} 2>> ${LOG_FILE}
    fi
    return $TRUE
} # wpar_pre_rm

wpar_post_i()
{
    mkdir -p /var/run
    echo "wpar_post_i (post-install): `date`" >> ${LOG_FILE}
    lslpp -l CentrifyDC.core | grep CentrifyDC.core >> ${LOG_FILE} 2>> ${LOG_FILE}

    if [ -f /etc/rc.tcpip ]; then
        if [ ! -f /etc/rc.tcpip.pre_cdc ]; then
            cp /etc/rc.tcpip /etc/rc.tcpip.pre_cdc
        fi
        cat /etc/rc.tcpip | grep CentrifyDC > /dev/null 2> /dev/null
        RC=$?
        if [ "${RC}" != "0" ]; then
            echo "Fixing file /etc/rc.tcpip ..." >> ${LOG_FILE}
            echo ""                                    >> /etc/rc.tcpip
            echo "# Start up CentrifyDC adclient"      >> /etc/rc.tcpip
            echo "\tif [ -n \"\$src_running\" ]; then" >> /etc/rc.tcpip
            echo "\t\tstartsrc -e LIBPATH=/usr/share/centrifydc/lib:/usr/share/centrifydc/kerberos/lib -s centrifydc" >> /etc/rc.tcpip
            echo "\tfi"                                >> /etc/rc.tcpip
            echo "# last CentrifyDC line"              >> /etc/rc.tcpip
        else
            echo "INFO: No changes made in /etc/rc.tcpip."
        fi
    else
        echo "WARNING: Could not find /etc/rc.tcpip."
    fi

    mkssys -s centrifydc -p /usr/sbin/adclient -u 0 -S -n 15 -f 9

    if [ ! -d /etc/krb5 ]; then mkdir -p /etc/krb5; fi
    if [ -f /etc/krb5.keytab ] && [ ! -h /etc/krb5.keytab ]; then
        echo "moving /etc/krb5.* into /etc/krb5 dir ..." >> ${LOG_FILE}
        mv -f /etc/krb5.* /etc/krb5
    fi
    ln -sf /etc/krb5/krb5.keytab /etc/krb5.keytab
    ln -sf /etc/krb5/krb5.ccache /etc/krb5.ccache

    if [ ! -d /var/krb5/security/creds ]; then mkdir -p /var/krb5/security/creds; fi
    if [ ! -d /etc/skel ];                then mkdir -p /etc/skel; fi
    if [ ! -f /etc/skel/.profile ];       then ln -s /etc/security/.profile /etc/skel; fi

    # setup the crontab for rotating centrify_client.log
    crontab -l |  grep -v "/usr/share/centrifydc/bin/logrotate.sh" > /var/tmp/cron.$$
    echo "0 0 * * 0-6 /usr/share/centrifydc/bin/logrotate.sh" >> /var/tmp/cron.$$
    crontab /var/tmp/cron.$$
    rm -f /var/tmp/cron.$$

    return $TRUE
} # wpar_post_i

wpar_config()
{
    echo "wpar_config (post-post-install): `date`" >> ${LOG_FILE}
    lslpp -l CentrifyDC.core | grep CentrifyDC.core >> ${LOG_FILE} 2>> ${LOG_FILE}

    if [ -f /etc/shells ]; then
        grep "\/usr\/bin\/dzsh" /etc/shells > /dev/null
        if [ $? -ne 0 ]; then
            echo "adding /usr/bin/dzsh to /etc/shells ..." >> ${LOG_FILE}
            echo /usr/bin/dzsh >> /etc/shells
        fi
    fi

    if [ -d /var/centrifydc/upgrade ]; then
        echo "Upgrading ..." >> ${LOG_FILE}
        mkdir -p /etc/centrifydc/custom >> ${LOG_FILE}
        cp -p /var/centrifydc/upgrade/custom/* /etc/centrifydc/custom >> ${LOG_FILE}
        mkdir -p /etc/centrifydc/new >> ${LOG_FILE}
        mv -f /etc/centrifydc/centrifydc.conf /etc/centrifydc/new >> ${LOG_FILE}
        mv -f /etc/centrifydc/group.ignore /etc/centrifydc/new >> ${LOG_FILE}
        mv -f /etc/centrifydc/user.ignore /etc/centrifydc/new >> ${LOG_FILE}
        echo "merging centrifydc.conf ..." >> ${LOG_FILE}
        /usr/share/centrifydc/bin/upgradeconf -r -c /etc/centrifydc/upgradeconf.conf \
                                                 /etc/centrifydc/custom/centrifydc.conf \
                                                 /etc/centrifydc/new/centrifydc.conf \
                                                 /etc/centrifydc/centrifydc.conf \
                                                 >> ${LOG_FILE} 2>> ${LOG_FILE}

        if [ ! -s /etc/centrifydc/group.ignore ]; then
            echo "Restoring group.ignore from /etc/centrifydc/custom/ ..."  | tee -a ${LOG_FILE}
            cp -pf /etc/centrifydc/custom/group.ignore /etc/centrifydc/
        fi
        if [ ! -s /etc/centrifydc/user.ignore ]; then
            echo "Restoring user.ignore from /etc/centrifydc/custom/ ..."  | tee -a ${LOG_FILE}
            cp -pf /etc/centrifydc/custom/user.ignore /etc/centrifydc/
        fi

        echo "removing the cache ..." >> ${LOG_FILE}
        rm /var/centrifydc/*.idx >> ${LOG_FILE} 2>> ${LOG_FILE}
        rm /var/centrifydc/*.cache >> ${LOG_FILE} 2>> ${LOG_FILE}
        # flush the AIX shared library cache
        /usr/sbin/slibclean

        if [ -f /etc/centrifydc/openldap/ldap.conf.cdc_upgrade ]; then
            echo "restoring original ldap.conf ..." >> ${LOG_FILE}
            mv -f /etc/centrifydc/openldap/ldap.conf.cdc_upgrade /etc/centrifydc/openldap/ldap.conf >> ${LOG_FILE} 2>> ${LOG_FILE}
        fi

        if [ -f /var/centrifydc/upgrade/START ]; then
            echo "starting adclient ..." >> ${LOG_FILE}
            /usr/bin/startsrc -e LIBPATH=/usr/share/centrifydc/lib:/usr/share/centrifydc/kerberos/lib -s centrifydc >> ${LOG_FILE}
        fi
        rm -Rf /var/centrifydc/upgrade >> ${LOG_FILE}
        echo "... done" >> ${LOG_FILE}

        echo "Checking /etc/syslog.conf for user.debug entry" >> ${LOG_FILE}
        cat /etc/syslog.conf | grep /var/log/centrifydc.log | grep '^user.debug' >> ${LOG_FILE} 2>> ${LOG_FILE}
        if [ "$?" = "0" ]; then
            echo "turning debug off" >> ${LOG_FILE}
            /usr/share/centrifydc/bin/addebug off >> ${LOG_FILE} 2>> ${LOG_FILE}

            echo "Checking /etc/syslog.conf for user.debug entry one more time" >> ${LOG_FILE}
            cat /etc/syslog.conf | grep /var/log/centrifydc.log | grep '^user.debug' >> ${LOG_FILE} 2>> ${LOG_FILE}
            if [ "$?" = "0" ]; then
                echo "Deleting user.debug entry from /etc/syslog.conf" >> ${LOG_FILE}
                cp -p /etc/syslog.conf /etc/syslog.conf.pre_cdc_upgrade >> ${LOG_FILE} 2>> ${LOG_FILE}
                sed -e "/user.debug[ 	]*\/var\/log\/centrifydc.log/d" /etc/syslog.conf > /etc/syslog.conf.tmp_upgrade
                mv -f /etc/syslog.conf.tmp_upgrade /etc/syslog.conf >> ${LOG_FILE} 2>> ${LOG_FILE}
            fi

            echo "turning debug back on" >> ${LOG_FILE}
            /usr/share/centrifydc/bin/addebug on >> ${LOG_FILE} 2>> ${LOG_FILE}
        fi

        # configure syslog-ng.conf when the syslog-ng has been installed
        SYSLOGNG_CONF="";
        if [ -s "/etc/syslog-ng/syslog-ng.conf" ] ; then
            SYSLOGNG_CONF="/etc/syslog-ng/syslog-ng.conf"
        fi
        if [ "X${SYSLOGNG_CONF}" != "X" ]; then
           echo "Checking $SYSLOGNG_CONF for centrifydc.log" >> ${LOG_FILE}
           cat $SYSLOGNG_CONF | grep /var/log/centrifydc.log  | grep "^destination centrify"  >> ${LOG_FILE} 2>> ${LOG_FILE}
        if [ "$?" = "0" ]; then
            echo "turning debug off" >> ${LOG_FILE}
            /usr/share/centrifydc/bin/addebug off >> ${LOG_FILE} 2>> ${LOG_FILE}

            echo "Checking $SYSLOGNG_CONF for centrifydc.log one more time" >> ${LOG_FILE}
            cat $SYSLOGNG_CONF | grep /var/log/centrifydc.log  | grep "^destination centrify" >> ${LOG_FILE} 2>> ${LOG_FILE}
            if [ "$?" = "0" ]; then
                echo "Deleting centrifydc.log from $SYSLOGNG_CONF" >> ${LOG_FILE}
                cp -p $SYSLOGNG_CONF ${SYSLOGNG_CONF}.pre_cdc_upgrade >> ${LOG_FILE} 2>> ${LOG_FILE}
                sed -e "/\/var\/log\/centrifydc.log/d" -e "/f_centrify/d" $SYSLOGNG_CONF > ${SYSLOGNG_CONF}.tmp_upgrade
                mv -f ${SYSLOGNG_CONF}.tmp_upgrade ${SYSLOGNG_CONF} >> ${LOG_FILE} 2>> ${LOG_FILE}
            fi

            echo "turning debug back on" >> ${LOG_FILE}
            /usr/share/centrifydc/bin/addebug on >> ${LOG_FILE} 2>> ${LOG_FILE}
        fi       
        fi
        echo "\nWARNING:"
        echo "To complete the update of Centrify DirectControl,"
        echo "you may need to restart some services that rely upon PAM and NSS or simply"
        echo "reboot the computer for proper operation. Failure to do so may result in"
        echo "login problems for AD users.\n"
    fi

    return $TRUE
} # wpar_config

wpar_pre_d()
{
    echo "wpar_pre_d (pre-pre-deinstall): `date`" >> ${LOG_FILE}

    if test -s /var/centrifydc/kset.domain; then
        echo "\nWARNING:" | tee -a ${LOG_FILE}
        echo "Could not uninstall Centrify DirectControl. Please run 'adleave' first.\n" | tee -a ${LOG_FILE}
        do_exit ${CODE_EUN}
    fi

    if [ -f /etc/centrifydc/openldap/slapd.conf ]; then
        rm -f /etc/centrifydc/openldap/slapd.conf >> ${LOG_FILE}
    fi

    if [ -f /etc/shells ]; then
        echo removing /usr/bin/dzsh from /etc/shells ... >> ${LOG_FILE}
        cat /etc/shells | sed '/\/usr\/bin\/dzsh/d' > /etc/shells.tmp
        mv -f /etc/shells.tmp /etc/shells
        awk '/^\//{ exit 1 }' /etc/shells
        if [ $? -eq 0 ]; then
            echo "WARNING: /etc/shells is empty, all ftp access will be disabled" >> ${LOG_FILE}
        fi
    fi

    return $TRUE
} # wpar_pre_d

wpar_unpost_i()
{
    echo "wpar_unpost_i (pre-deinstall): `date`" >> ${LOG_FILE}

    if [ -f /etc/rc.tcpip ]; then
        cat /etc/rc.tcpip | grep CentrifyDC > /dev/null 2> /dev/null
        RC=$?
        if [ "${RC}" = "0" ]; then
            cp /etc/rc.tcpip /etc/rc.tcpip.cdc
            cat /etc/rc.tcpip.cdc |
                sed -e '/Start up CentrifyDC adclient/,/last CentrifyDC line/d' > /etc/rc.tcpip
        else
            echo "Info: No changes made in /etc/rc.tcpip." >> ${LOG_FILE}
        fi
    else
        echo "Warning: Could not find /etc/rc.tcpip."
    fi
 
    # remove the rotating centrify_client.log from crontab
    crontab -l |  grep -v "/usr/share/centrifydc/bin/logrotate.sh" > cron.$$
    crontab cron.$$
    rm -f cron.$$

    rmssys -s centrifydc

    if [ -f /etc/centrifydc/passwd.ovr ]; then rm -f /etc/centrifydc/passwd.ovr; fi
    if [ -f /etc/centrifydc/group.ovr ]; then rm -f /etc/centrifydc/group.ovr; fi

    return $TRUE
} # wpar_unpost_i

wpar_unpre_i()
{
    echo "wpar_unpre_i (post-deinstall): `date`" >> ${LOG_FILE}

    rm -Rf /var/centrify
    rm -Rf /var/centrifydc
    rm -Rf /etc/centrifydc

    #remove the Centrifydc debug from syslog-ng.conf
    SYSLOGNG_CONF="";
    if [ -s "/etc/syslog-ng/syslog-ng.conf" ] ; then
        SYSLOGNG_CONF="/etc/syslog-ng/syslog-ng.conf"
    fi
    if [ "X${SYSLOGNG_CONF}" != "X" ]; then
       echo Checking $SYSLOGNG_CONF for centrifydc.log >> ${LOG_FILE}
       cat $SYSLOGNG_CONF | grep /var/log/centrifydc.log  | grep "^destination centrify" >> ${LOG_FILE} 2>> ${LOG_FILE}
       if [ "$?" = "0" ]; then
          echo Deleting centrifydc.log from $SYSLOGNG_CONF >> ${LOG_FILE}
          cp -p $SYSLOGNG_CONF ${SYSLOGNG_CONF}.pre_cdc_uninstall >> ${LOG_FILE} 2>> ${LOG_FILE}
          sed -e "/\/var\/log\/centrifydc.log/d" -e "/f_centrify/d" $SYSLOGNG_CONF > ${SYSLOGNG_CONF}.tmp_uninstall
          mv -f ${SYSLOGNG_CONF}.tmp_uninstall ${SYSLOGNG_CONF} >> ${LOG_FILE} 2>> ${LOG_FILE}
       fi
    fi

    return $TRUE
} # wpar_unpre_i


### adjust list of supported add-on packages
check_exceptions ()
{
    if [ ! -f ${CFG_FNAME_SUITE} ]; then
        if [ "${TARGET_OS}" != "darwin" -a "${UNINSTALL}" != "Y" ]; then
            echo "WARNING: Could not find ${CFG_FNAME_SUITE}, skipping exception check." | tee -a ${LOG_FILE}
        fi
        return $FALSE
    else
        EXC_LIST=`cat ${CFG_FNAME_SUITE} | grep "target_os,os_rev,arch" | grep cdc-${CDC_VER}`
        EXCEPTIONS=`cat ${CFG_FNAME_SUITE} | sed  's/\#.*$//' | grep "${TARGET_OS},${OS_REV}${OS_MODE},${ARCH}" | grep cdc-${CDC_VER}`
        debug_echo EXCEPTIONS=${EXCEPTIONS}
        i=2
        ADD_ON=`echo ${EXC_LIST} | cut -d',' -f$i`
        while [ "${ADD_ON}" != "" ]
        do
            EXC_KEY=`echo ${EXCEPTIONS} | cut -d',' -f$i`   
            if [ "${EXC_KEY}" = "0" ]; then
                ADD_ON_LIST=`echo ${ADD_ON_LIST} | sed "s/${ADD_ON}//" | sed "s/  / /g"`
            fi
            i=`expr $i + 1`
            ADD_ON=`echo ${EXC_LIST} | cut -d',' -f$i`   
        done
        debug_echo "ADD_ON_LIST=${ADD_ON_LIST}"
        return $TRUE
    fi
} # check_exceptions()

### set silent mode configuration
set_silent_cfg()
{
    VAR_LIST="ADCHECK ADJOIN DOMAIN USERID PASSWD COMPUTER CONTAINER ZONE SERVER REBOOT ADLICENSE"
    for VAR3 in ${ADD_ON_LIST}; do
        if [ "${VAR3}" = "cda" ]; then
            VAR_LIST="${VAR_LIST} CentrifyDA"
        else
            VAR_LIST="${VAR_LIST} CentrifyDC_${VAR3}"
        fi
    done
    # default settings
    ADCHECK="N"
    INSTALL="U"
    # Y - (yes) install if it's not installed
    # U - same as Y plus: update if it's installed but older version; keep current if the same version is installed
    # to be implemented: R - (repair, reinstall) same as U plus: update even if the same version is installed    
    if [ "${UNINSTALL}" = "Y" ]; then
        # it's uninstall.sh or install.sh -e
        echo $ECHO_FLAG "\nINFO: Non-interactive uninstall, ignoring INSTALL and UNINSTALL settings in config file." >> ${LOG_FILE}
        INSTALL="E"
    else
        # read INSTALL and UNINSTALL from config file
        VAR_LIST="${VAR_LIST} INSTALL UNINSTALL"
    fi
    if [ "${DA_ENABLE}" = "Y" ]; then
        # DA is enabled in command line
        echo $ECHO_FLAG "\nINFO: DA is enabled in command line, ignoring DA_ENABLE setting in config file." >> ${LOG_FILE}
    else
        # read DA_ENABLE from config file
        DA_ENABLE="N"
        VAR_LIST="${VAR_LIST} DA_ENABLE"        
    fi
    case "${TARGET_OS}" in
    solaris)
        if [ "${GLOBAL_ZONE_ONLY}" != "non_global" ]; then
            # global zone
            VAR_LIST="${VAR_LIST} GLOBAL_ZONE_ONLY"
        fi
        ;;
    esac
    ADJOIN="N"
    DOMAIN=
    USERID=administrator
    PASSWD=
    COMPUTER=`hostname`
    CONTAINER=Computers
    ZONE=default
    SERVER=
    REBOOT="N"
    # override defaults with values from config file 
    if [ "${SUITE}" != "Custom" ]; then
        CFG_FNAME=${CFG_FNAME_SUITE}
    fi 
    read_cfg_file
    if [ "${SUITE}" = "Standard" ]; then
        CentrifyDC_nis="N"
        CentrifyDA="N"
    fi
    if [ "${UNINSTALL}" = "Y" ] && [ "${INSTALL}" != "E" ]; then
        echo $ECHO_FLAG "\nERROR: Variable UNINSTALL=${UNINSTALL} conflicts with INSTALL=${INSTALL}." >> ${LOG_FILE}
        echo $ECHO_FLAG   "       Please sort it out then restart installer. Exiting ... "            >> ${LOG_FILE}
        return $FALSE
    fi
    if [ -n "${ADJOIN_CMD_OPTIONS}" ]; then
        ### ignore separate adjoin variables and just use adjoin options provided with --adjoin_opt=<...>
        ADJOIN="N"
    fi
    return $TRUE
} # set_silent_cfg()

### read install setting from config file
read_cfg_file ()
{
    if [ -f ${CFG_FNAME} ]; then
        IFS_ORG="${IFS}"
        if [ "${ECHO_FLAG}" = "-e" ]; then
            # bash
            IFS=$'\012'
        else
            IFS=$"`echo $ECHO_FLAG '\012\001'`"
        fi
        for LINE in `cat ${CFG_FNAME} | sed '/\#\#\# manifest \#\#\#/,$d' | sed  's/\#.*$//' | sed '/^$/d'`
        do
            IFS=$' '
            for VAR2 in ${VAR_LIST}
            do
                case "${LINE}" in
                ${VAR2}*)
                    eval ${VAR2}=`echo ${LINE} | sed "s/${VAR2}=//"`
                    ;;
                esac
            done
            if [ "${ECHO_FLAG}" = "-e" ]; then
                # bash
                IFS=$'\012'
            else
                IFS=$"`echo $ECHO_FLAG '\012\001'`"
            fi
        done
        IFS="${IFS_ORG}"
        echo $ECHO_FLAG "\nINFO: Silent mode settings:" >> ${LOG_FILE}
        for VAR1 in ${VAR_LIST}; do
            ### translate some parameters to upper case
            TMP_VAR1=\$"${VAR1}"
            TMP_VAR2=`eval "expr \"\${TMP_VAR1}\" "`
            case "${TMP_VAR2}" in
            y | n | k | u | e | r )
                eval ${VAR1}=`echo ${TMP_VAR2} | tr abcdefghijklmnopqrstuvwxyz ABCDEFGHIJKLMNOPQRSTUVWXYZ`
                ;;
            esac
            ### dump all parameters into the log
            if [ "${VAR1}" = "PASSWD" ]; then
                echo $ECHO_FLAG "    PASSWD=********" >> ${LOG_FILE}
            else
                echo $ECHO_FLAG "    ${VAR1}=\c" >> ${LOG_FILE}
                eval echo \$$VAR1 >> ${LOG_FILE}
            fi
        done
    else
        echo $ECHO_FLAG "\nWARNING: could not find ${CFG_FNAME} config file, using defaults ..." | tee -a ${LOG_FILE}
        return $FALSE
    fi
    return $TRUE
} # read_cfg_file

### Find location of the packages
find_pkg_dir () {
    PKG_DIR="`dirname ${THIS_PRG}`/"
    debug_echo PKG_DIR=${PKG_DIR}
    ADCHECK_FNAME="${PKG_DIR}${ADCHECK_FNAME}"
    CFG_FNAME="${PKG_DIR}${CFG_FNAME}"
    
    # If user does not provide suite config file, then use default.    
    if [ -z "${CFG_FNAME_SUITE}" ]; then
        CFG_FNAME_SUITE="${PKG_DIR}${CFG_FNAME_SUITE_DEF}"            
    else 
        # If user only provides suite config file name, the use PKG_DIR as directory.    
        if [ "`basename ${CFG_FNAME_SUITE}`" = "${CFG_FNAME_SUITE}" ]; then    
            CFG_FNAME_SUITE="${PKG_DIR}${CFG_FNAME_SUITE}"
        fi
        # If user provides a path for suite config file, then use it directly.
        
        # Make sure the suite config exists.
        [ -f "${CFG_FNAME_SUITE}" ] || { echo "ERROR: ${CFG_FNAME_SUITE} was not found."; do_error $CODE_ESU; }
    fi
}

###
set_package_name ()
{
    BASE_PKG=centrifydc
    if [ "$1" = "" ]; then 
        ADD_ON_PKG1=""
    elif [ "$1" = "samba" -a "${SAMBA_VER}" != "" ]; then
        ADD_ON_PKG1="-$1-${SAMBA_VER}"
        debug_echo ADD_ON_PKG1=${ADD_ON_PKG1}
    elif [ "$1" = "cda" -o "$1" = "CentrifyDA" ]; then
        BASE_PKG=centrifyda
        ADD_ON_PKG1=""
    else 
        ADD_ON_PKG1="-$1"
    fi
    case "${TARGET_OS}" in
    linux)
        PKG_FILE=${BASE_PKG}${ADD_ON_PKG1}-${CDC_VER}-${PKG_OS_REV}-${PKG_ARCH}.rpm
        if [ "${PKG_OS_REV}" = "deb5" ]; then PKG_FILE=${BASE_PKG}${ADD_ON_PKG1}-${CDC_VER}-${PKG_OS_REV}-${PKG_ARCH}.deb; fi
        ;;
    solaris)
        if [ "$1" = "samba" ] || [ "$1" = "openssh" ]; then
            PKG_FILE=${BASE_PKG}${ADD_ON_PKG1}-${CDC_VER}-${PKG_OS_REV}-${PKG_ARCH}-local.gz
        else
            PKG_FILE=${BASE_PKG}${ADD_ON_PKG1}-${CDC_VER}-${PKG_OS_REV}-${PKG_ARCH}-local.tgz
        fi
        ;;
    hpux)
        PKG_FILE=${BASE_PKG}${ADD_ON_PKG1}-${CDC_VER}-${PKG_OS_REV}-${PKG_ARCH}.depot.gz
        ;;
    aix)
        if [ "$1" = "samba" -a "${SAMBA_PKGFILE}" = "old" ] || [ "$1" = "openssh" -a "${OPENSSH_PKGFILE}" = "old" ]; then
            PKG_FILE=${BASE_PKG}${ADD_ON_PKG1}-${CDC_VER}-${PKG_OS_REV}-${PKG_ARCH}.bff.gz
        elif [ "$1" = "openssh" ] && [ "${OS_REV}" != "aix4.3" ] && \
             [ "`compare_ver ${CDC_VER} 4.4; echo ${COMPARE}`" != "lt" ]; then
            if [ "`cat /etc/security/login.cfg | sed 's/\*.*$//' | sed 's/ //g' | grep 'auth_type=PAM_AUTH'`" != "" ]; then
                PKG_FILE=${BASE_PKG}${ADD_ON_PKG1}-${CDC_VER}-${PKG_OS_REV}-${PKG_ARCH}-pam-bff.gz
            else
                PKG_FILE=${BASE_PKG}${ADD_ON_PKG1}-${CDC_VER}-${PKG_OS_REV}-${PKG_ARCH}-lam-bff.gz
            fi
        else
            PKG_FILE=${BASE_PKG}${ADD_ON_PKG1}-${CDC_VER}-${PKG_OS_REV}-${PKG_ARCH}-bff.gz
        fi
        ;;
    darwin)
        if [ "${DARWIN_PKG_NAME}" = "old" ]; then
            PKG_FILE=${BASE_PKG}${ADD_ON_PKG1}-${CDC_VER}-mac${PKG_OS_REV}-${PKG_ARCH}.tgz
        else
            PKG_FILE=${BASE_PKG}${ADD_ON_PKG1}-${CDC_VER}-mac${PKG_OS_REV}.tgz
        fi
        ;;
    esac
    if [ "${COMPAT_LINK_LIST}" != "" ]; then
        for link in ${COMPAT_LINK_LIST}; do
            LINK_SOURCE=`echo $link | cut -d'=' -f1`
            LINK_DEST=`echo $link | cut -d'=' -f2`
            if [ "${PKG_FILE}" = "${LINK_SOURCE}" ]; then
                debug_echo "!!! found link from ${PKG_FILE} to ${LINK_DEST}"
                PKG_FILE=${LINK_DEST}
            fi
        done
    fi 
} # set_package_name()

### Check that current platform is supported
is_supported ()
{
    set_package_name $1
    LS_PKG_DIR="`ls ${PKG_DIR}`"

    ### find compatible add-on packages

    COMPAT_OS_REV="`list_compat_os_rev ${PKG_OS_REV}`"
    PKG_FILE_1=${PKG_FILE}
    PKG_FILES=""
    for i in ${PKG_OS_REV} ${COMPAT_OS_REV}; do
        if [ "${TARGET_OS}" = "darwin" ]; then
            PKG_FILE_TMP="`echo ${PKG_FILE_1} | sed "s/-mac${PKG_OS_REV}/-mac$i/"`"
        else
            PKG_FILE_TMP="`echo ${PKG_FILE_1} | sed "s/-${PKG_OS_REV}-/-$i-/"`"
        fi
        PKG_FILES="${PKG_FILES} ${PKG_FILE_TMP}"
    done
    for PKG_FILE in ${PKG_FILES} ; do

        ### check if there is an exact match
        for i in ${LS_PKG_DIR}; do
            if [ "${PKG_FILE}" = "$i" ]; then
                return $TRUE
            fi
        done

        if [ "$1" != "" ] && [ -f ${CFG_FNAME_SUITE} ]; then
        ### find any packages version other than $CDC_VER
            PKG_FILE_TMP="`echo ${PKG_FILE} | sed "s/-${CDC_VER}-/-\*-/" `"
            PKG_FILE_LS="`ls -r ${PKG_DIR}${PKG_FILE_TMP} 2>/dev/null | sed 's/\.\///'`"
            if [ "${PKG_FILE_LS}" = "" ]; then
                if [ "$1" = "samba" -o "$1" = "openssh" ]; then
                    PKG_FILE_TMP="`echo ${PKG_FILE_TMP} | sed "s/-bff/.bff/" `"
                    PKG_FILE_LS="`ls -r ${PKG_DIR}${PKG_FILE_TMP} 2>/dev/null | sed 's/\.\///'`"
                fi
            fi
            if [ "${PKG_FILE_LS}" = "" ]; then
                debug_echo "Could not find ${PKG_FILE_TMP} in local directory"
            else
                debug_echo "PKG_FILE_LS=${PKG_FILE_LS}" #####

                if [ "$1" = "cda" ]; then
                    PKG=CentrifyDA
                else
                    PKG=CentrifyDC-$1
                fi
                COMPAT_LIST=`cat ${CFG_FNAME_SUITE} | sed  's/\#.*$//' | grep core-${CDC_VER} | grep ${PKG} | grep ':+:' | sed 's/ //g'`
                if [ "${COMPAT_LIST}" != "" ]; then
                    for path_file in ${PKG_FILE_LS}; do
                        file="`basename $path_file`"
                        if [ "$1" = "cda" ]; then
                            PKG_FILE_VER=`echo $file | cut -d '-' -f2`
                        elif [ "$1" = "samba" -o "$1" = "openssh" ]; then
                            PKG_FILE_VER=`echo $file | cut -d '-' -f4`
                        else
                            PKG_FILE_VER=`echo $file | cut -d '-' -f3`
                        fi
                        for line in ${COMPAT_LIST}; do
                            COMPAT_VER_LOW=`echo $line | cut -d ':' -f5`
                            COMPAT_VER_HIGH=`echo $line | cut -d ':' -f6`
                            if [ "`compare_ver ${PKG_FILE_VER} ${COMPAT_VER_LOW}; echo ${COMPARE}`" != "lt" ] && \
                                [ "`compare_ver ${PKG_FILE_VER} ${COMPAT_VER_HIGH}; echo ${COMPARE}`" != "gt" ]; then
                                COMPAT_LINK_LIST="${COMPAT_LINK_LIST} ${PKG_FILE_1}=${file}"
                                PKG_FILE=${file}
                                debug_echo "COMPAT_LINK_LIST=${COMPAT_LINK_LIST}"
                                return $TRUE
                            fi
                        done
                    done
                else
                    debug_echo "Found unsupported: PKG_FILE_LS=${PKG_FILE_LS}"
                fi
            fi
        fi

    done
    PKG_FILE=${PKG_FILE_1}

    ### try old package name on MacOS X for backward compatibility (before universal)
    if [ "${TARGET_OS}" = "darwin" ]; then
        PKG_FILE="`echo ${PKG_FILE} | sed "s/.tgz/-${PKG_ARCH}.tgz/"`"
        debug_echo "PKG_FILE=${PKG_FILE}"
        for i in ${LS_PKG_DIR}; do
            if [ "${PKG_FILE}" = "$i" ]; then
                DARWIN_PKG_NAME=old
                return $TRUE
            fi
        done
        ### set back to the new package name if we failed to find the old one
        set_package_name
    fi
    return $FALSE
} # is_supported()

### Find add-on packages
find_supported_addon ()
{
    FOUND_S=$FALSE
    for ADD_ON_PKG2 in ${ADD_ON_LIST}; do
        is_supported ${ADD_ON_PKG2}
        RC=$?
        if [ "$RC" = "0" ]; then
            if [ "${ADD_ON_PKG2}" = "cda" ]; then
                echo INFO: CentrifyDA is supported >> ${LOG_FILE}
            else
                echo INFO: CentrifyDC${SEP}${ADD_ON_PKG2} is supported >> ${LOG_FILE}
            fi
            eval ${ADD_ON_PKG2}=S
            FOUND_S=$TRUE
            debug_echo "${ADD_ON_PKG2}=\c"
            eval echo \$$ADD_ON_PKG2 >> ${DEBUG_OUT}
        fi
    done
    set_package_name
    return ${FOUND_S}
}

### Find installed add-on packages
is_addon_installed ()
{
    ADD_ON_INSTALLED=
    for ADD_ON_PKG3 in ${ADD_ON_LIST}; do
        is_installed ${ADD_ON_PKG3}
        RC=$?
        if [ "$RC" = "0" ]; then
            FIELD=3 # version field in the package file-name
            if [ "${ADD_ON_PKG3}" = "openssh" -o "${ADD_ON_PKG3}" = "samba" ]; then FIELD=4; fi
            if [ "${ADD_ON_PKG3}" = "cda" ]; then
                FIELD=2
                echo INFO: CentrifyDA-${INSTALLED_VER} is installed >> ${LOG_FILE}
                echo checking DirectAudit status ... >> ${LOG_FILE}
                /usr/sbin/dacontrol | head -1 | grep NOT >> /dev/null 2>> /dev/null
                if [ $? -eq 0 ]; then
                    echo DirectAudit is not enabled >> ${LOG_FILE}
                else
                    echo DirectAudit is enabled >> ${LOG_FILE}
                    DA_ENABLE="enabled"
                fi
            else
                echo INFO: CentrifyDC${SEP}${ADD_ON_PKG3}-${INSTALLED_VER} is installed >> ${LOG_FILE}
            fi
            VAR1=\$"${ADD_ON_PKG3}"
            VAR2=`eval "expr \"\${VAR1}\" "`
            if [ "${VAR2}" = "S" ]; then
                # check if installed and supported versions of add-on package are the same
                set_package_name ${ADD_ON_PKG3}
                SUPPORTED_VER=`echo ${PKG_FILE} | cut -d '-' -f${FIELD}`
                debug_echo "SUPPORTED_VER=${SUPPORTED_VER}"
                if [ "`compare_ver ${SUPPORTED_VER} ${INSTALLED_VER}; echo ${COMPARE}`" = "gt" ]; then
                    eval ${ADD_ON_PKG3}=\$$ADD_ON_PKG3+I # supported is newer than installed
                else
                    eval ${ADD_ON_PKG3}=\$$ADD_ON_PKG3=I # supported is same or older than installed
                fi
            else
                eval ${ADD_ON_PKG3}=I
            fi
            if [ "${ADD_ON_PKG3}" = "cda" ]; then
                ADD_ON_INSTALLED="${ADD_ON_INSTALLED} CentrifyDA-${INSTALLED_VER}"
            else
                ADD_ON_INSTALLED="${ADD_ON_INSTALLED} CentrifyDC${SEP}${ADD_ON_PKG3}-${INSTALLED_VER}"
            fi
            debug_echo "${ADD_ON_PKG3}=\c"
            eval echo \$$ADD_ON_PKG3 >> ${DEBUG_OUT}
        fi
    done
    if [ "${TARGET_OS}" = "linux" -a "${PKG_OS_REV}" = "deb5" ]; then
        ADD_ON_INSTALLED="`echo ${ADD_ON_INSTALLED} | sed 's/CentrifyDC/centrifydc/g' | sed 's/CentrifyDA/centrifyda/g'`"
    elif [ "${TARGET_OS}" = "aix" -a "${OPENSSH_OLD}" = "Y" ]; then
        ADD_ON_INSTALLED="`echo ${ADD_ON_INSTALLED} | sed 's/CentrifyDC\.openssh/CentrifyDC-openssh\.base/g'`"
        debug_echo "ADD_ON_INSTALLED=${ADD_ON_INSTALLED}"
    fi
    set_package_name
    if [ "${ADD_ON_INSTALLED}" = "" ]; then
        return $FALSE
    else
        return $TRUE
    fi
} # is_addon_installed()

### Check if CentrifyDC (or add-on) is installed already
is_installed ()
{
    BASE_PKG=CentrifyDC
    if [ "$1" = "" ]; then 
        echo $ECHO_FLAG "\ninstall-express.sh: is_installed: " >> ${LOG_FILE}
        ADD_ON_PKG4=""
    elif [ "$1" = "cda" ]; then
        BASE_PKG=CentrifyDA
        ADD_ON_PKG4=""
    else
        ADD_ON_PKG4="-$1"
    fi
    case "${TARGET_OS}" in
    linux)
        if [ "${PKG_OS_REV}" = "deb5" ]; then
            BASE_PKG=`echo ${BASE_PKG} | tr  ABCDEFGHIJKLMNOPQRSTUVWXYZ abcdefghijklmnopqrstuvwxyz`
            dpkg -s ${BASE_PKG}${ADD_ON_PKG4} 2> /dev/null | grep Status: | grep installed | grep -v not-installed >> ${LOG_FILE} \
                    && { INSTALLED="Y"; } || { INSTALLED="N"; }
        else
            rpm -q ${BASE_PKG}${ADD_ON_PKG4} >> ${LOG_FILE} 2> /dev/null \
                    && { INSTALLED="Y"; } || { INSTALLED="N"; }
        fi;;
    solaris)
        pkginfo -l ${BASE_PKG}${ADD_ON_PKG4} >> ${LOG_FILE} 2> /dev/null \
                && { INSTALLED="Y"; } || { INSTALLED="N"; } 
        ;;
    hpux)
        /usr/sbin/swlist -a revision ${BASE_PKG}${ADD_ON_PKG4} >> ${LOG_FILE} 2> /dev/null \
                && { INSTALLED="Y"; } || { INSTALLED="N"; } 
        ;;
    aix)
        if [ "$1" = "" -o "$1" = "cda" ]; then ADD_ON_PKG4=".core"; else ADD_ON_PKG4=".$1"; fi
        lslpp -l ${BASE_PKG}${ADD_ON_PKG4} >> ${LOG_FILE} 2> /dev/null \
                && { INSTALLED="Y"; } || { INSTALLED="N"; } 
        if [ "$1" = "openssh" -a "${INSTALLED}" = "N" ]; then # try to find old cdc-openss package
            lslpp -l CentrifyDC-openssh.base >> ${LOG_FILE} 2> /dev/null \
                    && { INSTALLED="Y"; OPENSSH_OLD="Y"; } || { INSTALLED="N"; }
        fi
        ;;
    darwin)
        if [ "$1" = "" ]; then
            if [ -x /usr/bin/adinfo -a -x /usr/sbin/adjoin ]; then INSTALLED="Y"; else INSTALLED="N"; fi
        elif [ "$1" = "krb5" ]; then
            if [ "`ls /usr/share/centrifydc/centrifydc-$1-*.tgz.lst 2> /dev/null | wc -w | sed 's/^[ ^t]*//'`" != "0" ] || \
               [ -x /usr/share/centrifydc/kerberos/bin/ftp -a -x /usr/share/centrifydc/kerberos/sbin/ftpd ]; then INSTALLED="Y"; else INSTALLED="N"; fi
        elif [ "$1" = "ldapproxy" ]; then
            if [ "`ls /usr/share/centrifydc/centrifydc-$1-*.tgz.lst 2> /dev/null | wc -w | sed 's/^[ ^t]*//'`" != "0" ] || \
               [ -x /usr/share/centrifydc/libexec/slapd -a -f /usr/share/centrifydc/etc/openldap/ldapproxy.slapd.conf ]; then INSTALLED="Y"; else INSTALLED="N"; fi
        elif [ "$1" = "adfixid" ]; then
            if [ "`ls /usr/share/centrifydc/centrifydc-$1-*.tgz.lst 2> /dev/null | wc -w | sed 's/^[ ^t]*//'`" != "0" ]; then
                INSTALLED="Y"; else INSTALLED="N"; fi
        elif [ "$1" = "utest" ]; then
            if [ "`ls /usr/share/centrifydc/centrifydc-$1-*.tgz.lst 2> /dev/null | wc -w | sed 's/^[ ^t]*//'`" != "0" ] || \
               [ "`ls /usr/share/centrifydc/tests/bin/ 2> /dev/null | wc -w | sed 's/^[ ^t]*//'`" != "0" ]; then INSTALLED="Y"; else INSTALLED="N"; fi
        elif [ "$1" = "cda" ]; then
            # CDA is not supported on Mac OS
            INSTALLED="N"
        else
            INSTALLED="N"
        fi
        ;;
    esac
    if [ "${INSTALLED}" = "Y" ]; then
        get_cur_version $1
        if [ "$1" = "" ]; then
            # Check licensed mode
            if [ "`compare_ver ${CUR_VER} 4.4; echo ${COMPARE}`" = "lt" ]; then
                ADLICENSE="Y"
            else
                if [ -x /usr/bin/adlicense ]; then
                    /usr/bin/adlicense | grep licensed > /dev/null 2> /dev/null
                    if [ $? -eq 0 ]; then
                        ADLICENSE="Y"
                    else
                        ADLICENSE="N"
                        echo $ECHO_FLAG "\ninstall.sh: Upgrading Express, license=N" >> ${LOG_FILE}
                    fi
                else
                    # Express mode is not supported
                    ADLICENSE="Y"
                fi
            fi
            # Check if already joined
            if [ -s ${VAR}/centrifydc/kset.domain ]; then
                ADJOINED="Y"
            fi
        fi
        return $TRUE
    else
        return $FALSE
    fi
} # is_installed()

### Detect version of the currently installed package (detect_version() replacement)
get_cur_version ()
{
    echo $ECHO_FLAG "\ninstall-express.sh: get_cur_version: " >> ${LOG_FILE}
    INSTALLED_VER="0.0.0-000" # unknown version
    BASE_PKG=CentrifyDC
    FIELD="2-3"
    if [ "$1" = "" ]; then
        ADD_ON_PKG9=""
    elif [ "$1" = "cda" ]; then
        BASE_PKG=CentrifyDA
        ADD_ON_PKG9=""
    elif [ "$1" = "samba" -o "$1" = "openssh" ]; then
        ADD_ON_PKG9="-$1"
        FIELD="4-5"
    else
        ADD_ON_PKG9="-$1"
        FIELD="3-4"
    fi
    case "${TARGET_OS}" in
    linux)
        if [ "${PKG_OS_REV}" = "deb5" ]; then
            BASE_PKG=`echo ${BASE_PKG} | tr  ABCDEFGHIJKLMNOPQRSTUVWXYZ abcdefghijklmnopqrstuvwxyz`
            INSTALLED_VER=`dpkg -s ${BASE_PKG}${ADD_ON_PKG9} 2> /dev/null | grep Version | cut -d ' ' -f2`
        else
            INSTALLED_VER=`rpm -q ${BASE_PKG}${ADD_ON_PKG9} 2> /dev/null | sed "s/${BASE_PKG}${ADD_ON_PKG9}-//"`
        fi
        if [ "$FIELD" = "4-5" ]; then
            # <upstream-ver>-<cdc-ver>.<build> or
            # <upstream-ver>-<cdc-ver>-<build>
            INSTALLED_VER=`echo ${INSTALLED_VER} | sed -e 's/^[^-]*-//' -e 's/^\([0-9]*\.[0-9]*\.[0-9]*\)\./\1-/'`
        fi
        ;;
    solaris)
        INSTALLED_VER=`pkginfo -l ${BASE_PKG}${ADD_ON_PKG9} 2> /dev/null | grep VERSION | cut -d ' ' -f6`
        if [ "$FIELD" = "4-5" ]; then
            if echo "$INSTALLED_VER" | grep "-" > /dev/null 2>&1 ; then
                INSTALLED_VER=`echo ${INSTALLED_VER} | sed 's/^[^-]*-//'`
            elif [ "$1" = "openssh" ]; then
                # Openssh version number does not contain CDC version
                # Run ssh command to get the installed version
                INSTALLED_VER=`/usr/share/centrifydc/bin/ssh -V 2>&1 | sed 's/.*build \([0-9\.-]*\).*/\1/'`
            fi
        fi 
        ;;
    hpux)
        INSTALLED_VER=`/usr/sbin/swlist -a revision ${BASE_PKG}${ADD_ON_PKG9} 2> /dev/null | grep "# ${BASE_PKG}" | sed "s/[[:space:]]\{1,\}/ /g" | cut -d ' ' -f3`
        if [ "$FIELD" = "4-5" ]; then
            # <upstream-ver>-<cdc-ver>.<build> or
            # <upstream-ver>-<cdc-ver>-<build>
            INSTALLED_VER=`echo ${INSTALLED_VER} | sed -e 's/^[^-]*-//' -e 's/^\([0-9]*\.[0-9]*\.[0-9]*\)\./\1-/'`           
        fi
        ;;
    aix)
        if [ "$1" = "" -o "$1" = "cda" ]; then ADD_ON_PKG9=".core"; else ADD_ON_PKG9=".$1"; fi
        INSTALLED_VER=`lslpp -l ${BASE_PKG}${ADD_ON_PKG9} 2> /dev/null | grep ${BASE_PKG} | \
                                     sed s/${BASE_PKG}${ADD_ON_PKG9}// | sed s/" "//g | sed s/COMMITTED/F/ | cut -d 'F' -f1`
        if [ "$FIELD" = "4-5" ]; then
            # <upstream-ver-major>.<upstream-ver-minor>.<cdc-short-ver>.<build>
            INSTALLED_BUILD=`echo ${INSTALLED_VER} | cut -d '.' -f4`
            INSTALLED_VER=`echo ${INSTALLED_VER} | cut -d '.' -f3 | sed 's/\([0-9]\)/\1./g' | sed "s/\.\$/.${INSTALLED_BUILD}/"`
        fi
        INSTALLED_VER=`echo ${INSTALLED_VER} | sed 's/\.\([0-9]*\)$/-\1/'`
        ;;
    darwin)
        BASE_PKG=`echo ${BASE_PKG} | tr  ABCDEFGHIJKLMNOPQRSTUVWXYZ abcdefghijklmnopqrstuvwxyz`
        if [ "`ls /usr/share/centrifydc/${BASE_PKG}${ADD_ON_PKG9}-*.tgz.lst 2> /dev/null | wc -w | sed 's/^[ ^t]*//'`" = "1" ]; then
            FULL_LST_FILE_NAME=`ls /usr/share/centrifydc/${BASE_PKG}${ADD_ON_PKG9}-*.tgz.lst`
            LST_FILE_NAME=`basename ${FULL_LST_FILE_NAME}`
            INSTALLED_VER=`echo ${LST_FILE_NAME} | cut -d '-' -f${FIELD}`
        elif [ "$1" = "" ]; then
            echo $ECHO_FLAG "WARNING: using adinfo -v to get current version ... " >> ${LOG_FILE}
            INSTALLED_VER=`/usr/bin/adinfo -v | cut -d ' ' -f 3 | sed 's/)//'`
        else
            echo $ECHO_FLAG "WARNING: cannot get <${ADD_ON_PKG9}> package version ... " >> ${LOG_FILE}
            return $FALSE
        fi
        ;;
    esac
    # cut off build bumber
    INSTALLED_VER=`echo ${INSTALLED_VER} | cut -d '-' -f1`
    # to be backward compatible with detect_version()
    if [ "$1" = "" ]; then
        CUR_VER=${INSTALLED_VER}
        echo $ECHO_FLAG "INFO: CUR_VER=${CUR_VER}" >> ${LOG_FILE}
    elif [ "$1" = "cda" ]; then
        CDA_CUR_VER=${INSTALLED_VER}
        echo $ECHO_FLAG "INFO: CDA_CUR_VER=${CDA_CUR_VER}" >> ${LOG_FILE}
    fi
    return $TRUE
} # get_cur_version()

### find Perl
is_perl_installed () 
{
    echo $ECHO_FLAG "\ninstall-express.sh: is_perl_installed: " >> ${LOG_FILE}
    echo "looking for Perl ..." >> ${LOG_FILE}
    PERL_DIRS="/bin /usr/bin /usr/local/bin /opt/bin /opt/perl/bin /opt/perl5/bin"
    for dir in `(IFS=:; set -- $PATH; echo "$@")` ${PERL_DIRS}
    do
        # If this file is a plain executable, we found it.
        if [ -x "$dir/perl" -a -f "$dir/perl" ]; then
            # Some systems have a broken perl earlier in the path;
            # test this one to make sure it works.
            if "$dir/perl" -e 'use strict;' > /dev/null 2>&1; then
                perl="$dir/perl"
                echo "found Perl: ${perl}" >> ${LOG_FILE}
                break
	    fi
        fi
    done

    if [ "$perl" = "" ]; then
        echo $ECHO_FLAG "\nWARNING:" | tee -a ${LOG_FILE}
        echo $ECHO_FLAG "Could not find Perl required by Group Policy (GP) functionality.\n" | tee -a ${LOG_FILE}
        return ${FALSE}
    fi
}

### disable GP in centrifydc.conf
disable_GP ()
{
    echo $ECHO_FLAG "\nWARNING: disabling GP in /etc/centrifydc/centrifydc.conf" >> ${LOG_FILE}
    cp -p /etc/centrifydc/centrifydc.conf /etc/centrifydc/centrifydc.conf.tmp
    sed -e "s/[# ]gp.disable.all: true/gp.disable.all: true/" \
        /etc/centrifydc/centrifydc.conf.tmp > /etc/centrifydc/centrifydc.conf
    echo $ECHO_FLAG "WARNING:" | tee -a ${LOG_FILE}
    echo $ECHO_FLAG "Group Policy (GP) functionality has been disabled.\n" | tee -a ${LOG_FILE}
    return ${TRUE}
}

### update keytab file
update_keytab ()
{
    
    # Update keytab if adclient is in connected status
    echo $ECHO_FLAG "start to update keytab ..." >> ${LOG_FILE}
    ADCLIENT_MODE=""
    for i in 1 2 3 4
    do
        ADCLIENT_MODE="`/usr/bin/adinfo -m`"
        if [ "X${ADCLIENT_MODE}" = "Xstarting" -o "X${ADCLIENT_MODE}" = "X<unavailable>" ]; then
            echo $ECHO_FLAG "Adclient is ${ADCLIENT_MODE}. Wait for $i second(s)." >> ${LOG_FILE}
            sleep $i
        else
            break
        fi
    done

    if [ "X${ADCLIENT_MODE}" = "Xconnected" ]; then
        echo $ECHO_FLAG "updating keytab ..." >> ${LOG_FILE}
        /usr/sbin/adkeytab -C -m >> ${LOG_FILE} 2>> ${LOG_FILE}
    else
        echo $ECHO_FLAG "skip to update keytab. Adclient is ${ADCLIENT_MODE}." >> ${LOG_FILE}
    fi

    if [ $? -eq 0 ]; then
        return ${TRUE}
    fi
    
    debug_echo "Updating keytab failed. Checking ${LOG_FILE} to get detail error."
    return ${FALSE}
}

### find adcheck utility
search_adcheck ()
{
    echo $ECHO_FLAG "\ninstall-express.sh: search_adcheck: " >> ${LOG_FILE}
    debug_echo "ADCHECK_FNAME=${ADCHECK_FNAME}"
    if [ -x "${ADCHECK_FNAME}" ]; then
        echo "... found" >> ${LOG_FILE}
    else
        if [ -f "${ADCHECK_FNAME}" ]; then
            echo $ECHO_FLAG "\nFound ${ADCHECK_FNAME} but it's not executable." | tee -a ${LOG_FILE}
        else
            echo $ECHO_FLAG "\nCould not find ${ADCHECK_FNAME} utility in local directory." | tee -a ${LOG_FILE}
        fi
        if [ "${SILENT}" = "NO" -a "${OS_CHECK}" != "skip" ]; then
            QUESTION="\nDo you want to continue installation? (Q|Y|N) [Y]:\c"; do_ask_YorN
            if [ ${ANSWER} != "Y" ]; then do_quit; fi
        fi
        ADCHECK_FNAME=""
        return ${FALSE}
    fi
    return ${TRUE}
}

### run adcheck utility
run_adcheck ()
{
    echo $ECHO_FLAG "\nRunning ${ADCHECK_FNAME} ..." | tee -a ${LOG_FILE}
    if [ "$1" = "" ]; then
        ${ADCHECK_FNAME} "patch.test" -t os -t net; ADCHECK_RC=$?
    else
        ${ADCHECK_FNAME} $1 -t ad; ADCHECK_RC=$?
    fi
    if [ "${ADCHECK_RC}" = "0" ]; then
        return ${TRUE}
    elif [ "${ADCHECK_RC}" = "1" -o "${ADCHECK_RC}" = "2" ]; then
        echo $ECHO_FLAG "\nWARNING: adcheck exited with warning(s)." | tee -a ${LOG_FILE}
        return ${TRUE}
    else
        echo $ECHO_FLAG "\nWARNING: adcheck exited with error(s)." | tee -a ${LOG_FILE}
        return ${FALSE}
    fi
}

### ask "YES or NO" QUESTION and read the ANSWER
do_ask_YorN () 
{
    ANSWER=""
    while [ "${ANSWER}" != "Y" -a "${ANSWER}" != "y" -a "${ANSWER}" != "N" -a "${ANSWER}" != "n" ]
    do
        echo ${ECHO_FLAG} "${QUESTION}"
        read ANSWER
        if [ "${ANSWER}" = "q" -o "${ANSWER}" = "Q" ]; then do_quit; fi
        if [ "$1" = "N" ]; then # default answer "N"
            if [ "${ANSWER}" = "" -o "${ANSWER}" = "n" ]; then ANSWER="N"; fi
            if [ "${ANSWER}" = "y" ]; then ANSWER="Y"; fi
        else
            if [ "${ANSWER}" = "" -o "${ANSWER}" = "y" ]; then ANSWER="Y"; fi
            if [ "${ANSWER}" = "n" ]; then ANSWER="N"; fi
        fi
        if [ "$2" = "C" ] && [ "${ANSWER}" = "c" -o "${ANSWER}" = "C" ]; then ANSWER="Y"; fi
    done
}

### ask about already installed package with available upgrade
do_ask_EorUorK ()
{
            QUESTION="\n${1}${2} is installed. Do you want to erase it (E), \nupdate (U) to ${3} or keep (K) current ${1} package? (Q|E|U|K) [K]:\c"
            ANSWER=""
            while [ "${ANSWER}" != "E" -a "${ANSWER}" != "U" -a "${ANSWER}" != "K" ]
            do
                echo ${ECHO_FLAG} ${QUESTION}
                read ANSWER
                if [ "${ANSWER}" = "q" -o "${ANSWER}" = "Q" ]; then do_quit; fi
                if [ "${ANSWER}" = "e" -o "${ANSWER}" = "E" ]; then
                    if [ "${1}" = "CentrifyDC" ]; then
                        UNINSTALL="Y"
                        do_remove_main
                        # do_remove_main() never returns
                    else
                        ANSWER="E"
                    fi
                fi
                if [ "${ANSWER}" = "u" ]; then ANSWER="U"; fi
                if [ "${ANSWER}" = "" -o "${ANSWER}" = "k" ]; then ANSWER="K"; fi
            done
}

### ask about already installed package with available reinstall
do_ask_EorRorK ()
{
            QUESTION="\n${1}${2} is already installed. Do you want to erase it (E), \nreinstall (R) ${3} or keep (K) current ${1} package? (Q|E|R|K) [K]:\c"
            ANSWER=""
            while [ "${ANSWER}" != "E" -a "${ANSWER}" != "R" -a "${ANSWER}" != "K" ]
            do
                echo ${ECHO_FLAG} ${QUESTION}
                read ANSWER
                if [ "${ANSWER}" = "q" -o "${ANSWER}" = "Q" ]; then do_quit; fi
                if [ "${ANSWER}" = "e" -o "${ANSWER}" = "E" ]; then
                    if [ "${1}" = "CentrifyDC" ]; then
                        UNINSTALL="Y"
                        do_remove_main
                        # do_remove_main() never returns
                    else
                        ANSWER="E"
                    fi
                fi
                if [ "${ANSWER}" = "r" ]; then ANSWER="R"; fi
                if [ "${ANSWER}" = "" -o "${ANSWER}" = "k" ]; then ANSWER="K"; fi
            done
}

### ask about already installed package (no upgrade)
do_ask_EorK ()
{
            QUESTION="\n${1}${2} is installed. Do you want to erase it (E) or keep (K)\n current ${1} package? (Q|E|K) [K]:\c"
            ANSWER=""
            while [ "${ANSWER}" != "E" -a "${ANSWER}" != "K" ]
            do
                echo ${ECHO_FLAG} ${QUESTION}
                read ANSWER
                if [ "${ANSWER}" = "q" -o "${ANSWER}" = "Q" ]; then do_quit; fi
                if [ "${ANSWER}" = "e" -o "${ANSWER}" = "E" ]; then
                    if [ "${1}" = "CentrifyDC" ]; then
                        UNINSTALL="Y"
                        do_remove_main
                        # do_remove_main() never returns
                    else
                        ANSWER="E"
                    fi
                fi
                if [ "${ANSWER}" = "" -o "${ANSWER}" = "k" ]; then ANSWER="K"; fi
            done
}

### ask the QUESTION and read the ANSWER (accept empty input)
do_ask () 
{
    ANSWER=""
    echo ${ECHO_FLAG} "${QUESTION}"
    read ANSWER
    if [ "${ANSWER}" = "q" -o "${ANSWER}" = "Q" ]; then do_quit; fi
}

### Suite prompt
do_suite_prompt ()
{
    echo $ECHO_FLAG "\ninstall-express.sh: do_suite_prompt: " >> ${LOG_FILE}

    echo ""
    echo "With this script, you can perform the following tasks:"
    if [ -f ${CFG_FNAME_SUITE} -a "${SUPPORTED}" = "Y" ] && \
       [ "${INSTALLED}" != "Y" -o "`compare_ver ${CDC_VER} ${CUR_VER}; echo ${COMPARE}`" = "gt" ]; then
        SUITE=""
        QUESTION="How do you want to proceed? ("; QUESTION_SEP=""
        QUESTION_DEFAULT="S"
        if [ "${ENTERPRISE_PL}" -eq $TRUE ]; then
            QUESTION="${QUESTION}${QUESTION_SEP}E"; QUESTION_SEP="|"
            echo "    - Install (update) Centrify Suite Enterprise Edition (License required) [E]"
            QUESTION_DEFAULT="E"
        fi
        QUESTION="${QUESTION}${QUESTION_SEP}S"; QUESTION_SEP="|"
        echo "    - Install (update) Centrify Suite Standard Edition (License required) [S]"

        if [ "${EXPRESS_PL}" -eq $TRUE ]; then
            QUESTION="${QUESTION}${QUESTION_SEP}X"; QUESTION_SEP="|"
            echo "    - Install (update) Centrify Suite Express Edition [X]"
	   QUESTION_DEFAULT="X"
        fi
        QUESTION="${QUESTION}${QUESTION_SEP}C"; QUESTION_SEP="|"
        echo "    - Custom install (update) of individual packages [C]"
        if [ "${INSTALLED}" = "Y" ]; then
            QUESTION="${QUESTION}${QUESTION_SEP}U"; QUESTION_SEP="|"
            echo "    - Uninstall of all Centrify packages [U]"
        fi
        QUESTION="${QUESTION}${QUESTION_SEP}Q) [${QUESTION_DEFAULT}]: \c"
    else
        SUITE="Custom"
        echo "    - Install, update or remove the Centrify DirectControl packages"
        echo "    - Check OS, network and Active Directory configuration"
        echo "    - Join an Active Directory domain"
        echo "    - Restart the local computer after installation"
        QUESTION=""
    fi

    echo ""
    echo "You can type Q at any prompt to quit the installation and exit"
    echo "the script without making any changes to your environment."
    echo ""

    if [ "${FORCE_DA_GLOBAL}" != "Y" ]; then
        show_installed
    fi
    if [ "${SUITE}" != "Custom" ]; then
        CONTINUE="N"
        while [ "${CONTINUE}" = "N" ]; do
            do_ask
            ANSWER=`echo ${ANSWER} | tr abcdefghijklmnopqrstuvwxyz ABCDEFGHIJKLMNOPQRSTUVWXYZ`
            if [ "${ANSWER}" = "" ]; then
                ANSWER="${QUESTION_DEFAULT}"
            fi
            if [ "${ANSWER}" = "E" -a "${ENTERPRISE_PL}" -eq $TRUE ]; then
                SUITE="Enterprise"
                EXPRESS="N"
                set_silent_cfg
                CONTINUE="Y"
            elif [ "${ANSWER}" = "S" ]; then
                SUITE="Standard"
                EXPRESS="N"
                set_silent_cfg
                CONTINUE="Y"
            elif [ "${ANSWER}" = "X" -a "${EXPRESS_PL}" -eq $TRUE ]; then
                SUITE="Standard"
                EXPRESS="Y"
                set_silent_cfg
                CONTINUE="Y"
            elif [ "${ANSWER}" = "C" ]; then
                SUITE="Custom"
                CONTINUE=""
            elif [ "${ANSWER}" = "U" -a "${INSTALLED}" = "Y" ]; then
                UNINSTALL="Y"
                do_remove_main
                # do_remove_main() never returns
            else
                echo "Unexpected input ..."
            fi
        done
        CONTINUE="N"
    fi
    return $TRUE
} # do_suite_prompt()

### Prompt user for relevant information
do_prompt ()
{
    echo $ECHO_FLAG "\ninstall-express.sh: do_prompt: " >> ${LOG_FILE}

    # INSTALL
    while [ "${INSTALL}" != "Y" ]; do
        if [ "${INSTALLED}" = "Y" ]; then
            if [ "${FORCE_DA_GLOBAL}" = "Y" ]; then
                INSTALL="K"
                break
            else
                if [ "${SUPPORTED}" = "Y" -a "`compare_ver ${CDC_VER} ${CUR_VER}; echo ${COMPARE}`" = "gt" ]; then
                    do_ask_EorUorK CentrifyDC -${CUR_VER} ${CDC_VER}
                elif [ "${SUPPORTED}" = "Y" ]; then
                    do_ask_EorRorK CentrifyDC -${CUR_VER} ${CDC_VER}
                else
                    do_ask_EorK CentrifyDC -${CUR_VER}
                fi
                if [ ${ANSWER} = "U" ]; then
                    INSTALL="U"
                    break
                elif [ ${ANSWER} = "R" ]; then
                    INSTALL="R"
                    if [ "${TARGET_OS}" = "aix" ]; then
                        FORCE_OPTION="-F" # Force reinstall
                    fi
                    break
                else
                    INSTALL="K"
                    break
                fi
            fi
        else
            QUESTION="\nInstall the Centrify DirectControl ${CDC_VER} package? (Q|Y|N) [Y]:\c"; do_ask_YorN
            if [ ${ANSWER} = "Y" ]; then
                INSTALL="Y"
            else
                QUESTION="Do you want to exit the installation? (Q|Y|N) [Y]:\c"; do_ask_YorN
                if [ ${ANSWER} = "Y" ]; then
                    do_quit
                else
                    echo Centrify DirectControl agent is not installed. Please install it first.
                    ANSWER=""
                fi
            fi
        fi
    done

    # bail on mac if asked to install/upgrade 3.x or earlier
    min_version_required || { echo $ECHO_FLAG "\nERROR: This version of install-express.sh cannot be used with CentrifyDC $CDC_VER"; do_error; }

    if [ "${INSTALL}" = "Y" -o "${INSTALL}" = "U" -o "${INSTALL}" = "R" ]; then
        PKG_FILE_LIST=${PKG_DIR}${PKG_FILE}
        PKG_I_LIST="CentrifyDC"
        if [ "${TARGET_OS}" = "aix" ]; then PKG_I_LIST="CentrifyDC.core"; fi
    fi
    # ADD ON PACKAGES
    for ADD_ON_PKG5 in ${ADD_ON_LIST}; do
        if [ "${TARGET_OS}" = "aix" -a "${ADD_ON_PKG5}" = "cda" ]; then
            ADD_ON_PKG_FULL="CentrifyDA.core"
            FIELD=2
            CUR_ADD_ON_VER=${CDA_CUR_VER}
        elif [ "${ADD_ON_PKG5}" = "cda" ]; then
            ADD_ON_PKG_FULL="CentrifyDA"
            FIELD=2
            CUR_ADD_ON_VER=${CDA_CUR_VER}
        else
            FIELD=3 # version field in the package file-name
            if [ "${ADD_ON_PKG5}" = "openssh" -o "${ADD_ON_PKG5}" = "samba" ]; then FIELD=4; fi
            ADD_ON_PKG_FULL="CentrifyDC${SEP}${ADD_ON_PKG5}"
            # find currently installed add-on package version
            for ADD_ON_PKG10 in ${ADD_ON_INSTALLED}; do
                CUR_ADD_ON_VER=""
                ADD_ON_PKG10=`echo ${ADD_ON_PKG10} | sed "s/DC\./DC-/"`
                if [ `echo ${ADD_ON_PKG10} | cut -d '-' -f2` = "${ADD_ON_PKG5}" ]; then
                    CUR_ADD_ON_VER=`echo ${ADD_ON_PKG10} | cut -d '-' -f3`     # x.x.x
                    #CUR_ADD_ON_VER=`echo ${ADD_ON_PKG10} | cut -d '-' -f3-4`   # x.x.x-xxx
                    break
                fi
            done
        fi
        set_package_name ${ADD_ON_PKG5}
        ADD_ON_VER=`echo ${PKG_FILE} | cut -d '-' -f${FIELD}`

        VAR1=\$"${ADD_ON_PKG5}"
        VAR2=`eval "expr \"\${VAR1}\" "`

        if [ "${VAR2}" = "S" ]; then # supported, not installed
            if [ "${ADD_ON_PKG5}" = "cda" ]; then
                QUESTION="\nInstall the Centrify DirectAudit ${ADD_ON_VER} package? (Q|Y|N) [Y]:\c"; do_ask_YorN
            else
                QUESTION="\nInstall the CentrifyDC-${ADD_ON_PKG5} ${ADD_ON_VER} package? (Q|Y|N) [Y]:\c"; do_ask_YorN
            fi
            if [ "${ANSWER}" = "Y" ]; then
                eval ${ADD_ON_PKG5}=\$$ADD_ON_PKG5+Y
                PKG_FILE_LIST="${PKG_FILE_LIST} ${PKG_DIR}${PKG_FILE}"
                PKG_I_LIST="${PKG_I_LIST} ${ADD_ON_PKG_FULL}"
            else
                eval ${ADD_ON_PKG5}=\$$ADD_ON_PKG5+N
            fi
        elif [ "${VAR2}" = "S+I" ]; then # supported and installed (different versions)
            if [ "${ADD_ON_PKG5}" = "cda" ]; then
                do_ask_EorUorK CentrifyDA -${CUR_ADD_ON_VER} ${ADD_ON_VER}
            else
                do_ask_EorUorK CentrifyDC-${ADD_ON_PKG5} -${CUR_ADD_ON_VER} ${ADD_ON_VER}
            fi
            if [ "${ANSWER}" = "U" ]; then
                eval ${ADD_ON_PKG5}=\$$ADD_ON_PKG5+U
                PKG_FILE_LIST="${PKG_FILE_LIST} ${PKG_DIR}${PKG_FILE}"
                PKG_I_LIST="${PKG_I_LIST} ${ADD_ON_PKG_FULL}"
            elif [ "${ANSWER}" = "E" ]; then
                eval ${ADD_ON_PKG5}=\$$ADD_ON_PKG5+E
                if [ "${TARGET_OS}" = "aix" -a "${ADD_ON_PKG5}" = "openssh" -a "${OPENSSH_OLD}" = "Y" ]; then
                    ADD_ON_PKG_FULL="CentrifyDC-openssh.base"
                fi
                PKG_E_LIST="${PKG_E_LIST} ${ADD_ON_PKG_FULL}"
            else
                eval ${ADD_ON_PKG5}=\$$ADD_ON_PKG5+K
            fi
        elif [ "${VAR2}" = "S=I" ]; then # supported and installed (same versions)
            if [ "${ADD_ON_PKG5}" = "cda" ]; then
                do_ask_EorRorK CentrifyDA -${CUR_ADD_ON_VER} ${ADD_ON_VER}
            else
                do_ask_EorRorK CentrifyDC-${ADD_ON_PKG5} -${CUR_ADD_ON_VER} ${ADD_ON_VER}
            fi
            if [ "${ANSWER}" = "R" ]; then
                eval ${ADD_ON_PKG5}=\$$ADD_ON_PKG5+R
                PKG_FILE_LIST="${PKG_FILE_LIST} ${PKG_DIR}${PKG_FILE}"
                PKG_I_LIST="${PKG_I_LIST} ${ADD_ON_PKG_FULL}"
                if [ "${TARGET_OS}" = "aix" ]; then
                    FORCE_OPTION="-F" # Force reinstall
                fi
            elif [ "${ANSWER}" = "E" ]; then
                eval ${ADD_ON_PKG5}=\$$ADD_ON_PKG5+E
                if [ "${TARGET_OS}" = "aix" -a "${ADD_ON_PKG5}" = "openssh" -a "${OPENSSH_OLD}" = "Y" ]; then
                    ADD_ON_PKG_FULL="CentrifyDC-openssh.base"
                fi
                PKG_E_LIST="${PKG_E_LIST} ${ADD_ON_PKG_FULL}"
            else
                eval ${ADD_ON_PKG5}=\$$ADD_ON_PKG5+K
            fi
        elif [ "${VAR2}" = "I" ]; then # installed, not supported
            if [ "${ADD_ON_PKG5}" = "cda" ]; then
                do_ask_EorK CentrifyDA -${CUR_ADD_ON_VER}
            else
                do_ask_EorK CentrifyDC-${ADD_ON_PKG5} -${CUR_ADD_ON_VER}
            fi
            if [ "${ANSWER}" = "E" ]; then
                eval ${ADD_ON_PKG5}=\$$ADD_ON_PKG5+E
                if [ "${TARGET_OS}" = "aix" -a "${ADD_ON_PKG5}" = "openssh" -a "${OPENSSH_OLD}" = "Y" ]; then
                    ADD_ON_PKG_FULL="CentrifyDC-openssh.base"
                fi
                PKG_E_LIST="${PKG_E_LIST} ${ADD_ON_PKG_FULL}"
            else
                eval ${ADD_ON_PKG5}=\$$ADD_ON_PKG5+K
            fi
        fi
        set_package_name
    done
    debug_echo "PKG_FILE_LIST=${PKG_FILE_LIST}"
    debug_echo "PKG_I_LIST=${PKG_I_LIST}"
    debug_echo "PKG_E_LIST=${PKG_E_LIST}"
    debug_echo INSTALL=${INSTALL}
    return $TRUE
} # do_prompt()

### set GLOBAL_ZONE_ONLY
do_prompt_gz ()
{
    echo $ECHO_FLAG "\ninstall-express.sh: do_prompt_gz: " >> ${LOG_FILE}
    if [ "${GLOBAL_ZONE_ONLY}" != "non_global" -a "${INSTALLED}" = "Y" -a "${PKG_FILE_LIST}" != "" ]; then
        is_installed_gz_only || INSTALLED_GZ_ONLY="N"
    fi
    if [ "${FORCE_DA_GLOBAL}" != "Y"  ]; then
        if [ "${INSTALLED}" = "Y" -a "${PKG_FILE_LIST}" != "" -a "${INSTALLED_GZ_ONLY}" = "N" ] || \
            [ "${INSTALLED}" = "N" -a "${PKG_FILE_LIST}" != "" ]; then
            if [ "${GLOBAL_ZONE_ONLY}" != "non_global" ]; then
                QUESTION="\nSolaris 10 global zone detected.\nDo you want to install CentrifyDC in the current Solaris zone only? (Q|Y|N) [N]:\c"
                do_ask_YorN "N"; GLOBAL_ZONE_ONLY=${ANSWER}
            fi
        fi
    fi
    return $TRUE
} # do_prompt_gz()

###
determine_license ()
{
    echo $ECHO_FLAG "\ninstall-express.sh: determine_license: " >> ${LOG_FILE}
    if [ "${EXPRESS_PL}" -eq $TRUE ]; then
        if [ -z "${EXPRESS}" ]; then
            # even if licensed, it is possible to downgrade to express edition
            # let user to decide which mode to use
            return $FALSE
        else
            # selected edition always override preset value of ADLICENSE 
            if [ "${EXPRESS}" = "Y" ]; then
                ADLICENSE="N"
            fi
        fi
    else
        ADLICENSE="Y"
    fi
    return $TRUE
} # determine_license()

###
do_prompt_license ()
{
    echo $ECHO_FLAG "\ninstall-express.sh: do_prompt_license: " >> ${LOG_FILE}

##
### If the platform supports Express then we'll assume you want to
## install in Express mode.
##

    if [ "${EXPRESS_PL}" -eq $TRUE ]; then
       QUESTION_DEFAULT="Y"
    else
       QUESTION_DEFAULT="N"
    fi
    QUESTION="\nExpress authentication mode does not allow use of\nseparately licensed features such as Group Policy,\nDirectAuthorize or DirectAudit.\n\nDo you want to install in Express authentication mode? (Q|Y|N) [${QUESTION_DEFAULT}]: \c"
    do_ask_YorN QUESTION_DEFAULT

    # The question is the opposite logic to the state of ADLICENSE.
    # If the user answers Y to Express authentication then ADLICENSE should be "N"
    if [ "${ANSWER}" = "Y" ]; then
	ADLICENSE="N"
    else
        ADLICENSE="Y"
    fi
    return $TRUE
} # do_prompt_license()

### ask adcheck, adjoin, reboot ...
do_prompt_join ()
{
    echo $ECHO_FLAG "\ninstall-express.sh: do_prompt_join: " >> ${LOG_FILE}
    echo ""
    # ADCHECK
    if [ -n "${ADCHECK_FNAME}" ]; then
        QUESTION="Do you want to run adcheck to verify your AD environment? (Q|Y|N) [Y]:\c"; do_ask_YorN; ADCHECK=${ANSWER}
        if [ "${ADCHECK}" = "Y" ]; then
            if [ "${DOMAIN}" = "" -o "${DOMAIN}" = "company.com" ]; then
                # DOMAIN
                while [ "${DOMAIN}" = "" -o "${DOMAIN}" = "company.com" ]
                do
                    QUESTION="\nPlease enter the Active Directory domain to check: \c"; do_ask; DOMAIN=${ANSWER}
                done
            fi
        else
            ADCHECK_RC=""
        fi
    fi

    # ADJOIN
    if [ "${ADJOINED}" = "Y" ]; then
        ANSWER="n"; ADJOIN=${ANSWER}
    elif [ -n "${ADJOIN_CMD_OPTIONS}" ]; then
        ANSWER="n"; ADJOIN=${ANSWER}
    else
        QUESTION="Join an Active Directory domain? (Q|Y|N) [Y]:\c"; do_ask_YorN; ADJOIN=${ANSWER}
    fi
    if [ "${ADJOIN}" = "Y" ]; then
        if [ "${DOMAIN}" = "" -o "${DOMAIN}" = "company.com" ]; then
            # DOMAIN
            while [ "${DOMAIN}" = "" -o "${DOMAIN}" = "company.com" ]
            do
                QUESTION="    Enter the Active Directory domain to join: \c"; do_ask; DOMAIN=${ANSWER}
            done
        fi
        # USERID
        QUESTION="    Enter the Active Directory authorized user [administrator]: \c"; do_ask
        if [ "${ANSWER}" != "" ]; then USERID=${ANSWER}; fi
        # PASSWD
        PASSWD=""
        while [ "${PASSWD}" = "" ]
        do
            echo $ECHO_FLAG "    Enter the password for the Active Directory user: \c"
            stty -echo
            read PASSWD;
            stty echo
            echo ""
            if [ "${PASSWD}" = "q" -o "${PASSWD}" = "Q" ]; then do_quit; fi
        done
        # COMPUTER
        QUESTION="    Enter the computer name [${COMPUTER}]: \c"; do_ask
        if [ "${ANSWER}" != "" ]; then COMPUTER=${ANSWER}; fi
        # CONTAINER
        QUESTION="    Enter the container DN [Computers]: \c"; do_ask
        if [ "${ANSWER}" != "" ]; then CONTAINER=${ANSWER}; fi
        # ZONE
        if [ "${ADLICENSE}" != "N" ]; then
            QUESTION="    Enter the name of the zone [default]: \c"; do_ask
            if [ "${ANSWER}" != "" ]; then ZONE=${ANSWER}; fi
        fi
        # SERVER
        QUESTION="    Enter the name of the domain controller [auto detect]: \c"; do_ask
        if [ "${ANSWER}" != "" ]; then SERVER=${ANSWER}; fi
    fi

    # CDA auditing
    check_auditing

    if [ "${ADJOIN}" = "Y" -o "${ADJOINED}" = "Y" -o -n "${ADJOIN_CMD_OPTIONS}" ] && [ "${DA_ENABLE}" != "enabled" ]; then
        if [ "${cda}" = "S+Y" -o "${cda}" = "S+I+U" -o "${cda}" = "S=I+R" -o "${cda}" = "S+I+K" -o "${cda}" = "S=I+K" -o "${cda}" = "I+K" ]; then
            QUESTION="Enable auditing for all shells on this computer? (Q|Y|N) [Y]:\c"; do_ask_YorN; DA_ENABLE=${ANSWER}
        fi 
    fi

    # REBOOT
    if [ "${ADJOIN}" = "Y" -o "${ADJOINED}" = "Y" -o -n "${ADJOIN_CMD_OPTIONS}" ]; then
        QUESTION="Reboot the computer after installation? (Q|Y|N) [Y]:\c"; do_ask_YorN; REBOOT=${ANSWER}
    fi
    return $TRUE
} # do_prompt_join()

### Verify input
do_verify () 
{
    echo $ECHO_FLAG "\ninstall-express.sh: do_verify: " >> ${LOG_FILE}
    echo ""
    SUITE_NAME=${SUITE}
    [ "${EXPRESS}" = "Y" ] && SUITE_NAME=Express
    echo "You chose Centrify Suite ${SUITE_NAME} Edition and entered the following:"

    if [ "${INSTALL}" = "Y" ]; then
        echo "    Install CentrifyDC ${CDC_VER} package: ${INSTALL}"
    elif [ "${INSTALL}" = "U" -o "${INSTALL}" = "R" -o "${SUPPORTED}" = "Y" ]; then
        if [ "`compare_ver ${CDC_VER} ${CUR_VER}; echo ${COMPARE}`" = "gt" ]; then
            echo "    (E)rase/(U)pdate to ${CDC_VER}/(K)eep CentrifyDC-${CUR_VER} package: ${INSTALL}"
        else
            echo "    (E)rase/(R)einstall ${CDC_VER}/(K)eep CentrifyDC-${CUR_VER} package: ${INSTALL}"
        fi
    else
        echo "    (E)rase/(K)eep CentrifyDC-${CUR_VER} package: ${INSTALL}"
    fi
    for ADD_ON_PKG6 in ${ADD_ON_LIST}; do
        # set full add-on package name and FIELD to find supported add-on version
        if [ "${ADD_ON_PKG6}" = "cda" ]; then
            ADD_ON_PKG_FULL="CentrifyDA"
            FIELD=2
            CUR_ADD_ON_VER=${CDA_CUR_VER}
        else
            ADD_ON_PKG_FULL="CentrifyDC-${ADD_ON_PKG6}"
            FIELD=3 # version field in the package file-name
            if [ "${ADD_ON_PKG6}" = "openssh" -o "${ADD_ON_PKG6}" = "samba" ]; then FIELD=4; fi
            # find currently installed add-on package version
            for ADD_ON_PKG10 in ${ADD_ON_INSTALLED}; do
                CUR_ADD_ON_VER=""
                ADD_ON_PKG10=`echo ${ADD_ON_PKG10} | sed "s/DC\./DC-/"`
                if [ `echo ${ADD_ON_PKG10} | cut -d '-' -f2` = "${ADD_ON_PKG6}" ]; then
                    CUR_ADD_ON_VER=`echo ${ADD_ON_PKG10} | cut -d '-' -f3`      # x.x.x
                    #CUR_ADD_ON_VER=`echo ${ADD_ON_PKG10} | cut -d '-' -f3-4`    # x.x.x-xxx
                    break
                fi
            done
        fi
        # find supported add-on version
        set_package_name ${ADD_ON_PKG6}
        ADD_ON_VER=`echo ${PKG_FILE} | cut -d '-' -f${FIELD}`
        # show answers
        VAR1=\$"${ADD_ON_PKG6}"
        VAR2=`eval "expr \"\${VAR1}\" "`
        if [ "${VAR2}" = "S+Y" -o "${VAR2}" = "S+N" ]; then
            ANSWER=`echo ${VAR2} | cut -c3-`
            echo "    Install ${ADD_ON_PKG_FULL} ${ADD_ON_VER} package: ${ANSWER}"
        elif [ "${VAR2}" = "S+I+U" -o "${VAR2}" = "S+I+E" -o "${VAR2}" = "S+I+K" ]; then
            ANSWER=`echo ${VAR2} | cut -c5-`
            echo "    (E)rase/(U)pdate to ${ADD_ON_VER}/(K)eep ${ADD_ON_PKG_FULL}-${CUR_ADD_ON_VER} package: ${ANSWER}"
        elif [ "${VAR2}" = "S=I+R" -o "${VAR2}" = "S=I+E" -o "${VAR2}" = "S=I+K" ]; then
            ANSWER=`echo ${VAR2} | cut -c5-`
            echo "    (E)rase/(R)einstall ${ADD_ON_VER}/(K)eep ${ADD_ON_PKG_FULL}-${CUR_ADD_ON_VER} package: ${ANSWER}"
        elif [ "${VAR2}" = "I+E" -o "${VAR2}" = "I+K" ]; then
            ANSWER=`echo ${VAR2} | cut -c3-`
            echo "    (E)rase/(K)eep ${ADD_ON_PKG_FULL}-${CUR_ADD_ON_VER} package: ${ANSWER}"
        fi
        set_package_name
    done

    if [ "${FORCE_DA_GLOBAL}" != "Y" ]; then
        if [ "${GLOBAL_ZONE_ONLY}" != "non_global" ]; then
            echo "    Install CentrifyDC in the global Solaris zone only : ${GLOBAL_ZONE_ONLY}"
        fi
    fi 
    if [ "${EXPRESS_PL}" -eq $TRUE -a -z "${EXPRESS}" ]; then

	# Express authentication mode is the inverse of ADLICENSE
	if [ "${ADLICENSE}" = "Y" ]; then
	    EXPRESS_MODE="N"
	else
	    EXPRESS_MODE="Y"
	fi
        echo "    Express authentication mode      : ${EXPRESS_MODE}"
    fi
    if [ -n "${ADCHECK_FNAME}" ]; then
        echo "    Run adcheck                      : ${ADCHECK}"
    fi
    if [ "${ADJOINED}" != "Y" -a -z "${ADJOIN_CMD_OPTIONS}" ]; then
        echo "    Join an Active Directory domain  : ${ADJOIN}"
    fi
    if [ "${ADJOIN}" = "Y" ]; then
        echo "    Active Directory domain to join  : ${DOMAIN}"
        echo "    Active Directory authorized user : ${USERID}"
        echo "    computer name                    : ${COMPUTER}"
        echo "    container DN                     : ${CONTAINER}"
        if [ "${ADLICENSE}" != "N" ]; then
            echo "    zone name                        : ${ZONE}"
        fi
        if [ "${SERVER}" = "" ]; then
            echo "    domain controller name           : auto detect"
        else
            echo "    domain controller name           : ${SERVER}"
        fi
    elif [ -n "${ADJOIN_CMD_OPTIONS}" ]; then
        echo "    Join an Active Directory domain using the next options:"
        echo "    ${ADJOIN_CMD_OPTIONS}"
    fi
    if [ "${ADJOIN}" = "Y" -o "${ADJOINED}" = "Y" -o -n "${ADJOIN_CMD_OPTIONS}" ] && [ "${DA_ENABLE}" != "enabled" ]; then
        if [ "${cda}" = "S=I+K" -o "${cda}" = "S=I+R" -o "${cda}" = "S+Y" ] || \
           [ "${cda}" = "S+I+K" -o "${cda}" = "S+I+U" -o "${cda}" = "I+K" ]; then
            echo "    Enable auditing                  : ${DA_ENABLE}"
        fi
    fi
    if [ "${ADJOIN}" = "Y" -o "${ADJOINED}" = "Y" -o -n "${ADJOIN_CMD_OPTIONS}" ]; then
        echo "    Reboot computer                  : ${REBOOT}"
    fi 
    echo ""
    echo ""
    echo "If this information is correct and you want to proceed, type \"Y\"."
    echo "To change any information, type \"N\" and enter new information."
    QUESTION="Do you want to continue (Y) or re-enter information? (Q|Y|N) [Y]:\c"; do_ask_YorN; CONTINUE=${ANSWER}
    if [ "${ANSWER}" != "Y" ]; then
        # reset to the default
        echo ""
        ADCHECK=""; ADJOIN=""; DOMAIN=""; USERID="administrator"; PASSWD=""; CONTAINER="Computers"
        SERVER=""; ZONE="default"; COMPUTER=`hostname`; REBOOT=""
        INPUT=""; INSTALL=""; SUITE="Custom"
        if [ "${DA_ENABLE}" != "enabled" ]; then DA_ENABLE=""; fi
        PKG_FILE_LIST=""; PKG_I_LIST=""; PKG_E_LIST=""
        set_package_name
        for ADD_ON_PKG6 in ${ADD_ON_LIST}; do
            VAR1=\$"${ADD_ON_PKG6}"
            VAR2=`eval "expr \"\${VAR1}\" "`
            if [ "${VAR2}" = "S+Y" -o "${VAR2}" = "S+N" -o "${VAR2}" = "I+E" -o "${VAR2}" = "I+K" ]; then
                VAR3=`echo ${VAR2} | cut -c1`
                eval ${ADD_ON_PKG6}=${VAR3}
            elif [ "${VAR2}" = "S+I+U" -o "${VAR2}" = "S+I+E" -o "${VAR2}" = "S+I+K" ] || \
                 [ "${VAR2}" = "S=I+R" -o "${VAR2}" = "S=I+E" -o "${VAR2}" = "S=I+K" ]; then
                VAR3=`echo ${VAR2} | cut -c1-3`
                eval ${ADD_ON_PKG6}=${VAR3}
            fi
        done
    fi
    return $TRUE
} # do_verify()

do_silent_prompt ()
{
    ### configure silent mode for the agent
    INSTALL=`echo ${INSTALL} | tr abcdefghijklmnopqrstuvwxyz ABCDEFGHIJKLMNOPQRSTUVWXYZ`
    if [ "${INSTALL}" = "N" -a "${INSTALLED}" = "N" ]; then
        echo "Silent mode: INSTALLED=${INSTALLED} and INSTALL=${INSTALL}" 
        do_quit
    fi
    if [ "${INSTALL}" = "E" -a "${INSTALLED}" = "Y" ]; then
        if [ "${ADD_ON_INSTALLED}" != "" ]; then
            echo $ECHO_FLAG "\nWARNING:" | tee -a ${LOG_FILE}
            echo $ECHO_FLAG "The following Centrify DirectControl add-on package(s) depend on CentrifyDC" | tee -a ${LOG_FILE}
            echo $ECHO_FLAG "core package and should be also removed:" | tee -a ${LOG_FILE}
            for ADD_ON_PKG in ${ADD_ON_INSTALLED}; do
                echo $ECHO_FLAG ${ADD_ON_PKG} | tee -a ${LOG_FILE}
            done
            echo $ECHO_FLAG "To uninstall all Centrify DirectControl packages set UNINSTALL=Y in" | tee -a ${LOG_FILE}
            echo $ECHO_FLAG "${CFG_FNAME} or use -e option." | tee -a ${LOG_FILE}
            do_quit
        fi
    fi
    if [ "${INSTALL}" = "Y" -a "${INSTALLED}" = "Y" ]; then INSTALL="N"; fi # only fresh install, no upgrade
    if [ "${INSTALL}" = "U" -a "${INSTALLED}" = "Y" ] && [ "`compare_ver ${CDC_VER} ${CUR_VER}; echo ${COMPARE}`" != "gt" ]; then INSTALL="N"; fi # update only, no reinstall
    if [ "${INSTALL}" = "U" -o "${INSTALL}" = "R" ] && [ "${INSTALLED}" = "N" ]; then INSTALL="Y"; fi # not installed yet so just install (skip upgrade steps)
    if [ "${INSTALL}" = "Y" -o "${INSTALL}" = "U" -o "${INSTALL}" = "R" ]; then
        # bail on mac if asked to install/upgrade 3.x or earlier
        min_version_required || { echo ; echo "This version of install-express.sh cannot be used with CentrifyDC $CDC_VER"; do_error; }

        PKG_FILE_LIST=${PKG_DIR}${PKG_FILE}
        PKG_I_LIST="CentrifyDC"
        if [ "${TARGET_OS}" = "aix" ]; then PKG_I_LIST="CentrifyDC.core"; fi
    fi
    if [ "${INSTALL}" = "R" ]; then
        if [ "${TARGET_OS}" = "aix" ]; then
            FORCE_OPTION="-F" # Force reinstall
        fi
    fi
    ### configure silent mode for add-on packages
    for ADD_ON_PKG8 in ${ADD_ON_LIST}; do
        if [ "${TARGET_OS}" = "aix" -a "${ADD_ON_PKG8}" = "cda" ]; then
            ADD_ON_PKG_FULL="CentrifyDA.core"
        elif [ "${ADD_ON_PKG8}" = "cda" ]; then
            ADD_ON_PKG_FULL="CentrifyDA"
        else
            ADD_ON_PKG_FULL="CentrifyDC${SEP}${ADD_ON_PKG8}"
        fi
        VAR1=\$"${ADD_ON_PKG8}"
        VAR2=`eval "expr \"\${VAR1}\" "`
        if [ "${ADD_ON_PKG8}" = "cda" ]; then
            VAR3=\$"CentrifyDA"
        else
            VAR3=\$"CentrifyDC_${ADD_ON_PKG8}"
        fi
        VAR4=`eval "expr \"\${VAR3}\" " | tr abcdefghijklmnopqrstuvwxyz ABCDEFGHIJKLMNOPQRSTUVWXYZ`
        debug_echo "${VAR1} ${VAR2} ${VAR3} ${VAR4}"
        if [ "${VAR2}" = "S" ]; then
            # Install? No?
            if [ "${VAR4}" = "Y" -o "${VAR4}" = "U" ]; then
                eval ${ADD_ON_PKG8}=\$$ADD_ON_PKG8+Y
                set_package_name ${ADD_ON_PKG8}
                PKG_FILE_LIST="${PKG_FILE_LIST} ${PKG_DIR}${PKG_FILE}"
                PKG_I_LIST="${PKG_I_LIST} ${ADD_ON_PKG_FULL}"
            else
                eval ${ADD_ON_PKG8}=\$$ADD_ON_PKG8+N
            fi
        elif [ "${VAR2}" = "S+I" ]; then
            # Erase? Upgrade? Keep?
            if [ "${VAR4}" = "U" ]; then
                eval ${ADD_ON_PKG8}=\$$ADD_ON_PKG8+U
                set_package_name ${ADD_ON_PKG8}
                PKG_FILE_LIST="${PKG_FILE_LIST} ${PKG_DIR}${PKG_FILE}"
                PKG_I_LIST="${PKG_I_LIST} ${ADD_ON_PKG_FULL}"
            elif [ "${VAR4}" = "E" ]; then
                eval ${ADD_ON_PKG8}=\$$ADD_ON_PKG8+E
                if [ "${TARGET_OS}" = "aix" -a "${ADD_ON_PKG5}" = "openssh" -a "${OPENSSH_OLD}" = "Y" ]; then
                    ADD_ON_PKG_FULL="CentrifyDC-openssh.base"
                fi
                PKG_E_LIST="${PKG_E_LIST} ${ADD_ON_PKG_FULL}"
            else
                eval ${ADD_ON_PKG8}=\$$ADD_ON_PKG8+K
            fi
        elif [ "${VAR2}" = "S=I" ]; then
            # Erase? Reinstall? Keep?
            if [ "${VAR4}" = "U" ]; then # update only, no reinstall
                eval ${ADD_ON_PKG8}=\$$ADD_ON_PKG8+K
            elif [ "${VAR4}" = "R" ]; then
                eval ${ADD_ON_PKG8}=\$$ADD_ON_PKG8+R
                set_package_name ${ADD_ON_PKG8}
                PKG_FILE_LIST="${PKG_FILE_LIST} ${PKG_DIR}${PKG_FILE}"
                PKG_I_LIST="${PKG_I_LIST} ${ADD_ON_PKG_FULL}"
                if [ "${TARGET_OS}" = "aix" ]; then
                    FORCE_OPTION="-F" # Force reinstall
                fi
            elif [ "${VAR4}" = "E" ]; then
                eval ${ADD_ON_PKG8}=\$$ADD_ON_PKG8+E
                if [ "${TARGET_OS}" = "aix" -a "${ADD_ON_PKG5}" = "openssh" -a "${OPENSSH_OLD}" = "Y" ]; then
                    ADD_ON_PKG_FULL="CentrifyDC-openssh.base"
                fi
                PKG_E_LIST="${PKG_E_LIST} ${ADD_ON_PKG_FULL}"
            else
                eval ${ADD_ON_PKG8}=\$$ADD_ON_PKG8+K
            fi
        elif [ "${VAR2}" = "I" ]; then
            # Erase? Keep?
            if [ "${VAR4}" = "E" ]; then
                eval ${ADD_ON_PKG8}=\$$ADD_ON_PKG8+E
                if [ "${TARGET_OS}" = "aix" -a "${ADD_ON_PKG5}" = "openssh" -a "${OPENSSH_OLD}" = "Y" ]; then
                    ADD_ON_PKG_FULL="CentrifyDC-openssh.base"
                fi
                PKG_E_LIST="${PKG_E_LIST} ${ADD_ON_PKG_FULL}"
            else
                eval ${ADD_ON_PKG8}=\$$ADD_ON_PKG8+K
            fi
        fi
        set_package_name
    done
    debug_echo "PKG_FILE_LIST=${PKG_FILE_LIST}"
    debug_echo "PKG_I_LIST=${PKG_I_LIST}"
    debug_echo "PKG_E_LIST=${PKG_E_LIST}"
    debug_echo INSTALL=${INSTALL}
    return $TRUE
} # do_silent_prompt

create_admin () 
{
    if [ ! -d ${VAR_TMP} ]; then mkdir -p ${VAR_TMP}; fi
    echo mail= > ${ADMIN_FILE}
    echo instance=overwrite >> ${ADMIN_FILE}
    echo partial=nocheck >> ${ADMIN_FILE}
    echo runlevel=nocheck >> ${ADMIN_FILE}
    echo idepend=${ADMIN_IDEPEND} >> ${ADMIN_FILE}
    echo rdepend=${ADMIN_RDEPEND} >> ${ADMIN_FILE}
    echo space=quit >> ${ADMIN_FILE}
    echo setuid=nocheck >> ${ADMIN_FILE}
    echo conflict=${ADMIN_CONFLICT} >> ${ADMIN_FILE}
    echo action=nocheck >> ${ADMIN_FILE}
    echo basedir=default >> ${ADMIN_FILE}
}

### Pre-install steps
do_preinstall () 
{
    if [ "$1" = "" ]; then
        echo $ECHO_FLAG "\ninstall-express.sh: do_preinstall: " >> ${LOG_FILE}

        if [ "${TARGET_OS}" = "darwin" ]; then
            #first things first, let's remove the old LaunchDaemon and StartupItem entry!
            #those files should not exist when doing a clean install, but let's make sure!!!
            if [ -e /Library/LaunchDaemons/centrifydc.plist ]; then
                rm -f /Library/LaunchDaemons/centrifydc.plist >> ${LOG_FILE}
            fi
            if [ -d /Library/StartupItems/CentrifyDC ]; then
                rm -rf /Library/StartupItems/CentrifyDC       >> ${LOG_FILE}
            fi
            # create /home if not exist. Don't link /home to /Users, because
            # it will cause problem on 10.4.
            if [ ! -e /home ]; then
                echo $ECHO_FLAG "/home does not exist. Create." >> ${LOG_FILE}
                mkdir /home 2>> ${LOG_FILE}
                chmod 755 /home 2>> ${LOG_FILE}
            fi
        else
            echo skipping ... >> ${LOG_FILE}
        fi

    elif [ "$1" = "openssh" -a "${TARGET_OS}" = "linux" ] &&
         [ "`compare_ver ${CDC_VER} 4.4; echo ${COMPARE}`" = "lt" ]; then
        echo $ECHO_FLAG "\ninstall-express.sh: do_preinstall: $1: " >> ${LOG_FILE}
        if [ -f /etc/pam.d/sshd ]; then
            echo "INFO: found non-centrify /etc/pam.d/sshd, renaming to /etc/pam.d/sshd.pre_cdc" >> ${LOG_FILE}
            mv /etc/pam.d/sshd /etc/pam.d/sshd.pre_cdc
            if [ "${PKG_OS_REV}" = "deb5" ]; then
                LINUX_OPTION="${LINUX_OPTION} --force-overwrite"
            else
                LINUX_OPTION="${LINUX_OPTION} --replacefiles"
            fi

        fi
    elif [ "$1" = "CentrifyDA" -a "${TARGET_OS}" = "solaris" ]; then
        do_force_da_global || return $?
    else ### add-on
        echo $ECHO_FLAG "\ninstall-express.sh: do_preinstall: $1: skipping ..." >> ${LOG_FILE}
    fi
    return ${TRUE}
} # do_preinstall()

### Post-install steps
do_postinstall () 
{
    if [ "$1" = "" ]; then
        echo $ECHO_FLAG "\ninstall-express.sh: do_postinstall: " >> ${LOG_FILE}

        if [ "${TARGET_OS}" = "darwin" ]; then
            if [ ${DSPLUGIN_HAS_BEEN_ENABLED} -eq 0 ]; then
                #register our plugin
                echo ${ECHO_FLAG} "Registering Directory Service plugin ..." | tee -a ${LOG_FILE}
                /usr/share/centrifydc/bin/dsconfig enable | tee -a ${LOG_FILE}
                echo ${ECHO_FLAG} "" | tee -a ${LOG_FILE}
                echo ${ECHO_FLAG} "WARNING: The Centrify DirectControl DirectoryService plugin has been enabled" | tee -a ${LOG_FILE}
                echo ${ECHO_FLAG} "If you had Directory Access (or Directory Utility) running during install,"   | tee -a ${LOG_FILE}
                echo ${ECHO_FLAG} "the checkbox next to the CentrifyDC plugin might not reflect that change."    | tee -a ${LOG_FILE}
                echo ${ECHO_FLAG} "To see the correct state, please quit (CMD-q) and restart Directory Access"   | tee -a ${LOG_FILE}
                echo ${ECHO_FLAG} "(or Directory Utility) after CentrifyDC installation is complete"             | tee -a ${LOG_FILE}
                echo ${ECHO_FLAG} "" | tee -a ${LOG_FILE}
                DSPLUGIN_HAS_BEEN_ENABLED=1
            fi
            cat /etc/shells 2> /dev/null | grep "\/usr\/bin\/dzsh" > /dev/null 2> /dev/null
            if [ "$?" -ne 0 ]; then
                echo adding /usr/bin/dzsh to /etc/shells ... >> ${LOG_FILE}
                echo /usr/bin/dzsh >> /etc/shells
            fi
        
        elif [ "${TARGET_OS}" = "solaris" ]; then
            # clean up temp files
            rm -f /lib/*centrify*.BK
            rm -f /usr/lib/*centrify*.BK
            rm -f /usr/lib/security/*centrify*.BK

        elif [ "${OS_REV}" = "aix6.1" -o "${OS_REV}" = "aix7.1" ]; then
            fix_wpar
        fi
        is_perl_installed       || { disable_GP; }
        restart_mcafee_agent

    elif [ "$1" = "CentrifyDA" -a "${TARGET_OS}" = "solaris" ]; then
        revert_force_da_global
    else ### add-on
        echo $ECHO_FLAG "\ninstall-express.sh: do_postinstall: $1: skipping ..." >> ${LOG_FILE}
    fi
    return ${TRUE}
} # do_postinstall()

save_admin_settings ()
{
    ADMIN_SAVE_IDEPEND=$ADMIN_IDEPEND
    ADMIN_SAVE_RDEPEND=$ADMIN_RDEPEND
    ADMIN_SAVE_CONFLICT=$ADMIN_CONFLICT
}

restore_admin_settings ()
{
    ADMIN_IDEPEND=$ADMIN_SAVE_IDEPEND
    ADMIN_RDEPEND=$ADMIN_SAVE_RDEPEND
    ADMIN_CONFLICT=$ADMIN_SAVE_CONFLICT
}

### Force install Solaris package for fix_install_solaris()
force_install_pkg ()
{
    rm -rf ${VAR_TMP}/*

    PKG_I2_LIST="`echo \"${PKG_I3_LIST} \" ${PKG_I2_LIST} | sed \"s/ $1 //\" `"
    if echo " $PKG_I3_LIST " | grep " $1 " > /dev/null 2>&1; then
        PKG_I3_LIST="`echo \"${PKG_I3_LIST} \" | sed \"s/ $1 //\" `"
        PKG_I_LIST=$1
        set_package_name `echo ${PKG_I_LIST} | sed s/CentrifyDC// | sed s/-// | sed 's/\.//' | sed s/core//`
        do_install ${PKG_I_LIST}
        RC_INSTALL=$?
    else
        RC_INSTALL=0
    fi
    restore_admin_settings
    return $RC_INSTALL
}

### check whether $1 covers all elements of $2 that seperated by ','
left_cover_right ()
{
    relements="`echo $2 | tr ',' ' '`"
    
    for relement in $relements; do
        if echo "$1" | grep -v "${relement}," > /dev/null 2>&1; then
            return $FALSE
        fi
    done
    return $TRUE
}

### Fix installation problem in Solaris
fix_install_solaris ()
{
    # Remove package from the list if it was installed successfully
    PKG_I3_LIST=""
    echo "Checking installation results ..."  | tee -a ${LOG_FILE}
    for i in ${PKG_I_LIST}; do
        PKG_I_RESULT="`get_pkgadd_result $i`"
        echo "  $i: $PKG_I_RESULT" >> ${LOG_FILE}
        eval "`echo ${i} | sed -e 's/-/_/' -e 's/\./_/'`_PKG_I_RESULT=$PKG_I_RESULT" # record get_pkgadd_result
        if [ "$PKG_I_RESULT" != "successful" ]; then
            PKG_I3_LIST="${PKG_I3_LIST} $i"
        fi
    done

    ### CentrifyDC
    IGNORE_I_ERROR="conflict,inc=CentrifyDC-nis," # Warnings and errors which can be ignored
    # if CentrifyDC installation is failed and
    # all warnings in $CentrifyDC_PKG_I_RESULT can be ignored
    if echo " $PKG_I3_LIST " | grep " CentrifyDC " > /dev/null 2>&1 && \
       left_cover_right "$IGNORE_I_ERROR" "$CentrifyDC_PKG_I_RESULT"; then
        if echo "$CentrifyDC_PKG_I_RESULT" | grep "conflict,"; then
            echo "INFO: Conflicts detected while installing CentrfiyDC package." | tee -a ${LOG_FILE}
            echo "Installing core package without conflict checking to fix conflicts ..." | tee -a ${LOG_FILE}

            save_admin_settings; ADMIN_CONFLICT=nocheck
            force_install_pkg "CentrifyDC" || return
        elif echo " $PKG_I_LIST " | grep " CentrifyDC-nis " > /dev/null 2>&1 && \
             echo "$CentrifyDC_PKG_I_RESULT" | grep "inc=CentrifyDC-nis," > /dev/null 2>&1; then
            echo "INFO: Incompatible CentrifyDC-nis detected when installing CentrifyDC." | tee -a ${LOG_FILE}
            echo "INFO: It is known issue when upgrading CentrifyDC and CentrifyDC-nis" | tee -a ${LOG_FILE}
            echo "Installing CentrifyDC package without dependency checking ..." | tee -a ${LOG_FILE}
        
            save_admin_settings; ADMIN_IDEPEND=nocheck
            force_install_pkg "CentrifyDC" || return
        fi
    fi
    ### CentrifyDC-nis
    IGNORE_I_ERROR="inc=CentrifyDC," # Warnings and errors which can be ignored
    # if CentrifyDC-nis installation is failed and
    # all warnings in $CentrifyDC_nis_PKG_I_RESULT can be ignored
    if echo " $PKG_I3_LIST " | grep " CentrifyDC-nis " > /dev/null 2>&1 && \
       left_cover_right "$IGNORE_I_ERROR" "$CentrifyDC_nis_PKG_I_RESULT"; then
        if echo "$CentrifyDC_nis_PKG_I_RESULT" | grep "inc=CentrifyDC," ]; then
            echo "INFO: Incompatible CentrifyDC detected when installing CentrifyDC-nis." | tee -a ${LOG_FILE}
            echo "INFO: This is a known issue that Solaris 9 U7 or before may have this problem." | tee -a ${LOG_FILE}
            echo "Installing CentrifyDC-nis package without dependency checking ..." | tee -a ${LOG_FILE}

            save_admin_settings; ADMIN_IDEPEND=nocheck
            force_install_pkg CentrifyDC-nis || return
        fi
    fi
    ### CentrifyDC-web
    IGNORE_I_ERROR="inc=CentrifyDC," # Warnings and errors which can be ignored
    # if CentrifyDC-web installation is failed and
    # all warnings in $CentrifyDC_web_PKG_I_RESULT can be ignored
    if echo " $PKG_I3_LIST " | grep " CentrifyDC-web " > /dev/null 2>&1 && \
       left_cover_right "$IGNORE_I_ERROR" "$CentrifyDC_web_PKG_I_RESULT"; then
        if echo "$CentrifyDC_web_PKG_I_RESULT" | grep "inc=CentrifyDC," ]; then
            echo "INFO: Incompatible CentrifyDC detected when installing CentrifyDC-web." | tee -a ${LOG_FILE}
            echo "INFO: This is a known issue that Solaris 9 U7 or before may have this problem." | tee -a ${LOG_FILE}
            echo "Installing CentrifyDC-web package without dependency checking ..." | tee -a ${LOG_FILE}

            save_admin_settings; ADMIN_IDEPEND=nocheck
            force_install_pkg CentrifyDC-web || return
        fi
    fi
}

### Install Centrify DirectControl suite
do_install_main ()
{
    echo $ECHO_FLAG "\ninstall-express.sh: do_install_main: " >> ${LOG_FILE}
    if [ -d ${VAR_TMP} ]; then
        rm -rf ${VAR_TMP}
    fi
    mkdir -p ${VAR_TMP}
    if [ ! -d ${VAR_TMP} ]; then
        echo $ECHO_FLAG "\nERROR: Could not create ${VAR_TMP}." | tee -a ${LOG_FILE}
        return $FALSE
    fi
    chmod 750 ${VAR_TMP}
    
    if  [ "${TARGET_OS}" = "solaris" -o "${TARGET_OS}" = "aix" -o "${TARGET_OS}" = "hpux" ]; then
        if [ "`echo ${PKG_I_LIST} | wc -w | sed 's/^[ ^t]*//'`" = "1" ]; then
            # install single package
            set_package_name `echo ${PKG_I_LIST} | sed s/CentrifyDC// | sed s/-// | sed 's/\.//' | sed s/core//`
            do_install ${PKG_I_LIST}
            RC_INSTALL=$?
            if [ "$RC_INSTALL" != "0" ]; then
                if [ "${TARGET_OS}" = "solaris" -a "$RC" = "4" ]; then
                    # Administration error
                    fix_install_solaris
                fi
                if [ "$RC_INSTALL" != "0" ]; then print_df; return ${FALSE}; fi
            fi
        else
            # multi-package install
            PKG_I2_LIST=""
            if [ "${GLOBAL_ZONE_ONLY}" != "Y" ] && [ -x /usr/sbin/zoneadm ] && \
                [ "`/usr/sbin/zoneadm list -p | grep 0:global > /dev/null; echo $?`" = "0" ] && \
                [ "${INSTALL}" = "U" ]; then
                # upgrade
                if [ "${nis}" = "S+Y" -o "${nis}" = "S+I+U" ] && \
                    [ "`compare_ver ${CDC_VER} ${CDC_VER_INC_NIS_2}; echo ${COMPARE}`" != "lt" ] && \
                    [ "`compare_ver ${CUR_VER} ${CDC_VER_INC_NIS_2}; echo ${COMPARE}`" = "lt" ]; then
                    # prepare for the second round to avoid dependency conflicts in Sol10 zones
                    PKG_I_LIST="`echo ${PKG_I_LIST} | sed 's/ CentrifyDC-nis//'`"
                    debug_echo "PKG_I_LIST=${PKG_I_LIST}"
                    PKG_I2_LIST="CentrifyDC-nis"
                fi
            fi
            for ADD_ON_PKG7 in ${PKG_I_LIST}; do
                set_package_name `echo ${ADD_ON_PKG7} | sed s/CentrifyDC// | sed s/-// | sed 's/\.//' | sed s/core//`
                do_install ${ADD_ON_PKG7} spool
                if [ "$?" != "0" ]; then print_df; return ${FALSE}; fi
            done
            do_install all
            RC_INSTALL=$?
            if [ "$RC_INSTALL" != "0" ]; then
                if [ "${TARGET_OS}" = "solaris" -a "$RC" = "4" ]; then
                    # Administration error
                    fix_install_solaris
                fi
                if [ "$RC_INSTALL" != "0" ]; then print_df; return ${FALSE}; fi
            fi
            # second round to avoid dependency conflicts in Sol10 zones
            if [ "${PKG_I2_LIST}" != "" ]; then
                PKG_I_LIST=${PKG_I2_LIST}
                PKG_I2_LIST=""
                rm -rf ${VAR_TMP}/*
                for ADD_ON_PKG7 in ${PKG_I_LIST}; do
                    set_package_name `echo ${ADD_ON_PKG7} | sed s/CentrifyDC// | sed s/-// | sed 's/\.//' | sed s/core//`
                    do_install ${ADD_ON_PKG7} spool
                    if [ "$?" != "0" ]; then print_df; return ${FALSE}; fi
                done
                do_install all
                RC_INSTALL=$?
                if [ "$RC_INSTALL" != "0" ]; then
                    if [ "${TARGET_OS}" = "solaris" -a "$RC" = "4" ]; then
                        # Administration error
                        fix_install_solaris
                    fi
                    if [ "$RC_INSTALL" != "0" ] || [ "${PKG_I2_LIST}" != "" ]; then print_df; return ${FALSE}; fi
                fi
            fi
        fi
    else
        # install on LINUX, IRIX and Mac OS using PKG_FILE_LIST
        do_install
        if [ "$?" != "0" ]; then print_df; return ${FALSE}; fi
    fi
    rm -rf ${VAR_TMP}
    return ${TRUE}
} # do_install_main()

### pkgadd wrapper that will save the output from pkgadd
do_pkgadd ()
{
    /usr/sbin/pkgadd "$@" > ${PKGADD_LOG} 2>&1
    RC=$?
    cat ${PKGADD_LOG} >> ${LOG_FILE}
    return ${RC}
}

### check whether swcopy/swinstall has exrequisite conflicts
### use swcopy/swinstall output file as first argument
check_sw_exrequisite ()
{
    if grep 'fileset(s) have been excluded due to exrequisite' "$1" > /dev/null; then
        return ${TRUE}
    fi
    return ${FALSE}
}

### swcopy that checks the warnings caused by exrequisites conflicts
### and return 2 if exrequisites conflicts found
### info: swcopy may not return error exit code when exrequisites conflicts
do_swcopy ()
{
    /usr/sbin/swcopy $@ > ${SWCOPY_LOG} 2> ${SWCOPY_LOG}
    RC=$?
    cat ${SWCOPY_LOG} >> ${LOG_FILE}
    if [ "${RC}" = "0" ] && \
        check_sw_exrequisite ${SWCOPY_LOG}; then
            return 2
    fi
    return ${RC}
}

### swinstall that checks the warnings caused by exrequisites conflicts
### and return 2 if exrequisites conflicts
### info: swinstall may not return error exit code when exrequisites conflicts
do_swinstall ()
{
    /usr/sbin/swinstall $@ > ${SWINSTALL_LOG} 2> ${SWINSTALL_LOG}
    RC=$?
    cat ${SWINSTALL_LOG} >> ${LOG_FILE}
    if [ "${RC}" = "0" ] && \
        check_sw_exrequisite ${SWINSTALL_LOG}; then
            return 2
    fi
    return ${RC}
}

### Check package installation result in the pkgadd log file
### get_pkgadd_result [package]
get_pkgadd_result ()
{
    if [ -f "${PKGADD_LOG}" ]; then
        # Read the block of log for this package only
        tail -r "${PKGADD_LOG}" | awk "
BEGIN {
    started=0; current_status=\"\"; result=\"notfound\"
}
{
    if (started == 0) {
        if (\$0 ~ /Installation of <$1> was/ || \
            \"$1\" == \"\" && \$0 ~ /Installation of </) {
            started=1
            result=\"\"
            if (\$0 ~ /successful/) { result=\"successful\"; exit }
        }
        else if (\$0 !~ /Dependency checking issues for package/) {
            # sample matching line 1:
            # The package <CentrifyDC> is a prerequisite package and should be
            # installed for package <CentrifyDC-ldapproxy> on zone <myzone>.
            # sample matching line 2:
            # pkgadd: ERROR: unknown preinstallation dependency check line <incompat=CentrifyDC-nis> for package <CentrifyDC> zone <myzone>: ignored
            if (\$0 ~ /for package <$1>.* zone/ || \
                \"$1\" == \"\" && \
                \$0 ~ /for package </) { # shown when checking zones
                started=1
                result=\"\"
            }
        }
    }
    else if (started == 1) {
        if (\$0 ~ /^## Verifying /) { exit }
        # exit if switch to the message of another package
        if (\$0 ~ /Installation of </) { exit }
        if (\$0 ~ /for package <.*>.* zone/ && \$0 !~ /for package <$1>.* zone/) { exit }
    }

    if (started == 1) {
        if (\$0 ~ /files are already installed/) { current_status=\"conflict\"; result=result \"conflict,\" }
        if (\$0 ~ /which is incompatible with/ || \$0 ~ /unknown preinstallation dependency check line/) { current_status=\"inc\"; result=result \"inc\" }
        if (\$0 ~ /prerequisite package/) { current_status=\"prer\"; result=result \"prer\" }
        if ((current_status == \"inc\" || current_status == \"prer\" || current_status == \"inc-zone\") && \$0 ~ /<.*>/) {
            x=index(\$0,\"<\")
            y=index(\$0,\">\")
            info=\"\"
            if (x > 0 && y > 0) { info=substr(\$0,x+1,y-x-1) }
            # the format inside <> may be <incompat=CentrifyDC>
            x=index(info,\"=\")
            if (x > 0) { info=substr(info,x+1) }
            if (info != \"\") { result=result \"=\" info \",\" }
            current_status=\"\"
        }
    }
}
END {
    if (result == \"\") {
        print \"unknown\"
    } else {
        print result
    }
}
"
    else
        echo "nolog"
    fi
}

### Install Centrify DirectControl package(s)
do_install () 
{
    echo $ECHO_FLAG "\ninstall-express.sh: do_install: " >> ${LOG_FILE}
    FLAG=""
    case "${TARGET_OS}" in
    linux)
        echo List of ${CDC_VER} packages to be installed: >> ${LOG_FILE}
        for i in ${PKG_I_LIST}; do
            echo "    ${i}" >> ${LOG_FILE}
        done
        if [ "${PKG_OS_REV}" = "deb5" ]; then
            CMD="dpkg -i"
            # Do not force using default configurations if --force-xxx option is given
            echo "$LINUX_OPTION" | grep '\-\-force\-' > /dev/null 2>&1 || FLAG="--force-confdef"
        else
            CMD="rpm -Uv"
            FLAG="--replacepkgs"
        fi
        
        ${CMD} ${FLAG} ${LINUX_OPTION} ${PKG_FILE_LIST} 2>> ${LOG_FILE}; RC=$?
        ;;
    solaris)
        if [ "$1" != "all" ]; then
            echo "Unzipping/unpackaging ${PKG_DIR}${PKG_FILE} to /var/tmp/centrifydc* ..." | tee -a ${LOG_FILE}
            case "${PKG_FILE}" in
            *".tgz")
                gunzip -c ${PKG_DIR}${PKG_FILE} | ( cd ${VAR_TMP} && tar -xf - )
                ;;
            *".gz")
                gunzip -c ${PKG_DIR}${PKG_FILE} > ${VAR_TMP}/${1}
                ;;
            *)
                echo ${ECHO_FLAG} "WARNING: Unexpected package file extension: ${PKG_FILE}" >> ${LOG_FILE}
                ;;
            esac
            if [ "$?" != "0" ]; then return ${FALSE}; fi
        fi
        if [ "$2" = "spool" ]; then
            # spool single package
            echo Spooling ${1} ... | tee -a ${LOG_FILE}
            mkdir -p ${VAR_TMP}/tmp
            mv ${VAR_TMP}/${1} ${VAR_TMP}/tmp
            do_pkgadd -s ${VAR_TMP} -d ${VAR_TMP}/tmp/${1} ${1} >> ${LOG_FILE} 2>> ${LOG_FILE}
            RC=$?
            rm -rf ${VAR_TMP}/tmp
        elif [ "$2" = "" -a "$1" != "" -a "$1" != "all" ]; then
            # install single package
            echo Installing ${1} ... | tee -a ${LOG_FILE}
            create_admin
            if [ "${FORCE_DA_GLOBAL}" != "Y" -a "${GLOBAL_ZONE_ONLY}" = "Y" ]; then FLAG="-G"; fi
            do_pkgadd ${FLAG} -a ${ADMIN_FILE} -n -d ${VAR_TMP}/${1} ${1} 2>> ${LOG_FILE}
            RC=$?
            sleep 5
        elif [ "$1" = "all" ]; then
            # install all from spool dir
            echo Installing all from spool dir ... | tee -a ${LOG_FILE}
            create_admin
            if [ "${FORCE_DA_GLOBAL}" != "Y" -a "${GLOBAL_ZONE_ONLY}" = "Y" ]; then FLAG="-G"; fi
            if [ "${INSTALL}" = "Y" ] && [ "${GLOBAL_ZONE_ONLY}" != "Y" ] && [ -x /usr/sbin/zoneadm ] && \
               [ "`/usr/sbin/zoneadm list -p | grep 0:global > /dev/null; echo $?`" = "0" ]; then
                # fresh install from global zone into all zones 
                if do_pkgadd ${FLAG} -a ${ADMIN_FILE} -n -d ${VAR_TMP} CentrifyDC 2>> ${LOG_FILE}; then
                    PKG_I_LIST=`echo ${PKG_I_LIST} | sed 's/CentrifyDC //'`
                    do_pkgadd ${FLAG} -a ${ADMIN_FILE} -n -d ${VAR_TMP} ${PKG_I_LIST} 2>> ${LOG_FILE}
                fi
            else
                do_pkgadd ${FLAG} -a ${ADMIN_FILE} -n -d ${VAR_TMP} ${PKG_I_LIST} 2>> ${LOG_FILE}
            fi
            RC=$?
            sleep 5
        fi
        ;;
    hpux)
        if [ "$1" != "all" ]; then
            echo "Unzipping ${PKG_DIR}${PKG_FILE} to /var/tmp/centrifydc* ..." | tee -a ${LOG_FILE}
            PKG_DEPOT="`echo ${PKG_FILE} | sed 's/\.gz//'`"
            cp ${PKG_DIR}${PKG_FILE} ${VAR_TMP}
            if [ "$?" != "0" ]; then return ${FALSE}; fi
            ( cd ${VAR_TMP} && gunzip ${PKG_FILE} )
            if [ "$?" != "0" ]; then return ${FALSE}; fi
        fi
        if [ "$2" = "spool" ]; then
            # spool single package
            echo Spooling ${1} ... | tee -a  ${LOG_FILE}
            # If CentrifyDC is not going to be reinstalled or upgraded,
            # enforce_dependencies must be set to false. As swcopy or
            # swinstall will check the dependency packages in the spool dir.
            if [ "${INSTALL}" = "K" ] || \
                [ "${INSTALL}" = "N" -a "${INSTALLED}" = "Y" ] ; then
                SWCOPY_X_OPTION="-x enforce_dependencies=false"
            else
                SWCOPY_X_OPTION=""
            fi
            do_swcopy -s ${VAR_TMP}/${PKG_DEPOT} ${SWCOPY_X_OPTION} ${1}
            RC=$?
        elif [ "$2" = "" -a "$1" != "" -a "$1" != "all" ]; then
            # install single package
            echo Installing ${1} ... | tee -a ${LOG_FILE}
            do_swinstall -s ${VAR_TMP}/${PKG_DEPOT} ${X_OPTION_LIST} ${1}
            RC=$?
        elif [ "$1" = "all" ]; then
            # install all from spool dir
            echo Installing all from spool dir ... | tee -a ${LOG_FILE}
            do_swinstall ${X_OPTION_LIST} ${PKG_I_LIST}
            RC=$?
            rm -r /var/spool/sw/*
        fi
        ;;
    aix)
        if [ "$1" != "all" ]; then
            echo "Unzipping ${PKG_DIR}${PKG_FILE} to /var/tmp/centrifydc* ..." | tee -a ${LOG_FILE}
            if [ -f ${VAR_TMP}/.toc ]; then rm -f ${VAR_TMP}/.toc; fi
            cp ${PKG_DIR}${PKG_FILE} ${VAR_TMP}
            if [ "$?" != "0" ]; then return ${FALSE}; fi
            ( cd ${VAR_TMP} && gunzip ${PKG_FILE} )
            if [ "$?" != "0" ]; then return ${FALSE}; fi
        fi
        if [ "${OS_REV}" != "aix4.3" ]; then FLAG="Y"; fi
        if [ "$2" = "spool" ]; then
            # spool single package
            echo no spooling on AIX ... >> ${LOG_FILE}
            RC=0
        elif [ "$2" = "" -a "$1" != "" -a "$1" != "all" ]; then
            # install single package
            if [ "${1}" = "CentrifyDA.core" ]; then
                echo Installing ${1} ${ADD_ON_VER} ... | tee -a ${LOG_FILE}
            else
                echo Installing ${1} ${CDC_VER} ... | tee -a ${LOG_FILE}
            fi
            installp ${FORCE_OPTION} -a${FLAG} -d ${VAR_TMP} $1                >> ${LOG_FILE} 2>> ${LOG_FILE}
            RC=$?
        elif [ "$1" = "all" ]; then
            # install all from spool dir
            echo Installing all from spool dir ... | tee -a ${LOG_FILE}
            installp ${FORCE_OPTION} -a${FLAG} -d ${VAR_TMP} all               >> ${LOG_FILE} 2>> ${LOG_FILE}
            RC=$?
        fi
        ;;
    darwin)
        echo $ECHO_FLAG "\nUnzipping packages to /private/var/tmp/centrifydc* ..." | tee -a ${LOG_FILE}
        cp ${PKG_FILE_LIST} ${VAR_TMP}
        if [ "$?" != "0" ]; then rm -rf ${VAR_TMP}; return ${FALSE}; fi
        gunzip --quiet ${VAR_TMP}/centrifydc-*${CDC_VER}-mac${PKG_OS_REV}*.tgz
        if [ "$?" != "0" ]; then rm -rf ${VAR_TMP}; return ${FALSE}; fi
        for file in `ls ${VAR_TMP}/*.tar`
        do
            echo $ECHO_FLAG "\nInstalling from $file ..." | tee -a ${LOG_FILE}
            tar -C / ${FLAG} -xf $file
            if [ $? -ne 0 ]; then
                RC=1
            else
                RC=0
                tar -tf $file | sed 's/\.\//\//g' > $file.lst
                rm -f $file
                check_list_file $file
            fi
        done
        ;;
    esac
    echo INFO: install/upgrade RC=${RC} >> ${LOG_FILE}
    if [ "${RC}" != "0" ]; then return ${FALSE}; fi
    return ${TRUE}
} # do_install()

### check if installed package has a list file (mac os)
check_list_file ()
{
    echo $ECHO_FLAG "\ninstall-express.sh: check_list_file: " >> ${LOG_FILE}
        if [ "`echo ${CDC_VER} | grep '-' 2> /dev/null`" != "" ]; then
            ### installing package with long version number
            LIST_FILE_NAME="`basename $1 | sed s/tar/tgz/`.lst"
            if [ "`cat ${1}.lst | grep ${LIST_FILE_NAME} 2> /dev/null`" != "" ]; then
                debug_echo "Found package list file /usr/share/centrifydc/${LIST_FILE_NAME}"
            else
                echo "Could not find list file in the package." >> ${LOG_FILE}
                echo "Generating package list file ..." >> ${LOG_FILE}
                echo "/usr/share/centrifydc/${LIST_FILE_NAME}" >> ${1}.lst
                cp ${1}.lst /usr/share/centrifydc/`basename ${1} | sed s/tar/tgz/`.lst
            fi
        else
            if [ "`basename $1 | cut -d'-' -f2`" = "${CDC_VER}" ]; then
                ### installing core package with short version number
                BUILD_NUMBER="`/usr/bin/adinfo --version | cut -d' ' -f3 | cut -d- -f2`"
                LIST_FILE_NAME_FIRST="`basename $1 | cut -d'-' -f1-2`"
                LIST_FILE_NAME_SECOND="`basename $1 | cut -d'-' -f3-4 | sed s/tar/tgz/`"
            else
                ### installing add-on package with short version number
                if [ "`basename $1 | cut -d'-' -f2`" = "adfixid" ]; then
                    BUILD_NUMBER="`/usr/share/centrifydc/bin/adfixid --version | cut -d' ' -f2 | cut -d- -f2`"
                else
                    BUILD_NUMBER=000
                fi
                LIST_FILE_NAME_FIRST="`basename $1 | cut -d'-' -f1-3`"
                LIST_FILE_NAME_SECOND="`basename $1 | cut -d'-' -f4-5 | sed s/tar/tgz/`"
            fi
            LIST_FILE_NAME=`cat ${1}.lst | grep ${LIST_FILE_NAME_FIRST} 2> /dev/null | grep ${LIST_FILE_NAME_SECOND} 2> /dev/null`
            if [ "${LIST_FILE_NAME}" != "" ]; then
                debug_echo "Found package list file ${LIST_FILE_NAME}"
            else
                echo "Could not find list file in the package." >> ${LOG_FILE}
                echo "Generating package list file ..." >> ${LOG_FILE}
                echo "/usr/share/centrifydc/`basename ${1} | sed -e s/${CDC_VER}/${CDC_VER}-${BUILD_NUMBER}/ -e s/tar/tgz/`.lst" >> ${1}.lst
                cp ${1}.lst /usr/share/centrifydc/`basename ${1} | sed s/${CDC_VER}/${CDC_VER}-${BUILD_NUMBER}/ | sed s/tar/tgz/`.lst
            fi
        fi
    return $TRUE
}

### Pre-uninstall steps
do_preremove () 
{
    if [ "$1" = "" ]; then
        echo $ECHO_FLAG "\ninstall-express.sh: do_preremove: " >> ${LOG_FILE}

        if [ "${TARGET_OS}" = "darwin" ]; then
            if [ "${OS_REV}" = "10.3" ]; then
                DIR="/System/Library/StartupItems/LoginWindow"
                if [ -f ${DIR}/StartupParameters.plist ]; then
                    if [ ! -f ${DIR}/StartupParameters.plist.centrifydc ]; then
                        cp -p ${DIR}/StartupParameters.plist \
                              ${DIR}/StartupParameters.plist.centrifydc
                    fi
                    cat ${DIR}/StartupParameters.plist \
                        | grep Requires | grep DirectoryServices > /dev/null
                    if [ "$?" = "0" ]; then
                        echo reverting ${DIR}/StartupParameters.plist >> ${LOG_FILE}
                        # create file with original ownership and permissions
                        cp -p ${DIR}/StartupParameters.plist \
                              ${DIR}/StartupParameters.plist.tmp
                        cat ${DIR}/StartupParameters.plist \
                            | sed '/Requires/ { s/, "DirectoryServices"//; } ' \
                            > ${DIR}/StartupParameters.plist.tmp
                        mv ${DIR}/StartupParameters.plist.tmp \
                           ${DIR}/StartupParameters.plist
                    fi
                fi
            fi
            echo "Removing /etc/centrifydc/*.ovr files ..." >> ${LOG_FILE}
            if [ -f /etc/centrifydc/passwd.ovr ]; then rm -f /etc/centrifydc/passwd.ovr >> ${LOG_FILE}; fi
            if [ -f /etc/centrifydc/group.ovr ]; then rm -f /etc/centrifydc/group.ovr >> ${LOG_FILE}; fi

            if [ -f /etc/shells ]; then
                echo removing /usr/bin/dzsh from /etc/shells ... >> ${LOG_FILE}
                cat /etc/shells | sed '/\/usr\/bin\/dzsh/d' > /etc/shells.tmp
                mv /etc/shells.tmp /etc/shells
            fi
        elif [ "${OS_REV}" = "aix6.1" -o "${OS_REV}" = "aix7.1" ]; then
            fix_wpar
        fi

        # turn addebug off
        ADDEBUG="/usr/share/centrifydc/bin/addebug"
        ${ADDEBUG} | grep off  >> ${LOG_FILE} 2>> ${LOG_FILE}
        if [ $? -ne 0 ]; then
            echo $ECHO_FLAG "Disabling addebug ..." >> ${LOG_FILE}
            if [ "${TARGET_OS}" = "darwin" ]; then
                if [ -f /usr/share/centrifydc/bin/cdcdebug ]; then
                    ADDEBUG="/usr/share/centrifydc/bin/cdcdebug"
                fi
            fi
            ${ADDEBUG} off >> ${LOG_FILE} 2>> ${LOG_FILE}
            if [ $? -ne 0 ]; then
                echo $ECHO_FLAG "\nWARNING: Cannot disable addebug" >> ${LOG_FILE}
            fi
        fi
                
        # disable Smart Card support
        if [ "${TARGET_OS}" = "darwin" ]; then
            SCTOOL="/usr/bin/sctool"
            ${SCTOOL} -s | grep -i enable  >> ${LOG_FILE} 2>> ${LOG_FILE}
            if [ "$?" = "0" ]; then
                echo $ECHO_FLAG "Disabling Smart Card support ..." >> ${LOG_FILE}
                ${SCTOOL} -d >> ${LOG_FILE} 2>> ${LOG_FILE}
            fi
        fi

    elif [ "$1" = "cda" ]; then
        echo $ECHO_FLAG "\ninstall-express.sh: do_preremove: $1: " >> ${LOG_FILE}
        if [ -f /usr/share/centrifydc/bin/uninstall-da.sh ]; then rm -f /usr/share/centrifydc/bin/uninstall-da.sh; fi
    else ### add-on
        echo $ECHO_FLAG "\ninstall-express.sh: do_preremove: $1: skipping ..." >> ${LOG_FILE}
    fi
    return ${TRUE}
} # do_preremove()

### Post-uninstall steps
do_postremove () 
{
    if [ "$1" = "" ]; then
        echo $ECHO_FLAG "\ninstall-express.sh: do_postremove: " >> ${LOG_FILE}
        if [ "${TARGET_OS}" = "darwin" ]; then
            /usr/bin/defaults delete /Library/Preferences/DirectoryService/DirectoryService "Centrify DirectControl" 2>&1 >> ${LOG_FILE}
        else
            echo "skipping ..." >> ${LOG_FILE}
        fi
        if [ -f /usr/share/centrifydc/bin/uninstall.sh ]; then rm -f /usr/share/centrifydc/bin/uninstall.sh; fi
        restart_mcafee_agent
    elif [ "$1" = "CentrifyDA" ]; then
        echo $ECHO_FLAG "\ninstall-express.sh: do_postremove: $1: " >> ${LOG_FILE}
        for tries in 1 2 3; do
            echo $ECHO_FLAG "making sure dad is not running ... " >> ${LOG_FILE}
            dadPid=`ps -ae | awk '$4 ~ /^dad$/ { print $1; }'`
            if [ ! -z "$dadPid" ]; then
                if [ $tries -eq 3 ]; then
                    kill -9 $dadPid >> ${LOG_FILE} 2>> ${LOG_FILE}
                else
                    kill $dadPid >> ${LOG_FILE} 2>> ${LOG_FILE}
                    sleep 5
                fi
            else
                break
            fi
        done
    elif [ "$1" = "CentrifyDC-openssh" ]; then
        echo $ECHO_FLAG "\ninstall-express.sh: do_postremove: $1: " >> ${LOG_FILE}
        if [ -f /etc/pam.d/sshd.pre_cdc ]; then
            echo "INFO: restoring /etc/pam.d/sshd from /etc/pam.d/sshd.pre_cdc ..." >> ${LOG_FILE}
            mv /etc/pam.d/sshd.pre_cdc /etc/pam.d/sshd
        fi
    else ### add-on
        echo $ECHO_FLAG "\ninstall-express.sh: do_postremove: $1: skipping ..." >> ${LOG_FILE}
    fi
    return ${TRUE}
}

### ask to confirm then do uninstall/remove/erase
do_remove_main ()
{
    echo $ECHO_FLAG "\ninstall-express.sh: do_remove_main: " >> ${LOG_FILE}
    echo preparing  for uninstall ... | tee -a ${LOG_FILE}
    if [ "${INSTALLED}" != "Y" ]; then is_installed; fi
    if [ "${INSTALLED}" = "Y" ]; then
        if [ -z "${ADD_ON_INSTALLED}" ]; then is_addon_installed; fi
        INSTALLED="Y" # core is installed so keep it set to "Y"
        if [ "${SILENT}" = "NO" ]; then
            if [ "${ADD_ON_INSTALLED}" != "" ]; then
                echo $ECHO_FLAG "\nWARNING:" | tee -a ${LOG_FILE}
                echo $ECHO_FLAG "The following Centrify DirectControl add-on package(s) depend on CentrifyDC" | tee -a ${LOG_FILE}
                echo $ECHO_FLAG "core package and will be also removed:" | tee -a ${LOG_FILE}
                for ADD_ON_PKG in ${ADD_ON_INSTALLED}; do
                    echo $ECHO_FLAG ${ADD_ON_PKG} | tee -a ${LOG_FILE}
                done
            fi
            QUESTION="Do you want to uninstall Centrify DirectControl (CentrifyDC-${CUR_VER}) \nfrom this computer? (Q|Y|N) [N]:\c"
            ANSWER=""
            while [ "${ANSWER}" != "Y" -a "${ANSWER}" != "y" ]
            do
                echo ${ECHO_FLAG} "${QUESTION}"
                read ANSWER
                if [ "${ANSWER}" = "q" -o "${ANSWER}" = "Q" ]; then do_quit; fi
                if [ "${ANSWER}" = "" -o "${ANSWER}" = "n" -o "${ANSWER}" = "N" ]; then umask_restore; do_exit $CODE_NUN; fi
            done
            QUESTION="Reboot the computer after uninstall? (Q|Y|N) [Y]:\c"; do_ask_YorN; REBOOT=${ANSWER}
        else
            if [ "${ADD_ON_INSTALLED}" != "" -a "${UNINSTALL}" = "" ]; then
                ### silent mode, add-on(s) installed, config file has INSTALL=E but UNINSTALL is not set
                echo $ECHO_FLAG "\nERROR:" | tee -a ${LOG_FILE}
                echo $ECHO_FLAG "Found the next add-on package:" | tee -a ${LOG_FILE}
                for ADD_ON_PKG in ${ADD_ON_INSTALLED}; do
                    echo $ECHO_FLAG ${ADD_ON_PKG}
                done
                echo $ECHO_FLAG "Please define UNINSTALL=Y in config file to allow" | tee -a ${LOG_FILE}
                echo $ECHO_FLAG "complete uninstall of all Centrify DirectControl packages." | tee -a ${LOG_FILE}
                do_error $CODE_ESU
            fi
            ### force to leave domain if computer joined
            if test -s ${VAR}/centrifydc/kset.domain; then
                echo $ECHO_FLAG "\nWARNING: non-interactive uninstall, forcing to leave domain ..." | tee -a ${LOG_FILE}
                echo $ECHO_FLAG "\nADINFO:" >> ${LOG_FILE}
                /usr/bin/adinfo >> ${LOG_FILE}
                /usr/sbin/adleave -f
            fi
            if [ "${ADD_ON_INSTALLED}" != "" ]; then
                echo $ECHO_FLAG "\nWARNING:" | tee -a ${LOG_FILE}
                echo $ECHO_FLAG "The following Centrify DirectControl add-on package(s) depend on CentrifyDC" | tee -a ${LOG_FILE}
                echo $ECHO_FLAG "core package and will be also removed:" | tee -a ${LOG_FILE}
                for ADD_ON_PKG in ${ADD_ON_INSTALLED}; do
                    echo $ECHO_FLAG ${ADD_ON_PKG}
                done
            fi
        fi
        if [ "${ADD_ON_INSTALLED}" != "" ]; then
            ### remove add-on packages first
            echo ""
            for ADD_ON_PKG in ${ADD_ON_INSTALLED}; do
                ADD_ON_PKG_NAME="`echo ${ADD_ON_PKG} | cut -d '-' -f1`"
                if [ "${TARGET_OS}" != "aix" ] && \
                   [ "${ADD_ON_PKG_NAME}" != "CentrifyDA" -a "${ADD_ON_PKG_NAME}" != "centrifyda" ]; then
                    ADD_ON_PKG_NAME="`echo ${ADD_ON_PKG} | cut -d '-' -f1-2`"
                fi
                do_preremove  ${ADD_ON_PKG_NAME}   || { echo "pre-uninstall script failed ...";    do_error $CODE_EUN; }
                do_remove     ${ADD_ON_PKG_NAME}   || { echo "uninstalling CentrifyDC failed ..."; do_error $CODE_EUN; }
                do_postremove ${ADD_ON_PKG_NAME}   || { echo "post-uninstall script failed ...";   do_error $CODE_EUN; }
            done
        fi
        ### remove core package
        do_preremove     || { echo "pre-uninstall script failed ...";    do_error $CODE_EUN; }
        do_remove        || { echo "uninstalling CentrifyDC failed ..."; do_error $CODE_EUN; }
        do_postremove    || { echo "post-uninstall script failed ...";   do_error $CODE_EUN; }
        echo Uninstall successful. | tee -a ${LOG_FILE}
        if [ "${REBOOT}" = "Y" ]; then
            do_reboot   || { echo "rebooting failed ..."; do_error $CODE_EUN; }
        else
            # On Mac, kill loginwindow if no user loged in via console
            if [ "${TARGET_OS}" = "darwin" ]; then
                who | grep console > /dev/null 2>&1
                if [ $? -ne 0 ]; then
                    echo "Killing loginwindow..."| tee -a ${LOG_FILE}
                    killall loginwindow
                    if [ $? -ne 0 ]; then
                        echo "Failed to kill loginwindow."| tee -a ${LOG_FILE}
                    else
                        echo "Succeeded in killing loginwindow."| tee -a ${LOG_FILE}
                    fi
                fi
            fi
        fi
        do_exit $CODE_SUN
        # do_exit() never returs
    elif [ "${ADD_ON_INSTALLED}" != "" ]; then
        ### CDC agent is not installed but found add-on(s)
        missing_agent
        # missing_agent() never returs
    else
        echo ${ECHO_FLAG} "ERROR: Centrify DirectControl is not installed." | tee -a ${LOG_FILE}
        do_error $CODE_NUN
        # do_error() never returns
    fi
} # do_remove_main()

### Uninstall Centrify DirectControl suite
do_remove () 
{
    if [ "$1" = "" ]; then
        ### removing core package
        echo $ECHO_FLAG "\ninstall-express.sh: do_remove: " >> ${LOG_FILE}
        if [ -d ${VAR_TMP} ]; then
            rm -rf ${VAR_TMP}
        fi
        mkdir -p ${VAR_TMP}
        chmod 750 ${VAR_TMP}
        if test -s ${VAR}/centrifydc/kset.domain; then
            echo
            echo This computer is currently joined to the Active Directory domain. | tee -a ${LOG_FILE}
            echo To remove the software cleanly you should leave the domain. | tee -a ${LOG_FILE}
            echo To do so you need to provide AD user name and password. Running 'adleave' ... | tee -a ${LOG_FILE}
            USERID=administrator
            QUESTION="    Enter the Active Directory authorized user [administrator]: \c"; do_ask
            if [ "${ANSWER}" != "" ]; then USERID=${ANSWER}; fi
            /usr/sbin/adleave -u ${USERID}
        fi
        if test -s ${VAR}/centrifydc/kset.domain; then
            echo The attempt to leave the domain failed. Do you want to retry? | tee -a ${LOG_FILE}
            echo Running 'adleave' ... | tee -a ${LOG_FILE}
            USERID=administrator
            QUESTION="    Enter the Active Directory authorized user [administrator]: \c"; do_ask
            if [ "${ANSWER}" != "" ]; then USERID=${ANSWER}; fi
            /usr/sbin/adleave -u ${USERID}
        fi
        if test -s ${VAR}/centrifydc/kset.domain; then
            echo The attempt to leave the domain failed. The adleave command will run | tee -a ${LOG_FILE}
            echo using the --force option. This option removes and resets only local DirectControl files. | tee -a ${LOG_FILE}
            echo After uninstalling, you will need to manually disable the computer account in Active Directory. | tee -a ${LOG_FILE}
            echo Forcing to leave AD domain now ... | tee -a ${LOG_FILE}
            /usr/sbin/adleave -f
        fi
    
        #now that we left the domain, we can safely deregister dsplugin...    
        if [ "${TARGET_OS}" = "darwin" ]; then
            echo ${ECHO_FLAG} "Unregistering Directory Service plugin ..." | tee -a ${LOG_FILE}
            /usr/share/centrifydc/bin/dsconfig off | tee -a ${LOG_FILE}
            echo ${ECHO_FLAG} "" | tee -a ${LOG_FILE}
            echo ${ECHO_FLAG} "WARNING: The Centrify DirectControl DirectoryService plugin has been removed" | tee -a ${LOG_FILE}
            echo ${ECHO_FLAG} "If you had Directory Access (or Directory Utility) running during uninstall,"   | tee -a ${LOG_FILE}
            echo ${ECHO_FLAG} "the list of plugins might not reflect that change."                           | tee -a ${LOG_FILE}
            echo ${ECHO_FLAG} "To see the correct state, please quit (CMD-q) and restart Directory Access"   | tee -a ${LOG_FILE}
            echo ${ECHO_FLAG} "(or Directory Utility) after CentrifyDC removal is complete"                  | tee -a ${LOG_FILE}
            echo ${ECHO_FLAG} "" | tee -a ${LOG_FILE}
        fi
        
        echo Uninstalling Centrify DirectControl ... | tee -a ${LOG_FILE}
        case "${TARGET_OS}" in
        linux)
            if [ "${PKG_OS_REV}" = "deb5" ]; then
                dpkg -P centrifydc >> ${LOG_FILE} 2>> ${LOG_FILE}
            else
                rpm -e CentrifyDC
            fi
            if [ "$?" != "0" ]; then do_error; fi
            ;;
        solaris)
            create_admin
            /usr/sbin/pkgrm -a ${ADMIN_FILE} -n CentrifyDC  2>> ${LOG_FILE}
            if [ "$?" != "0" ]; then do_error; fi
            sleep 5
            ;;
        hpux)
            /usr/sbin/swremove CentrifyDC >> ${LOG_FILE} 2>> ${LOG_FILE}
            if [ "$?" != "0" ]; then do_error; fi
            ;;
        aix)
            installp -u CentrifyDC.core >> ${LOG_FILE} 2>> ${LOG_FILE}
            if [ "$?" != "0" ]; then do_error; fi
            ;;
        darwin)
            remove_tar_package || { remove_tar_package_old; }
            ;;
        esac
        rm -rf ${VAR_TMP}
    else ### if [ "$1" = "" ]
        ### removing add-on package
        echo Uninstalling $1 ... | tee -a ${LOG_FILE}
        case "${TARGET_OS}" in
        linux)
            if [ "${PKG_OS_REV}" = "deb5" ]; then
                dpkg -P $1 >> ${LOG_FILE} 2>> ${LOG_FILE}
            else
                rpm -e $1 >> ${LOG_FILE} 2>> ${LOG_FILE}
            fi
            if [ "$?" != "0" ]; then do_error; fi
            ;;
        solaris)
            create_admin
            /usr/sbin/pkgrm -a ${ADMIN_FILE} -n $1  2>> ${LOG_FILE}
            if [ "$?" != "0" ]; then do_error; fi
            sleep 5
            ;;
        hpux)
            swremove $1 >> ${LOG_FILE} 2>> ${LOG_FILE}
            if [ "$?" != "0" ]; then do_error; fi
            ;;
        aix)
            installp -u $1 >> ${LOG_FILE} 2>> ${LOG_FILE}
            if [ "$?" != "0" ]; then do_error; fi
            ;;
        darwin)
            remove_tar_package $1 || { remove_tar_package_old $1; }
            ;;
        esac
    fi ### if [ "$1" = "" ]
    return ${TRUE}
} # do_remove()

# mac os uninstall
remove_tar_package ()
{
    echo $ECHO_FLAG "\ninstall-express.sh: remove_tar_package: " >> ${LOG_FILE}
    if [ "$1" = "" ]; then
        LIST_FILE="/usr/share/centrifydc/centrifydc-[0-9]*-mac${PKG_OS_REV}.tgz.lst"
        if [ -f /private/etc/centrifydc/centrifydc.conf.bak ]; then rm -f /private/etc/centrifydc/centrifydc.conf.bak; fi # GP backup
        if [ -d /private/etc/centrifydc/new ]; then rm -Rf /private/etc/centrifydc/new; fi # upgrade temp dir
        if [ -d /private/etc/centrifydc/custom ]; then rm -Rf /private/etc/centrifydc/custom; fi # upgrade temp dir
        if [ -d /private/var/centrifydc/previous ]; then rm -Rf /private/var/centrifydc/previous; fi # previous adjoin files
    else
        LIST_FILE="/usr/share/centrifydc/`echo $1 | tr A-Z a-z`-[0-9]*-mac${PKG_OS_REV}.tgz.lst"
    fi
    LIST_FILE_NAME="`ls -t ${LIST_FILE} 2>> /dev/null`"
    LIST_FILE_NUMBER="`echo ${LIST_FILE_NAME} | wc -w | sed 's/^[ ^t]*//'`"
    debug_echo LIST_FILE_NAME=${LIST_FILE_NAME}
    if [ ${LIST_FILE_NUMBER} -eq 0 ]; then
        ### try old .lst file with ARCH
        echo $ECHO_FLAG "\nINFO: Couldn't find package list file ${LIST_FILE}, trying old name ..." >> ${LOG_FILE}
        if [ "$1" = "" ]; then
            LIST_FILE="/usr/share/centrifydc/centrifydc-[0-9]*-mac${PKG_OS_REV}-${PKG_ARCH}.tgz.lst"
        else
            LIST_FILE="/usr/share/centrifydc/`echo $1 | tr A-Z a-z`-[0-9]*-mac${PKG_OS_REV}-${PKG_ARCH}.tgz.lst"
        fi
        LIST_FILE_NAME="`ls -t ${LIST_FILE} 2>> /dev/null`"
        LIST_FILE_NUMBER="`echo ${LIST_FILE_NAME} | wc -w | sed 's/^[ ^t]*//'`"
        debug_echo LIST_FILE_NAME=${LIST_FILE_NAME}
        if [ ${LIST_FILE_NUMBER} -eq 0 ]; then
            echo $ECHO_FLAG "\nWARNING: Couldn't find package list file ${LIST_FILE} ..." >> ${LOG_FILE}
            return ${FALSE}
        fi
        echo $ECHO_FLAG "      ... found ${LIST_FILE}" >> ${LOG_FILE}
    fi
    if [ ${LIST_FILE_NUMBER} -gt 1 ]; then
        echo $ECHO_FLAG "\nWARNING: Found more than one package list file:" >> ${LOG_FILE}
        echo $ECHO_FLAG "`ls -l ${LIST_FILE}`"                              >> ${LOG_FILE}
        echo $ECHO_FLAG "Using the latest list file for uninstal ..."       >> ${LOG_FILE}
        LIST_FILE_NAME_LATEST=
        for j in ${LIST_FILE_NAME}
        do 
            if [ "${LIST_FILE_NAME_LATEST}" = "" ]; then
                ### take first name from the list (the latest)
                LIST_FILE_NAME_LATEST=$j
            else
                ### remove all .lst files but the laters one
                rm -f $j
            fi
        done
        LIST_FILE_NUMBER=1
        LIST_FILE_NAME=${LIST_FILE_NAME_LATEST}
    fi
    if [ ${LIST_FILE_NUMBER} -eq 1 ]; then
        for file in `cat ${LIST_FILE_NAME}`
        do
            if [ -f $file -o -h $file ]; then
                debug_echo "removing file: $file"
                rm -f $file
            fi
            DIR_NAME="`dirname $file | grep entrify 2> /dev/null`"
            ### removing empty dirs recursively, one round for each dir level in the path
            for i in `echo ${DIR_NAME} | sed 's/\// /g'`
            do
                if [ "${DIR_NAME}" != "" ] && [ -d ${DIR_NAME} ]; then
                    if [ "${DIR_NAME}" = "StartupItems" ]; then break; fi
                    ### remove dir if it's empty
                    if [ `ls ${DIR_NAME}  | wc -w | sed 's/^[ ^t]*//'` -eq 0 ]; then
                        debug_echo "removing dir: ${DIR_NAME}"
                        rmdir ${DIR_NAME}
                    else
                        break
                    fi
                    ### shift to the parent dir
                    DIR_NAME="`dirname ${DIR_NAME} | grep entrify 2> /dev/null`"
                fi
            done
        done
        rm -f ${LIST_FILE_NAME}
        if [ "$1" = "" ]; then
            LIST_FILE_NAME="`ls /usr/share/centrifydc/centrifydc-krb5lib-[0-9]*.tgz.lst 2> /dev/null`"
            if [ "${LIST_FILE_NAME}" != "" ]; then rm -f /usr/share/centrifydc/centrifydc-krb5lib-[0-9]*-mac${PKG_OS_REV}-${PKG_ARCH}.tgz.lst; fi
            RC=0
            if [ -d /usr/share/centrifydc ]; then rmdir /usr/share/centrifydc >> ${LOG_FILE} 2>> /dev/null; RC=$?; fi
            if [ $RC -ne 0 ]; then
                echo "WARNING: /usr/share/centrifydc is not empty:" >> ${LOG_FILE} 2>> ${LOG_FILE}
                ls -lR /usr/share/centrifydc >> ${LOG_FILE} 2>> ${LOG_FILE}
                echo "removing /usr/share/centrifydc anyway ..." >> ${LOG_FILE} 2>> ${LOG_FILE}
                rm -Rf /usr/share/centrifydc >> ${LOG_FILE} 2>> ${LOG_FILE}
            fi
            RC=0
            if [ -d /private/var/centrifydc ]; then rmdir /private/var/centrifydc >> ${LOG_FILE} 2>> /dev/null; RC=$?; fi
            if [ $RC -ne 0 ]; then
                echo "WARNING: /private/var/centrifydc is not empty:" >> ${LOG_FILE} 2>> ${LOG_FILE}
                ls -lR /private/var/centrifydc >> ${LOG_FILE} 2>> ${LOG_FILE}
                echo "removing /private/var/centrifydc anyway ..." >> ${LOG_FILE} 2>> ${LOG_FILE}
                rm -Rf /private/var/centrifydc >> ${LOG_FILE} 2>> ${LOG_FILE}
            fi
            RC=0
            if [ -d /private/etc/centrifydc ]; then rmdir /private/etc/centrifydc >> ${LOG_FILE} 2>> /dev/null; RC=$?; fi
            if [ $RC -ne 0 ]; then
                echo "WARNING: /private/etc/centrifydc is not empty:" >> ${LOG_FILE} 2>> ${LOG_FILE}
                ls -lR /private/etc/centrifydc >> ${LOG_FILE} 2>> ${LOG_FILE}
                echo "removing /private/etc/centrifydc anyway ..." >> ${LOG_FILE} 2>> ${LOG_FILE}
                rm -Rf /private/etc/centrifydc >> ${LOG_FILE} 2>> ${LOG_FILE}
            fi
            RC=0
            rm -Rf /private/etc/cma.d/S_CENTDC*
            if [ -d /private/etc/cma.d ]; then rmdir /private/etc/cma.d >> ${LOG_FILE} 2>> /dev/null; RC=$?; fi
            if [ $RC -ne 0 ]; then
                echo "INFO: /private/etc/cma.d is not empty:" >> ${LOG_FILE} 2>> ${LOG_FILE}
                ls -lR /private/etc/cma.d >> ${LOG_FILE} 2>> ${LOG_FILE}
            fi
        fi
    fi

    if [ "${TARGET_OS}" = "darwin" ]; then
        #remove the package receipt, in case we were installed from dmg...
        rm -Rf /Library/Receipts/CentrifyDC*.pkg 
        rm -f /var/db/receipts/com.centrify.centrifydc.*
    fi
    return ${TRUE}
} # remove_tar_package()

# mac os uninstall
remove_tar_package_old ()
{
    echo $ECHO_FLAG "\ninstall-express.sh: remove_tar_package_old: " >> ${LOG_FILE}
    if [ "$1" = "" ]; then
        rm -f  /Library/LaunchDaemons/centrifydc.plist 2>> ${LOG_FILE}
        rm -Rf /Library/StartupItems/CentrifyDC/ 2>> ${LOG_FILE}
        rm -Rf /System/Library/Frameworks/DirectoryService.framework/Resources/Plugins/CentrifyDC.dsplug 2>> ${LOG_FILE}
        rm -f  /private/etc/pam.d/centrifydc 2>> ${LOG_FILE}
        rm -f  /usr/lib/pam/pam_centrifydc.* 2>> ${LOG_FILE}
        rm -Rf /private/etc/centrifydc 2>> ${LOG_FILE}
        rm -Rf /private/var/centrifydc 2>> ${LOG_FILE}
        rm -Rf /usr/share/centrifydc 2>> ${LOG_FILE}
        rm -f  /usr/bin/adgpresult 2>> ${LOG_FILE}
        rm -f  /usr/bin/adgpupdate 2>> ${LOG_FILE}
        rm -f  /usr/bin/adinfo 2>> ${LOG_FILE}
        rm -f  /usr/bin/adfinddomain 2>> ${LOG_FILE}
        rm -f  /usr/bin/adpasswd 2>> ${LOG_FILE}
        rm -f  /usr/sbin/adclient 2>> ${LOG_FILE}
        rm -f  /usr/sbin/adflush 2>> ${LOG_FILE}
        rm -f  /usr/sbin/adjoin 2>> ${LOG_FILE}
        rm -f  /usr/sbin/adleave 2>> ${LOG_FILE}
        rm -f  /usr/share/man/man1/addebug.1 2>> ${LOG_FILE}
        rm -f  /usr/share/man/man1/adgpupdate.1 2>> ${LOG_FILE}
        rm -f  /usr/share/man/man1/adinfo.1 2>> ${LOG_FILE}
        rm -f  /usr/share/man/man1/adfixid.1 2>> ${LOG_FILE}
        rm -f  /usr/share/man/man1/adjoin.1 2>> ${LOG_FILE}
        rm -f  /usr/share/man/man1/adleave.1 2>> ${LOG_FILE}
        rm -f  /usr/share/man/man1/adpasswd.1 2>> ${LOG_FILE}
    elif [ "$1" = "CentrifyDC-krb5" ]; then
        rm -f /usr/share/centrifydc/kerberos/bin/[cfgrstuv]* 2>> ${LOG_FILE}
        rm -f /usr/share/centrifydc/kerberos/bin/k[ers]* 2>> ${LOG_FILE}
        rm -f /usr/share/centrifydc/kerberos/lib/libkadm* 2>> ${LOG_FILE}
        rm -f /usr/share/centrifydc/kerberos/man/man1/[cfrstv]* 2>> ${LOG_FILE}
        rm -f /usr/share/centrifydc/kerberos/man/man1/k[ers]* 2>> ${LOG_FILE}
        rm -Rf /usr/share/centrifydc/kerberos/include 2>> ${LOG_FILE}
        rm -Rf /usr/share/centrifydc/kerberos/man/man5 2>> ${LOG_FILE}
        rm -Rf /usr/share/centrifydc/kerberos/man/man8 2>> ${LOG_FILE}
        rm -Rf /usr/share/centrifydc/kerberos/sbin 2>> ${LOG_FILE}
        rm -Rf /usr/share/centrifydc/kerberos/share 2>> ${LOG_FILE}
    elif [ "$1" = "CentrifyDC-krb5lib" ]; then
        echo $ECHO_FLAG "\nWARNING: CentrifyDC-$1 should be removed by removing CentrifyDc agent." >> ${LOG_FILE}
    elif [ "$1" = "CentrifyDC-adfixid" ]; then
        rm -f /usr/share/centrifydc/bin/adfixid 2>> ${LOG_FILE}
        rm -f /usr/share/man/man1/adfixid.1 2>> ${LOG_FILE}
    elif [ "$1" = "CentrifyDC-utest" ]; then
        rm -Rf /usr/share/centrifydc/tests 2>> ${LOG_FILE}
    else
        echo $ECHO_FLAG "\nERROR: Unknown package $1; Don't know how to remove ..." >> ${LOG_FILE}
        return $FALSE
    fi
    #remove the package receipt, in case we were installed from dmg...
    rm -Rf /Library/Receipts/CentrifyDC*.pkg 
    rm -f /var/db/receipts/com.centrify.centrifydc.*
    return $TRUE
}

copy_installer () {
    cp -f ${THIS_PRG} /usr/share/centrifydc/bin/uninstall.sh >> ${LOG_FILE}
    chmod 550 /usr/share/centrifydc/bin/uninstall.sh >> ${LOG_FILE}
    if [ -f /usr/share/centrifydc/bin/install.sh ]; then rm -f /usr/share/centrifydc/bin/install.sh; fi
}

### Prepare for upgrade
do_preupgrade () 
{
    if [ "$1" = "" ]; then
        echo $ECHO_FLAG "\ninstall-express.sh: do_preupgrade: " >> ${LOG_FILE}
        if [ "${TARGET_OS}" = "darwin" ]; then
            echo "preparing for upgrade ..."
        
            # remove the old LaunchDaemon and StartupItem entry!
            if [ -f /Library/LaunchDaemons/centrifydc.plist ]; then
                rm -f /Library/LaunchDaemons/centrifydc.plist >> ${LOG_FILE}
            fi
            if [ -d /Library/StartupItems/CentrifyDC ]; then
                rm -rf /Library/StartupItems/CentrifyDC       >> ${LOG_FILE}
            fi

            # create /home if not exist. Don't link /home to /Users, because
            # it will cause problem on 10.4.
            if [ ! -e /home ]; then
                echo $ECHO_FLAG "/home does not exist. Create." >> ${LOG_FILE}
                mkdir /home 2>> ${LOG_FILE}
                chmod 755 /home 2>> ${LOG_FILE}
            fi

            # remove the old MCXSynthesizers
            if [ -d /System/Library/Frameworks/DirectoryService.framework/Resources/Plugins/CentrifyDC.dsplug/Contents/Resources/Synthesizers ]; then
                rm -Rf /System/Library/Frameworks/DirectoryService.framework/Resources/Plugins/CentrifyDC.dsplug/Contents/Resources/Synthesizers/* >> ${LOG_FILE}
            fi

            mkdir -p /private/var/centrifydc/upgrade >> ${LOG_FILE}
            CUR_VER=`/usr/sbin/adjoin --version | sed "s/CentrifyDC //"`
            
            # Remember the original cdc version            
            echo "${CUR_VER}" > /private/var/centrifydc/upgrade/CDC_VER_ORIG 2>> ${LOG_FILE}            

            chmod 755 /private/var/centrifydc >> ${LOG_FILE}
            echo Upgrading from ${CUR_VER} ... >> ${LOG_FILE}

            echo preserving centrifydc.conf ... >> ${LOG_FILE}
            mkdir -p /private/etc/centrifydc/custom >> ${LOG_FILE}
            cp -p /private/etc/centrifydc/*.* /private/etc/centrifydc/custom >> ${LOG_FILE}

            STATUS="off"
            if [ -f /private/var/centrifydc/upgrade/START ]; then
                rm /private/var/centrifydc/upgrade/START >> ${LOG_FILE}
            fi
            eval $CHECK_ADCLIENT >> ${LOG_FILE}
            if [ "$?" = "0" ]; then
                STATUS="on"
                touch /private/var/centrifydc/upgrade/START >> ${LOG_FILE}
            fi
            echo remove old smartcard setting ... >> ${LOG_FILE}
            /usr/share/centrifydc/mappers/machine/mac_mapper_smartcard.pl unmap boot

            echo adclient STATUS=${STATUS} >> ${LOG_FILE}
            if [ "${STATUS}" = "on" ]; then
                echo stopping adclient ... >> ${LOG_FILE}
                touch /private/var/centrifydc/upgrade/START >> ${LOG_FILE}
                /usr/share/centrifydc/bin/centrifydc stop >> ${LOG_FILE}
            fi
            if [ `echo ${CDC_VER} | cut -d. -f1` -ge 4 ]; then
                if [ -f /usr/share/centrifydc/mappers/user/filemounts.pl ]; then
                    rm -f /usr/share/centrifydc/mappers/user/filemounts.pl
                fi
            fi
        elif [ "${TARGET_OS}" = "aix" ]; then
            echo skipping ... >> ${LOG_FILE}
        else
            if [ "${TARGET_OS}" = "solaris" ]; then
                if [ -d /usr/share/centrifydc/libexec ]; then
                    /usr/sbin/pkgchk -l -p /usr/share/centrifydc/libexec | grep CentrifyDC-openssh > /dev/null
                    if [ "$?" = "0" ]; then
                        /usr/sbin/removef CentrifyDC-openssh /usr/share/centrifydc/libexec > /dev/null
                        /usr/sbin/removef -f CentrifyDC-openssh
                    fi
                    /usr/sbin/installf CentrifyDC /usr/share/centrifydc/libexec
                    INSTALLF="run"
                fi
                if [ "`compare_ver ${CDC_VER} 4; echo ${COMPARE}`" != "lt" ] &&
                   [ "`compare_ver ${CUR_VER} 4; echo ${COMPARE}`" = "lt" ]; then
                    if [ -f /usr/share/centrifydc/bin/adfixid ]; then
                        /usr/sbin/installf CentrifyDC /usr/share/centrifydc/bin/adfixid
                        INSTALLF="run"
                    fi
                    if [ -f /usr/share/man/man1/adfixid.1 ]; then
                        /usr/sbin/installf CentrifyDC /usr/share/man/man1/adfixid.1
                        INSTALLF="run"
                    fi
                    if [ -f /usr/sbin/adkeytab ]; then
                        /usr/sbin/installf CentrifyDC /usr/sbin/adkeytab
                        INSTALLF="run"
                    fi
                    if [ -f /usr/share/man/man1/adkeytab.1 ]; then
                        /usr/sbin/installf CentrifyDC /usr/share/man/man1/adkeytab.1
                        INSTALLF="run"
                    fi
                fi
                if [ "`compare_ver ${CDC_VER} 4.2; echo ${COMPARE}`" != "lt" ] &&
                   [ "`compare_ver ${CUR_VER} 4.2; echo ${COMPARE}`" = "lt" ]; then
                    if [ -f /usr/share/centrifydc/java/lib/centrifydc_japi.jar ]; then
                        /usr/sbin/pkgchk -l -p /usr/share/centrifydc/java/lib/centrifydc_japi.jar | grep CentrifyDC-web > /dev/null
                        if [ "$?" = "0" ]; then
                            /usr/sbin/removef CentrifyDC-web /usr/share/centrifydc/java/lib/centrifydc_japi.jar \
                                                   /usr/share/centrifydc/java/lib/centrifydc_jazman.jar \
                                                   /usr/share/centrifydc/java/lib/libcentrifydc_japi.so > /dev/null 2>> ${LOG_FILE}
                            /usr/sbin/removef -f CentrifyDC-web 2>> ${LOG_FILE}
                        fi
                        /usr/sbin/installf CentrifyDC /usr/share/centrifydc/java/lib/centrifydc_japi.jar 2>> ${LOG_FILE}
                        /usr/sbin/installf CentrifyDC /usr/share/centrifydc/java/lib/centrifydc_jazman.jar 2>> ${LOG_FILE}
                        /usr/sbin/installf CentrifyDC /usr/share/centrifydc/java/lib/libcentrifydc_japi.so 2>> ${LOG_FILE}
                        INSTALLF="run"
                    fi
                    if [ -f /usr/bin/adsmb ]; then
                        /usr/sbin/removef CentrifyDC /usr/bin/adsmb > /dev/null 2>> ${LOG_FILE}
                        /usr/sbin/removef -f CentrifyDC > /dev/null 2>> ${LOG_FILE}
                        mv -f /usr/bin/adsmb /usr/bin/adsmb.BK
                        ln -s /usr/bin/adsmb.BK /usr/bin/adsmb
                        /usr/sbin/installf CentrifyDC /usr/bin/adsmb > /dev/null 2>> ${LOG_FILE}
                        INSTALLF="run"
                    fi
                fi
                if [ "${INSTALLF}" = "run" ]; then
                    # installf is slow so run it once
                    /usr/sbin/installf -f CentrifyDC 2>> ${LOG_FILE}
                fi
            fi
            eval $CHECK_ADCLIENT >> ${LOG_FILE}
            if [ "$?" = "0" ]; then
                echo stopping adclient ... >> ${LOG_FILE}
                if [ -x /usr/share/centrifydc/bin/centrifydc ]; then
                    /usr/share/centrifydc/bin/centrifydc stop >> ${LOG_FILE} 2>> ${LOG_FILE}
                else
                    if [ "${TARGET_OS}" = "hpux" ]; then
                        /sbin/init.d/centrifydc stop >> ${LOG_FILE} 2>> ${LOG_FILE}
                    else
                        /etc/init.d/centrifydc stop >> ${LOG_FILE} 2>> ${LOG_FILE}
                    fi
                fi
                sleep 2
                if [ -f "/etc/nsswitch.conf.pre_cdc" ]; then
                    echo backing out /etc/nsswitch.conf ... >> ${LOG_FILE}
                    cp -p /etc/nsswitch.conf /etc/nsswitch.conf.upgrade >> ${LOG_FILE} 2>> ${LOG_FILE}
                    if [ $? -ne 0 ]; then
                       return ${FALSE}
                    fi
                    cp -p /etc/nsswitch.conf.pre_cdc /etc/nsswitch.conf >> ${LOG_FILE} 2>> ${LOG_FILE}
                    if [ $? -ne 0 ]; then
                        return ${FALSE}
                    fi
                fi
            fi
        fi
        ls -l /var/centrifydc/*.idx >> ${LOG_FILE} 2> /dev/null
        if [ "$?" = "0" ]; then
            echo removing *.idx files ... >> ${LOG_FILE}
            rm -f /var/centrifydc/*.idx >> ${LOG_FILE} 2>> ${LOG_FILE}
        fi
        ls -l /var/centrifydc/*.cache >> ${LOG_FILE} 2> /dev/null
        if [ "$?" = "0" ]; then
            echo removing *.cache files ... >> ${LOG_FILE}
            rm -f /var/centrifydc/*.cache >> ${LOG_FILE} 2>> ${LOG_FILE}
        fi
    elif [ "$1" = "CentrifyDA" ]; then
        echo $ECHO_FLAG "\ninstall-express.sh: do_preupgrade: $1: " >> ${LOG_FILE}
        echo $ECHO_FLAG checking DirectAudit status ... >> ${LOG_FILE}
        /usr/sbin/dacontrol | head -1 | grep NOT >> ${LOG_FILE} 2>> ${LOG_FILE}
        if [ $? -eq 0 ]; then
            echo $ECHO_FLAG DirectAudit is not enabled >> ${LOG_FILE}
        else
            echo $ECHO_FLAG WARNING: | tee -a ${LOG_FILE}
            echo $ECHO_FLAG Before upgrading DirectAudit you MUST disable auditing. | tee -a ${LOG_FILE}
            echo $ECHO_FLAG Please disable auditing and then retry. | tee -a ${LOG_FILE}
            echo $ECHO_FLAG Exiting ... | tee -a ${LOG_FILE}
            return ${FALSE}
        fi
    else ### add-on
        echo $ECHO_FLAG "\ninstall-express.sh: do_preupgrade: $1: skipping ..." >> ${LOG_FILE}
    fi
    return ${TRUE}
} # do_preupgrade()

### Post-upgrade configuration
do_postupgrade () 
{
    if [ "$1" = "" ]; then

    echo $ECHO_FLAG "\ninstall-express.sh: do_postupgrade: " >> ${LOG_FILE}
    if [ "${TARGET_OS}" = "darwin" ]; then
        echo "finishing upgrade ..."


        grep 'auto.schema.name.lower' \
            /private/etc/centrifydc/custom/centrifydc.conf > /dev/null 2>&1

        # auto.schema.name.lower is a new option. Set it to false
        # because we are upgrading.
        if [ "$?" -ne "0" ]; then
            echo "Set auto.schema.name.lower to false" >> ${LOG_FILE}
            sed -e '/# auto.schema.name.lower/ {
                        a\
                        auto.schema.name.lower: false
                    }' -i .bak /private/etc/centrifydc/centrifydc.conf

            # Remove the backup file created by sed
            rm -f /private/etc/centrifydc/centrifydc.conf.bak
        fi

        mkdir -p /private/etc/centrifydc/new >> ${LOG_FILE}
        mv -f /private/etc/centrifydc/centrifydc.conf /private/etc/centrifydc/new >> ${LOG_FILE}
        mv -f /private/etc/centrifydc/group.ignore /private/etc/centrifydc/new >> ${LOG_FILE}
        mv -f /private/etc/centrifydc/user.ignore /private/etc/centrifydc/new >> ${LOG_FILE}
        
        # Add http to adclient.krb5.service.principals if the original version less than 4.2.0
        if [ -s /private/var/centrifydc/upgrade/CDC_VER_ORIG ]; then
            CDC_VER_ORIG="`cat /private/var/centrifydc/upgrade/CDC_VER_ORIG | sed 's/[^0-9]*//g'`"
            if [ -n "${CDC_VER_ORIG}" ]; then
                if [ "${CDC_VER_ORIG}" -lt "420000" ]; then
                    # Enable adclient.krb5.service.principals in new centrifydc.conf.
                    # So that the http can be merged to original centrifydc.conf
                    NEWCDCCONF="/private/etc/centrifydc/new/centrifydc.conf"
                    TMPCDCCONF="${NEWCDCCONF}.tmp"
                    sed 's/##*[ ]*\(adclient\.krb5\.service\.principals.*\)/\1/g' ${NEWCDCCONF} > ${TMPCDCCONF} 2>> ${LOG_FILE}
                    mv -f ${TMPCDCCONF} ${NEWCDCCONF} 2>> ${LOG_FILE}
                fi
            fi
        fi
        
        echo merging centrifydc.conf ... >> ${LOG_FILE}
        /usr/share/centrifydc/bin/upgradeconf -r -c /private/etc/centrifydc/upgradeconf.conf \
                                                 /private/etc/centrifydc/custom/centrifydc.conf \
                                                 /private/etc/centrifydc/new/centrifydc.conf \
                                                 /private/etc/centrifydc/centrifydc.conf \
                                                 >> ${LOG_FILE} \
                                                 2>> ${LOG_FILE}
        if [ ! -s /etc/centrifydc/group.ignore ]; then
            echo "Restoring group.ignore from /etc/centrifydc/custom/ ..."  | tee -a ${LOG_FILE}
            cp -pf /etc/centrifydc/custom/group.ignore /etc/centrifydc/
        fi
        if [ ! -s /etc/centrifydc/user.ignore ]; then
            echo "Restoring user.ignore from /etc/centrifydc/custom/ ..."  | tee -a ${LOG_FILE}
            cp -pf /etc/centrifydc/custom/user.ignore /etc/centrifydc/
        fi

        echo executing fix_pam_rsh.sh ... >> ${LOG_FILE}
        if [ -f /usr/share/centrifydc/bin/fix_pam_rsh.sh ]; then
            /usr/share/centrifydc/bin/fix_pam_rsh.sh >> ${LOG_FILE}
        fi
        if [ -f /private/var/centrifydc/upgrade/START ]; then
            screensaver_file="/etc/pam.d/screensaver"

            echo "Cleaning up $screensaver_file ..." >> ${LOG_FILE}

            if [ -f "${screensaver_file}.pre_cdc" ]; then
                mv -f "${screensaver_file}.pre_cdc" \
                    "${screensaver_file}"
            fi

            # Just in case if screensaver still contains our entries.
            if [ -f "${screensaver_file}" ]; then
                sed -i .bak -E '/(pam_centrifydc.so|CentrifyDC)/d' \
                    "${screensaver_file}"
                rm -f "${screensaver_file}.bak"
            fi

            echo starting adclient ... >> ${LOG_FILE}
            /usr/share/centrifydc/bin/centrifydc start >> ${LOG_FILE}
            update_keytab

            #needed because we might have added new mechanisms 
            echo refreshing CentrifyPAM entries in /etc/authorization ... >> ${LOG_FILE}
            /System/Library/CoreServices/SecurityAgentPlugins/CentrifyPAM.bundle/Contents/Resources/config disable >> ${LOG_FILE} 2>> ${LOG_FILE}
            /System/Library/CoreServices/SecurityAgentPlugins/CentrifyPAM.bundle/Contents/Resources/config enable  >> ${LOG_FILE} 2>> ${LOG_FILE}
        fi
        rm -R /private/var/centrifydc/upgrade >> ${LOG_FILE}

        echo Checking /etc/syslog.conf for user.debug entry >> ${LOG_FILE}
        cat /etc/syslog.conf | grep /var/log/centrifydc.log | grep '^user.debug' >> ${LOG_FILE} 2>> ${LOG_FILE}
        if [ "$?" = "0" ]; then
            echo turning debug off >> ${LOG_FILE}
            /usr/share/centrifydc/bin/addebug off >> ${LOG_FILE} 2>> ${LOG_FILE}

            echo Checking /etc/syslog.conf for user.debug entry one more time >> ${LOG_FILE}
            cat /etc/syslog.conf | grep /var/log/centrifydc.log | grep '^user.debug' >> ${LOG_FILE} 2>> ${LOG_FILE}
            if [ "$?" = "0" ]; then
                echo Deleting user.debug entry from /etc/syslog.conf >> ${LOG_FILE}
                cp -p /etc/syslog.conf /etc/syslog.conf.pre_cdc_upgrade >> ${LOG_FILE} 2>> ${LOG_FILE}
                sed -e "/user.debug[ 	]*\/var\/log\/centrifydc.log/d" /etc/syslog.conf > /etc/syslog.conf.tmp_upgrade
                mv -f /etc/syslog.conf.tmp_upgrade /etc/syslog.conf >> ${LOG_FILE} 2>> ${LOG_FILE}
            fi

            echo turning debug back on >> ${LOG_FILE}
            /usr/share/centrifydc/bin/addebug on >> ${LOG_FILE} 2>> ${LOG_FILE}
        fi
        
        if [ ${DSPLUGIN_HAS_BEEN_ENABLED} -eq 0 ]; then
            #register our plugin
            echo ${ECHO_FLAG} "Registering Directory Service plugin ..." | tee -a ${LOG_FILE}
            /usr/share/centrifydc/bin/dsconfig enable | tee -a ${LOG_FILE}
            echo ${ECHO_FLAG} "" | tee -a ${LOG_FILE}
            echo ${ECHO_FLAG} "WARNING: The Centrify DirectControl DirectoryService plugin has been enabled" | tee -a ${LOG_FILE}
            echo ${ECHO_FLAG} "If you had Directory Access (or Directory Utility) running during upgrade,"   | tee -a ${LOG_FILE}
            echo ${ECHO_FLAG} "the checkbox next to the CentrifyDC plugin might not reflect that change."    | tee -a ${LOG_FILE}
            echo ${ECHO_FLAG} "To see the correct state, please quit (CMD-q) and restart Directory Access"   | tee -a ${LOG_FILE}
            echo ${ECHO_FLAG} "(or Directory Utility) after CentrifyDC upgrade is complete"                  | tee -a ${LOG_FILE}
            echo ${ECHO_FLAG} "" | tee -a ${LOG_FILE}
            DSPLUGIN_HAS_BEEN_ENABLED=1
        fi        
        
        /usr/share/centrifydc/bin/dsconfig restart | tee -a ${LOG_FILE}   #needed in case of upgrade 3.x -> 4.x

        if [ "${REBOOT}" = "N" ]; then
            echo ${ECHO_FLAG} ""                                                        | tee -a ${LOG_FILE}
            echo ${ECHO_FLAG} "Updating Centrify DirectControl from a previous release" | tee -a ${LOG_FILE}
            echo ${ECHO_FLAG} "requires that you restart this computer."                | tee -a ${LOG_FILE}
            echo ${ECHO_FLAG} "To complete the update of Centrify DirectControl,"       | tee -a ${LOG_FILE}
            echo ${ECHO_FLAG} "restart this computer as soon as possible."              | tee -a ${LOG_FILE}
        fi
        return $TRUE
        
    elif [ "${TARGET_OS}" = "aix" ]; then
        echo skipping ... >> ${LOG_FILE}
    else
        if test -s ${VAR}/centrifydc/kset.domain; then
            if [ -f /etc/nsswitch.conf.upgrade ]; then
                echo restoring /etc/nsswitch.conf ... >> ${LOG_FILE}
                mv /etc/nsswitch.conf.upgrade /etc/nsswitch.conf >> ${LOG_FILE} 2>> ${LOG_FILE}
            fi
            echo restarting adclient ... >> ${LOG_FILE}
            if [ -x /usr/share/centrifydc/bin/centrifydc ]; then
                /usr/share/centrifydc/bin/centrifydc restart >> ${LOG_FILE} 2>> ${LOG_FILE}
                update_keytab
            else
                if [ "${TARGET_OS}" = "hpux" ]; then
                    /sbin/init.d/centrifydc stop >> ${LOG_FILE} 2>> ${LOG_FILE}
                    /sbin/init.d/centrifydc start >> ${LOG_FILE} 2>> ${LOG_FILE}
                else
                    /etc/init.d/centrifydc stop >> ${LOG_FILE} 2>> ${LOG_FILE}
                    /etc/init.d/centrifydc start >> ${LOG_FILE} 2>> ${LOG_FILE}
                fi
            fi
        fi
    fi

    restart_mcafee_agent

    else ### add-on
        echo $ECHO_FLAG "\ninstall-express.sh: do_postupgrade: $1: skipping ..." >> ${LOG_FILE}
    fi
    hash -r
    return ${TRUE}
} # do_postupgrade()

###
set_license_mode ()
{
    echo $ECHO_FLAG "\ninstall-express.sh: set_license_mode: " >> ${LOG_FILE}
    if [ -x /usr/bin/adlicense ]; then

        if [ "${TARGET_OS}" = "solaris" ] && \
            [ -x /usr/sbin/zoneadm ] && \
            SOL_ZONES=`/usr/sbin/zoneadm list -cp` && \
            echo "$SOL_ZONES" | grep "0:global" > /dev/null && \
            [ "${GLOBAL_ZONE_ONLY}" != "Y" ]; then
            # Solaris global zone, installing to all zones
            
            echo "Setting zones licensed/express mode from global zone ..." >> ${LOG_FILE}
            echo "$SOL_ZONES" | \
                while read SOL_ZONE ; do
                SOL_ZONENAME=`echo "$SOL_ZONE" | awk -F: '{ print $2 }'`
                SOL_ZONESTATE=`echo "$SOL_ZONE" | awk -F: '{ print $3 }'`
                SOL_ZONEPATH=`echo "$SOL_ZONE" | awk -F: '{ print $4 }'`
                if [ -n "$SOL_ZONENAME" ]; then
                    
                    # On OpenSolaris, ready installed zone to access zone path
                    SOL_NEEDREADY=0
                    if [ "$SOL_ZONESTATE" = "installed" ]; then
                        case ${OS_REV} in
                            sol20* )
                                SOL_NEEDREADY=1
                                ;;
                        esac
                    fi
                    
                    test "$SOL_NEEDREADY" = "1" && \
                        /usr/sbin/zoneadm -z "$SOL_ZONENAME" ready  >> ${LOG_FILE}
                    # TBD: Do this on certain zone states only?
                    echo "  $SOL_ZONENAME: Root path $SOL_ZONEPATH" \
                        >> ${LOG_FILE}
                    if [ -d "$SOL_ZONEPATH" ]; then
                        test "$SOL_ZONEPATH" = "/" && SOL_ZONEROOT= || \
                            SOL_ZONEROOT="$SOL_ZONEPATH/root"
                        # Default is licensed mode, remove the license file
                        # to change to express mode. Note that this only
                        # works on a fresh install.
                        if [ "${ADLICENSE}" = "N" ]; then
                            rm -f "$SOL_ZONEROOT/var/centrifydc/kset.licensemode" >> ${LOG_FILE} 2>> ${LOG_FILE}
                        fi
                    else
                        echo "  Zone $SOL_ZONENAME: Root path $SOL_ZONEPATH does not exist." >> ${LOG_FILE}
                    fi
                    
                    test "$SOL_NEEDREADY" = "1" && \
                        /usr/sbin/zoneadm -z "$SOL_ZONENAME" halt >> ${LOG_FILE}
                fi
            done
        else
            if [ "${ADLICENSE}" = "N" ]; then
                /usr/bin/adlicense --express >> ${LOG_FILE}
            else
                /usr/bin/adlicense --licensed >> ${LOG_FILE}
            fi
        fi
    else
        if [ "${EXPRESS_PL}" -eq $TRUE ]; then
            echo ${ECHO_FLAG} "WARNING: Could not find /usr/bin/adlicense." | tee -a ${LOG_FILE}
        fi
    fi
    return ${TRUE}
} # set_license_mode

### Join domain
do_join () 
{
    U_USERID=
    N_COMPUTER=
    S_SERVER=
    W_MODE=
    echo Joining the Active Directory domain ${DOMAIN} ... | tee -a ${LOG_FILE}
    echo USERID=${USERID} >> ${LOG_FILE}
    echo COMPUTER=${COMPUTER} >> ${LOG_FILE}
    echo CONTAINER=${CONTAINER} >> ${LOG_FILE}
    echo SERVER=${SERVER} >> ${LOG_FILE}
    if [ "${EXPRESS_PL}" -eq $TRUE -a "${ADLICENSE}" = "N" ]; then
        W_MODE="-w"
        ZONE="" # no zone in express mode
    fi
    echo ZONE=${ZONE} >> ${LOG_FILE}
    if [ "${USERID}" != "" -a "${USERID}" != "administrator" ]; then U_USERID="-u ${USERID}"; fi
    if [ "${COMPUTER}" != "" -a "${COMPUTER}" != "`hostname`" ]; then N_COMPUTER="-n ${COMPUTER}"; fi
    if [ "${SERVER}" != "" ]; then S_SERVER="-s ${SERVER}"; fi
    if [ "${ZONE}" != "" -a "${ZONE}" != "default" -a "${CONTAINER}" != "" -a "${CONTAINER}" != "Computers" ]; then
        /usr/sbin/adjoin ${DOMAIN} ${U_USERID} -p "`echo ${PASSWD}`" ${N_COMPUTER} ${S_SERVER} -c "`echo ${CONTAINER}`" -z "`echo ${ZONE}`" \
                                          && echo "" || { echo "join failed"; return $FALSE; }
    elif [ "${CONTAINER}" != "" -a "${CONTAINER}" != "Computers" ]; then
        /usr/sbin/adjoin ${DOMAIN} ${U_USERID} -p "`echo ${PASSWD}`" ${N_COMPUTER} ${S_SERVER} -c "`echo ${CONTAINER}`" ${W_MODE} \
                                          && echo "" || { echo "join failed"; return $FALSE; }
    elif [ "${ZONE}" != "" -a "${ZONE}" != "default" ]; then
        /usr/sbin/adjoin ${DOMAIN} ${U_USERID} -p "`echo ${PASSWD}`" ${N_COMPUTER} ${S_SERVER} -z "`echo ${ZONE}`" \
                                          && echo "" || { echo "join failed"; return $FALSE; }
    else
        /usr/sbin/adjoin ${DOMAIN} ${U_USERID} -p "`echo ${PASSWD}`" ${N_COMPUTER} ${S_SERVER} ${W_MODE} \
                                          && echo "" || { echo "join failed"; return $FALSE; }
    fi
} # do_join()

### Reboot the computer
do_reboot () {
    umask_restore
    echo "Rebooting the computer ..."
    while [ "${DELAY}" != "0" ]
    do
        echo ${ECHO_FLAG} "You have ${DELAY} seconds left before rebooting. Press CTRL-C to terminate  \r\c"
        sleep 1
        DELAY=`expr ${DELAY} - 1`
    done
    echo "Rebooting now ...                                                                     "
    sync; sync
    ${REBOOT_CMD}
    return $TRUE
}

### print drive space information
print_df ()
{
    echo $ECHO_FLAG "\nERROR:" >> ${LOG_FILE}
    echo $ECHO_FLAG "Installation error, checking file system ...\n" >> ${LOG_FILE}
    if [ "${TARGET_OS}" = "hpux" ]; then
        bdf >> ${LOG_FILE}
    else
        df -k >> ${LOG_FILE}
    fi
    return ${TRUE}
}

### print error message about missing CDC agent while add-on(s) installed
missing_agent()
{
    echo $ECHO_FLAG "\nERROR: Broken dependencies!" | tee -a ${LOG_FILE}
    echo "Centrify DirectControl (CentrifyDC) is not installed on this computer but" | tee -a ${LOG_FILE}
    echo "it is required by the next already installed add-on package(s):" | tee -a ${LOG_FILE}
    for i in ${ADD_ON_INSTALLED}; do
        echo "    ${i}" | tee -a ${LOG_FILE}
    done
    echo "Please resolve dependency issue and then rerun this installer." | tee -a ${LOG_FILE}
    do_error $CODE_ESU
    # do_error() never returs
}

### Exit with error
do_error () {
    umask_restore
    if [ "$1" = "" ]; then
        if [ "${INSTALL}" = "Y" ]; then
            RC=$CODE_EIN
        elif [ "${INSTALL}" = "U" ]; then
            RC=$CODE_EUP
        else
            RC=$FALSE
        fi
    else
        RC=$1
    fi
    
    if [ -n "${LOG_FILE}" ]; then    
        echo ${ECHO_FLAG} "\nError detected." >> ${LOG_FILE}
        echo ${ECHO_FLAG} "\nError detected. More information may be found in the logfile"
        echo "(location is ${LOG_FILE})."
        echo $ECHO_FLAG "Exiting ..." | tee -a ${LOG_FILE}
        echo $ECHO_FLAG "EXIT CODE: $RC" >> ${LOG_FILE}
    fi
    
    exit $RC
}

### Exit by user request
do_quit () {
    umask_restore
    echo Installation terminated. Exiting ... | tee -a ${LOG_FILE}
    exit 2
}

### Exit gracefully
do_exit () {
    umask_restore
    if [ "$1" = "" ]; then 
        if [ -z "${PKG_I_LIST}" -a -z "${PKG_E_LIST}" ]; then
            RC=$CODE_NIN # nothing on install
        elif [ "${INSTALL}" = "Y" ]; then
            RC=$CODE_SIN # fresh install
        elif [ "${INSTALL}" = "U" ] || [ "${INSTALL}" = "K" -a -n "${PKG_I_LIST}" ]; then
            RC=$CODE_SUP # upgrade or add-on install
        elif [ -n "${PKG_E_LIST}" -a -z "${PKG_I_LIST}" ]; then
            RC=$CODE_SUN # partial uninstall
        else
            RC=$TRUE 
        fi
    else
        RC=$1
    fi
    if [ "$RC" = "$CODE_NIN" -o "$RC" = "$CODE_NUN" ]; then
        echo $ECHO_FLAG "Install-express.sh completed successfully. Nothing was installed or uninstalled." | tee -a ${LOG_FILE}
    else
        echo $ECHO_FLAG "Install-express.sh completed successfully." | tee -a ${LOG_FILE}
    fi
    echo $ECHO_FLAG "EXIT CODE: $RC" >> ${LOG_FILE}
    exit $RC
}

do_clean ()
{
    if [ "${TARGET_OS}" = "darwin" ]; then 
        if [ -f /Users/vadim/BUILD/centrifydc/usr/share/centrifydc/ldapproxy/libexec/openldap/libback_centrifydc.la ]; then
            rm -f /Users/vadim/BUILD/centrifydc/usr/share/centrifydc/ldapproxy/libexec/openldap/libback_centrifydc.* \
                           >> ${LOG_FILE} 2>> ${LOG_FILE}
            CUR_DIR="`pwd`"
            cd /Users/vadim/BUILD/centrifydc/usr/share/centrifydc/ldapproxy/libexec
            DIR_LIST="openldap libexec ldapproxy centrifydc share usr centrifydc BUILD vadim"
            for dir in ${DIR_LIST}; do
                echo removing ${dir} >> ${LOG_FILE} 2>> ${LOG_FILE}
                rmdir ${dir} >> ${LOG_FILE} 2>> ${LOG_FILE}
                if [ $? -ne 0 ]; then
                    cd ${CUR_DIR}
                    return $FALSE
                else
                    cd ..
                fi
            done
            cd ${CUR_DIR}
        fi
    fi
    return $TRUE
}

### repair files and dirs conflictes
fix_conflicts ()
{
    if [ "${TARGET_OS}" = "solaris" ]; then
        # CentrifyDC-openssh
        for dir in /etc/centrifydc/ssh /usr/share/centrifydc/man/man8
        do
            if [ -d ${dir} ]; then
                if echo "${openssh}" | grep "I" > /dev/null ; then
                    /usr/sbin/pkgchk -l -p ${dir} | grep CentrifyDC-openssh > /dev/null
                    if [ "$?" != "0" ]; then
                        /usr/sbin/installf CentrifyDC-openssh ${dir} > /dev/null
                        /usr/sbin/installf -f CentrifyDC-openssh 2>> ${LOG_FILE}
                    fi
                else
                    echo "removing directory $dir ..." >> ${LOG_FILE}
                    rm -r ${dir}
                fi
            fi
        done
        # CentrifyDC-krb5
        if [ -f /usr/share/centrifydc/kerberos/sbin/ktutil ] && [ -x /usr/sbin/zoneadm ] &&
           [ "`/usr/sbin/zoneadm list -p | grep 0:global > /dev/null; echo $?`" != "0" ] ; then
            /usr/sbin/pkgchk -l -p /usr/share/centrifydc/kerberos/sbin/ktutil | grep CentrifyDC-krb5 > /dev/null
            if [ "$?" = "0" ]; then
                echo "moving files from CentrifyDC-krb5 to CentrifyDC package ..." >> ${LOG_FILE}
                FILE_LIST="\
                bin/krb5-config bin/ksu sbin sbin/ktutil \
                man/man1/kerberos.1 man/man1/krb5-config.1 man/man1/ksu.1 \ 
                man/man5 man/man5/kdc.conf.5 man/man5/krb5.conf.5 \ 
                man/man8 man/man8/ktutil.8 \ 
                "
                for file in ${FILE_LIST}; do
                    path_name="/usr/share/centrifydc/kerberos/${file}"
                    if [ -s ${path_name} ]; then
                        /usr/sbin/removef  CentrifyDC-krb5 ${path_name} > /dev/null
                        /usr/sbin/installf CentrifyDC      ${path_name} > /dev/null
                        INSTALLF="run"
                    fi
                done
                if [ "${INSTALLF}" = "run" ]; then
                    /usr/sbin/removef  -f CentrifyDC-krb5 2>> ${LOG_FILE}
                    /usr/sbin/installf -f CentrifyDC      2>> ${LOG_FILE}
                fi
            fi
        fi
    fi
    return $TRUE
} # fix_conflicts()

### Check if custom log-file exists and writable or could be created
check_log_file ()
{
    if [ "${LOG_FILE}" = "" ]; then
        LOG_FILE=${LOG_FILE_DEF}
    fi
    if [ ! -f ${LOG_FILE} ]; then
        LOG_DIR="`dirname ${LOG_FILE}`/"
        mkdir -p ${LOG_DIR}
        touch ${LOG_FILE}
        if [ "$?" != "0" ]; then
            echo $ECHO_FLAG "\nERROR: Could not create the log-file ${LOG_FILE}."
            if [ "${LOG_FILE}" = "${LOG_FILE_DEF}" ]; then
                LOG_FILE=""
            else
                LOG_FILE=${LOG_FILE_DEF}
                echo "Using default log-file ${LOG_FILE_DEF} instead."
            fi
            return $FALSE
        fi
    fi
    if [ ! -w ${LOG_FILE} ]; then
        echo $ECHO_FLAG "\nWARNING: The log-file ${LOG_FILE} is not writable."
        chmod +w ${LOG_FILE}
        if [ "$?" != "0" ]; then
            echo $ECHO_FLAG "\nERROR: Could not make the log-file ${LOG_FILE} writable."
            if [ "${LOG_FILE}" = "${LOG_FILE_DEF}" ]; then
                LOG_FILE=""
            else
                LOG_FILE=${LOG_FILE_DEF}
                echo "Using default log-file ${LOG_FILE_DEF} instead."
            fi
            return $FALSE
        fi
    fi
    return $TRUE
} # check_log_file()

### Log file header
log_header ()
{
    check_log_file
    if [ "$?" != "0" ]; then
        if [ "${LOG_FILE}" = "" ]; then echo ${ECHO_FLAG} "\nError detected. Exiting ..."; exit $CODE_ESU; fi
        check_log_file   || { echo ${ECHO_FLAG} "\nError detected. Exiting ..."; exit $CODE_ESU; }
    fi
    if [ "${DEBUG}" = "on" ]; then DEBUG_OUT=${LOG_FILE}; fi
    echo $ECHO_FLAG "\n\ninstall-express.sh ***************** rev = ${CDC_VER_YEAR} (${REV}) ********************" >> ${LOG_FILE}
    date >> ${LOG_FILE}
    debug_echo "current dir: `pwd`"
    if [ "${DEBUG}" = "on" ]; then
        ls -l >> ${LOG_FILE}
        echo "`uname -a`" >> ${LOG_FILE} 2>> ${LOG_FILE}
    fi
}

###
logo ()
{
    cat <<-END_LOGO

*****                                                                   *****
*****             WELCOME to the Centrify Express installer!            *****
*****                                                                   *****

END_LOGO
}

validate_x_opt ()
{
    uid_check
    detect_os
    case "${TARGET_OS}" in
    hpux)
        if [ "$1" = "enforce_dependencies=false" ]; then X_OPTION_LIST="${X_OPTION_LIST}-x $1 "
        elif [ "$1" = "enforce_scripts=false" ]; then X_OPTION_LIST="${X_OPTION_LIST}-x $1 "
        else
            echo ERROR: invalid extra option: $1
            do_error $CODE_ESU
        fi
        echo "extra options: ${X_OPTION_LIST}" >> ${LOG_FILE}
        ;;
    *)
        echo ERROR: invalid extra option: $1
        do_error $CODE_ESU
        ;;
    esac

    return ${TRUE} 
}

version_weight ()
{
    VERSION_NUMBER=$1
    if [ "`echo ${VERSION_NUMBER} | grep '-'`" != "" ]; then return 4; fi
    if [ "`echo ${VERSION_NUMBER} | grep '\.'`" = "" ]; then return 1
    else
        VERSION_NUMBER=`echo ${VERSION_NUMBER} | sed 's/\./\:/' | cut -d ':' -f2`
        if [ "`echo ${VERSION_NUMBER} | grep '\.'`" = "" ]; then return 2
        else  return 3
        fi
    fi
    # wrong format
    return 0
}

# compare version strings, accept next formats: x.x.x-xxx, x.x.x, x.x or x ( 4.1.0 and: 4 are "eq" )
compare_ver ()
{
    if [ -z "${1}" -o -z "${2}" ]; then echo "ERROR: compare_ver() needs two parameters to compare"; return $FALSE; fi
    V_W_1=`version_weight $1; echo $?`
    V_W_2=`version_weight $2; echo $?`
    ONE=`echo $1 | sed 's/[a-z]//g'`
    TWO=`echo $2 | sed 's/[a-z]//g'`
      if [ `echo $ONE | cut -d. -f1` -lt `echo $TWO | cut -d. -f1` ]; then COMPARE="lt"; return ${TRUE}
    elif [ `echo $ONE | cut -d. -f1` -gt `echo $TWO | cut -d. -f1` ]; then COMPARE="gt"; return ${TRUE}
    elif [ ${V_W_1} -eq 1 -o ${V_W_2} -eq 1 ]; then COMPARE="eq"; return ${TRUE}
    elif [ `echo $ONE | cut -d. -f2` -lt `echo $TWO | cut -d. -f2` ]; then COMPARE="lt"; return ${TRUE}
    elif [ `echo $ONE | cut -d. -f2` -gt `echo $TWO | cut -d. -f2` ]; then COMPARE="gt"; return ${TRUE}
    elif [ ${V_W_1} -eq 2 -o ${V_W_2} -eq 2 ]; then COMPARE="eq"; return ${TRUE}
    elif [ `echo $ONE | cut -d. -f3 | cut -d '-' -f1` -lt `echo $TWO | cut -d. -f3 | cut -d '-' -f1` ]; then COMPARE="lt"; return ${TRUE}
    elif [ `echo $ONE | cut -d. -f3 | cut -d '-' -f1` -gt `echo $TWO | cut -d. -f3 | cut -d '-' -f1` ]; then COMPARE="gt"; return ${TRUE}
    elif [ ${V_W_1} -eq 3 -o ${V_W_2} -eq 3 ]; then COMPARE="eq"; return ${TRUE}
    elif [ `echo $ONE | cut -d. -f3 | cut -d '-' -f2` -lt `echo $TWO | cut -d. -f3 | cut -d '-' -f2` ]; then COMPARE="lt"; return ${TRUE}
    elif [ `echo $ONE | cut -d. -f3 | cut -d '-' -f2` -gt `echo $TWO | cut -d. -f3 | cut -d '-' -f2` ]; then COMPARE="gt"; return ${TRUE}
    else return ${FALSE}
    fi
}

# check if we're asked to install a previous version, which we don't know
# how to handle anymore. mac os x only, at this point.
min_version_required ()
{
    if [ "${UNINSTALL}" = "Y" ]; then #always support uninstall
        return ${TRUE};
    fi

    if [ "${TARGET_OS}" = "darwin" ]; then
        compare_ver ${CDC_VER} ${CDC_VER_MINIMUM_MAC}
        if [ "${COMPARE}" = "lt" ] ; then return ${FALSE}; fi
    fi

    
    return ${TRUE};
}

check_auditing ()
{
    if [ "${DA_ENABLE}" = "enabled" ] && [ "${cda}" = "S+I+U" -o "${cda}" = "S=I+R" ]; then
        # Auditing must be disabled during CDA upgrade/reinstall
        echo "" | tee -a ${LOG_FILE}
        echo "WARNING: Centrify DirectAudit auditing is currently enabled"         | tee -a ${LOG_FILE}
        echo "         but must be disabled during upgrade/reinstall."             | tee -a ${LOG_FILE}
        if [ "${SILENT}" = "NO" ]; then
            echo "         If you choose \"N\" to continue without disabling auditing,"  | tee -a ${LOG_FILE}
            echo "         the CentrifyDA package will be excluded from upgrade."        | tee -a ${LOG_FILE}
            QUESTION="\nDo you want to disable auditing now? (Y|N|Q) [Y]:\c"; do_ask_YorN
            if [ "${ANSWER}" = "Y" ]; then
                echo "Disabling auditing ..." | tee -a ${LOG_FILE}
                /usr/sbin/dacontrol -d -a >> ${LOG_FILE}
                DA_ENABLE=
            else
                # exclude CDA from upgrade/reinstall
                cda="`echo ${cda} | sed 's/[UR]/K/'`"
                PKG_I_LIST="`echo ${PKG_I_LIST} | sed 's/CentrifyDA//'`"
                PKG_FILE_LIST_TMP=
                for package_file in ${PKG_FILE_LIST}
                do
                    case "${package_file}" in
                    *"centrifyda"* )
                        echo "excluding $package_file from PKG_FILE_LIST" >> ${LOG_FILE}
                        ;;
                    *)
                        PKG_FILE_LIST_TMP="${PKG_FILE_LIST_TMP} $package_file"
                        ;;
                    esac
                done
                PKG_FILE_LIST=${PKG_FILE_LIST_TMP}
                debug_echo "PKG_FILE_LIST=${PKG_FILE_LIST}"
                debug_echo "PKG_I_LIST=${PKG_I_LIST}"
            fi
        else
            echo "         Please disable auditing or exclude the CentrifyDA package from" | tee -a ${LOG_FILE}
            echo "         upgrade and then restart installation. Exiting ..."             | tee -a ${LOG_FILE}
            do_error ${CODE_EUP}
        fi
    fi
    return ${TRUE}
}

check_dependencies ()
{
    RC=${TRUE}
    
    ### CDC-nis
    ASK_REMOVE_NIS=$FALSE # whether ask user to remove NIS
    NEED_REMOVE_NIS=$FALSE # whether remove NIS
    if [ "${INSTALL}" = "U" ] && [ "${nis}" = "I+K" -o "${nis}" = "S+I+K" ] &&
       [ "`compare_ver ${CDC_VER} ${CDC_VER_INC_NIS}; echo ${COMPARE}`" != "lt" ] &&
       [ "`compare_ver ${CUR_VER} ${CDC_VER_INC_NIS}; echo ${COMPARE}`" = "lt" ]; then
        ASK_REMOVE_NIS=$TRUE
    fi
    ### CDC-nis (2)
    # For CDC version >= $CDC_VER_INC_NIS
    # HP-UX fails to upgrade CDC if NIS < 4.0 is already installed
    # Workaround: remove NIS add-on package before upgrade
    if [ "${INSTALL}" = "U" ] && [ "${TARGET_OS}" = "hpux" ] && [ "${nis}" = "S+I+U" ] &&
       [ "`compare_ver ${CDC_VER} ${CDC_VER_INC_NIS}; echo ${COMPARE}`" != "lt" ] &&
       [ "`compare_ver ${CUR_VER} ${CDC_VER_INC_NIS}; echo ${COMPARE}`" = "lt" ]; then
        NEED_REMOVE_NIS=$TRUE
    fi
    ### CDC-nis (3)
    # For CDC version >= $CDC_VER_INC_NIS_3
    # It is incompatible with older version NIS (only compare the first version number of x.x.x)
    # Ask users to remove NIS if users select to keep current NIS version
    if [ "${INSTALL}" = "U" ] && [ "${nis}" = "I+K" -o "${nis}" = "S+I+K" -o "${nis}" = "S+I+U" ] &&
       [ "`compare_ver ${CDC_VER} ${CDC_VER_INC_NIS_3}; echo ${COMPARE}`" != "lt" ] &&
       [ "`echo \"${CUR_VER}\" | cut -d '.' -f1`" -lt "`echo \"${CDC_VER}\" | cut -d '.' -f1`" ]; then # CUR_VER means current NIS version
        if [ "${nis}" = "S+I+U" ]; then # if upgrading NIS
            # HP-UX and Debian 5 is unable to upgrade CDC and NIS directly
            if [ "${PKG_OS_REV}" = "deb5" ]; then
                # Workaround: ignore dependency of centrifydc-nis
                LINUX_OPTION="${LINUX_OPTION} --ignore-depends=centrifydc-nis"
            elif [ "${TARGET_OS}" = "hpux" ]; then
                # Workaround: remove NIS add-on package before upgrade
                NEED_REMOVE_NIS=$TRUE
            fi
        else # if keeping NIS
            ASK_REMOVE_NIS=$TRUE
        fi
    fi
    ### CDC-nis (Final)
    if [ "$ASK_REMOVE_NIS" = "$TRUE" ]; then
        echo "" | tee -a ${LOG_FILE}
        echo "WARNING: A version of the Centrify DirectControl NIS Server (CentrifyDC-nis)"   | tee -a ${LOG_FILE}
        echo "         has been detected that is not compatible with the version of"          | tee -a ${LOG_FILE}
        echo "         DirectControl you are installing."                                     | tee -a ${LOG_FILE}
        if [ "${SILENT}" = "NO" ]; then
            echo "         If you continue (C|Y), the CentrifyDC-nis package will be removed."   | tee -a ${LOG_FILE}
            echo "         You may also quit (Q|N), download the latest version of"              | tee -a ${LOG_FILE}
            echo "         CentrifyDC-nis and then restart installation."                        | tee -a ${LOG_FILE}
            QUESTION="\nDo you want to continue installation? (C|Y|Q|N) [N]:\c"; do_ask_YorN "N" "C"
            if [ "${ANSWER}" != "Y" ]; then
                do_quit
            else
                NEED_REMOVE_NIS=$TRUE
            fi
        else
            echo "         Please mark CentrifyDC-nis for removal or upgrade and then"      | tee -a ${LOG_FILE}
            echo "         restart installation. Exiting ..."                               | tee -a ${LOG_FILE}
            RC=${FALSE}
        fi
    fi
    if [ "$NEED_REMOVE_NIS" = "$TRUE" ]; then
        if [ "${nis}" = "I+K" ]; then nis="I+E"; fi
        if [ "${nis}" = "S+I+K" ]; then nis="S+I+E"; fi
        if [ "${TARGET_OS}" = "aix" ]; then
            PKG_E_LIST="${PKG_E_LIST} CentrifyDC.nis"
        else
            PKG_E_LIST="${PKG_E_LIST} CentrifyDC-nis"
        fi
    fi
    
    ### CDC-openssh
    if [ "${openssh}" = "S+Y" ] && [ "${TARGET_OS}" = "linux" ] && [ -f /etc/pam.d/sshd ] &&
       [ "`compare_ver ${CDC_VER} 4.4; echo ${COMPARE}`" = "lt" ]; then
        echo "" | tee -a ${LOG_FILE}
        echo "WARNING: Non-centrify version of /etc/pam.d/sshd has been found." | tee -a ${LOG_FILE}
        if [ "${SILENT}" = "NO" ]; then
            echo "         If you continue (C|Y), /etc/pam.d/sshd will be renamed (moved) to"    | tee -a ${LOG_FILE}
            echo "         /etc/pam.d/sshd.pre_cdc to allow CentrifyDC-openssh to be installed." | tee -a ${LOG_FILE}
            echo "         You may also quit (Q|N), restart installation in Custom mode and"     | tee -a ${LOG_FILE}
            echo "         choose to not install the CentrifyDC-openssh package."                | tee -a ${LOG_FILE}
            QUESTION="\nDo you want to continue installation? (C|Y|Q|N) [Y]:\c"; do_ask_YorN "Y" "C"
            if [ "${ANSWER}" != "Y" ]; then
                do_quit
            fi
        else
            echo "         It will be renamed (moved) to /etc/pam.d/sshd.pre_cdc prior to CentrifyDC-openssh installation."     | tee -a ${LOG_FILE}
            RC=${TRUE}
        fi
    fi
    ### CDC-krb5
    if [ "${INSTALL}" = "U" ] && [ "${krb5}" = "I+K" -o "${krb5}" = "S+I+K" ] &&
       [ "`compare_ver ${CDC_VER} ${CDC_VER_INC_KRB5}; echo ${COMPARE}`" != "lt" ] && 
       [ "`compare_ver ${CUR_VER} ${CDC_VER_INC_KRB5}; echo ${COMPARE}`" = "lt" ]; then
        echo "" | tee -a ${LOG_FILE}
        echo "WARNING: A version of the Centrify MIT Kerberos Tools (CentrifyDC-krb5)"        | tee -a ${LOG_FILE}
        echo "         has been detected that is not compatible with the version of"          | tee -a ${LOG_FILE}
        echo "         DirectControl you are installing."                                     | tee -a ${LOG_FILE}
        if [ "${SILENT}" = "NO" ]; then
            echo "         If you continue (C|Y), the CentrifyDC-krb5 package will be removed."  | tee -a ${LOG_FILE}
            echo "         You may also quit (Q|N), download the latest version of"              | tee -a ${LOG_FILE}
            echo "         CentrifyDC-krb5 and then restart installation."                       | tee -a ${LOG_FILE}
            QUESTION="\nDo you want to continue installation? (C|Y|Q|N) [N]:\c"; do_ask_YorN "N" "C"
            if [ "${ANSWER}" != "Y" ]; then 
                do_quit
            else
                if [ "${krb5}" = "I+K" ]; then krb5="I+E"; fi
                if [ "${krb5}" = "S+I+K" ]; then krb5="S+I+E"; fi
                if [ "${TARGET_OS}" = "aix" ]; then
                    PKG_E_LIST="${PKG_E_LIST} CentrifyDC.krb5"
                else
                    PKG_E_LIST="${PKG_E_LIST} CentrifyDC-krb5"
                fi
            fi
        else
            echo "         Please mark CentrifyDC-krb5 for removal or upgrade and then"     | tee -a ${LOG_FILE}
            echo "         restart installation. Exiting ..."                               | tee -a ${LOG_FILE}
            RC=${FALSE}
        fi
    fi
    ### CDC-krb5 (2), upgrading
    if [ "${INSTALL}" = "U" ] && [ "${krb5}" = "S+I+U" ] &&
       [ "`compare_ver ${CDC_VER} ${CDC_VER_INC_KRB5}; echo ${COMPARE}`" != "lt" ] &&
       [ "`compare_ver ${CUR_VER} ${CDC_VER_INC_KRB5}; echo ${COMPARE}`" = "lt" ]; then

        if [ "${TARGET_OS}" = "hpux" ]; then
            PKG_E_LIST="${PKG_E_LIST} CentrifyDC-krb5"
        elif [ "${TARGET_OS}" = "solaris" ] && [ -x /usr/sbin/zoneadm ] &&
             [ "`/usr/sbin/zoneadm list -p | grep 0:global > /dev/null; echo $?`" = "0" ]; then
            PKG_E_LIST="${PKG_E_LIST} CentrifyDC-krb5"
        fi
    fi
    ### CDC-idmap
    if [ "${INSTALL}" = "U" ] && [ "${idmap}" = "I+K" -o "${idmap}" = "S+I+K" ] &&
       [ "`compare_ver ${CDC_VER} ${CDC_VER_INC_IDMAP}; echo ${COMPARE}`" != "lt" ]; then
        # backup samba init script for 4.1.0 upgrade
        INIT_SCRIPT=${INIT_DIR}/centrifydc-samba
        if [ -f ${INIT_SCRIPT} ] && [ ! -f ${INIT_SCRIPT}.upgrade ]; then
            cp -p ${INIT_SCRIPT} ${INIT_SCRIPT}.upgrade >> ${LOG_FILE} 2>> ${LOG_FILE}
        fi
        # HP-UX only
        RC_SAMBA_FILE=/etc/rc.config.d/centrifydc-samba.rc
        if [ -f ${RC_SAMBA_FILE} ] && [ ! -f ${RC_SAMBA_FILE}.upgrade ]; then
            cp -p ${RC_SAMBA_FILE} ${RC_SAMBA_FILE}.upgrade >> ${LOG_FILE} 2>> ${LOG_FILE}
        fi
        echo "" | tee -a ${LOG_FILE}
        echo "WARNING: This version of the CentrifyDC package includes functionality" | tee -a ${LOG_FILE}
        echo "         previously delivered in the CentrifyDC-idmap package."         | tee -a ${LOG_FILE}
        if [ "${SILENT}" = "NO" ]; then
            echo "         If you continue (C|Y), the CentrifyDC-idmap package will be removed." | tee -a ${LOG_FILE}
            QUESTION="\nDo you want to continue installation? (C|Y|Q|N) [N]:\c"; do_ask_YorN "N" "C"
            if [ "${ANSWER}" != "Y" ]; then
                do_quit
            else
                if [ "${idmap}" = "I+K" ]; then idmap="I+E"; fi
                if [ "${idmap}" = "S+I+K" ]; then idmap="S+I+E"; fi
                if [ "${TARGET_OS}" = "aix" ]; then
                    PKG_E_LIST="${PKG_E_LIST} CentrifyDC.idmap"
                else
                    PKG_E_LIST="${PKG_E_LIST} CentrifyDC-idmap"
                fi
            fi
        else
            echo "         Please mark CentrifyDC-idmap for removal and then"               | tee -a ${LOG_FILE}
            echo "         restart installation. Exiting ..."                               | tee -a ${LOG_FILE}
            RC=${FALSE}
        fi
    fi
    return ${RC}
} # check_dependencies

# show installed packages with versions
show_installed ()
{
    ### unknown version
    for ADD_ON_PKG10 in ${ADD_ON_INSTALLED}; do
        case "${ADD_ON_PKG10}" in
        *"0.0.0")
            echo ${ECHO_FLAG} "\nWARNING:" | tee -a ${LOG_FILE}
            echo ${ECHO_FLAG} "${ADD_ON_PKG10} is installed but version cannot be determined." | tee -a ${LOG_FILE}
            ;;
        esac
    done

    if [ "${INSTALLED}" = "Y" ]; then
        echo ${ECHO_FLAG} "\nCurrently installed:"  | tee -a ${LOG_FILE}
        echo ${ECHO_FLAG} "CentrifyDC-${CUR_VER}" | tee -a ${LOG_FILE}
        for ADD_ON_PKG11 in ${ADD_ON_INSTALLED}; do
            echo ${ECHO_FLAG} "${ADD_ON_PKG11}" | tee -a ${LOG_FILE}
        done
        echo ""
    fi
    return $TRUE
}

warnings ()
{
    ### DirectAudit in Solaris zones
    if [ "${FORCE_DA_GLOBAL}" != "Y" -a "${GLOBAL_ZONE_ONLY}" = "Y" -a \
        "`echo ${PKG_I_LIST} | grep CentrifyDA`" != "" ]; then
        case ${cda} in
            "S+Y" | "S+I+U" | "S=I+R")
                        # exclude CDA from install/upgrade/reinstall
                cda="`echo ${cda} | sed 's/Y/N/' | sed 's/[UR]/K/'`"
                PKG_I_LIST="`echo ${PKG_I_LIST} | sed 's/CentrifyDA//'`"
                echo ${ECHO_FLAG} "\nWARNING: You have chosen to install in the global zone only, but one" | tee -a ${LOG_FILE}
                echo ${ECHO_FLAG}   "         component, DirectAudit, must be installed in all zones." | tee -a ${LOG_FILE}
                echo ${ECHO_FLAG}   "         If you continue, DirectAudit will not be installed." | tee -a ${LOG_FILE}
                ;;
            *)
                echo ${ECHO_FLAG} "\nERROR:" | tee -a ${LOG_FILE}
                echo ${ECHO_FLAG} "cda=${cda} conflicts with PKG_I_LIST=${PKG_I_LIST}" | tee -a ${LOG_FILE}
                do_error ${CODE_EIN}
                ;;
        esac
    fi

    ### CDC-openssh
    if [ "${openssh}" = "S+I+U" ] && [ "${TARGET_OS}" != "linux" ]; then
        echo ${ECHO_FLAG} "\nWARNING:" | tee -a ${LOG_FILE}
        echo ${ECHO_FLAG} "The current version of the OpenSSH package doesn't preserve" | tee -a ${LOG_FILE}
        echo ${ECHO_FLAG} "during upgrade any configuration file changes you may have made." | tee -a ${LOG_FILE}
        QUESTION="\nDo you want installer to back up them now? (Y|N|Q) [Y]:\c"; do_ask_YorN "Y"
        if [ "${ANSWER}" = "Y" ]; then
            echo ${ECHO_FLAG} "\nPlease remove /var/tmp/cdc-openssh-backup after recovering your files."   | tee -a ${LOG_FILE}
            echo ${ECHO_FLAG} "Making backup copy in /var/tmp/cdc-openssh-backup/ ..."                     | tee -a ${LOG_FILE}
            mkdir -p /var/tmp/cdc-openssh-backup
            chmod 750 /var/tmp/cdc-openssh-backup
            cp -f /etc/centrifydc/ssh/* /var/tmp/cdc-openssh-backup
        fi
    fi

    return ${TRUE}
}

# Cleanup if signal is received.
signal_handler ()
{
    trap "" ${SIGNAL_LIST}  
    echo "Signal received." | tee -a ${LOG_FILE}
    if [ -f /etc/nsswitch.conf.upgrade ]; then
        echo "Restoring /etc/nsswitch.conf ..." >> ${LOG_FILE}
        mv /etc/nsswitch.conf.upgrade /etc/nsswitch.conf >> ${LOG_FILE} 2>> ${LOG_FILE}
    fi
    revert_force_da_global
    if [ -d "${VAR_TMP}" ]; then
        echo "Cleaning up temporary directory ${VAR_TMP} ..." >> ${LOG_FILE}
        rm -rf ${VAR_TMP} >> ${LOG_FILE} 2>> ${LOG_FILE}
    fi
    do_error ${CODE_SIG}
}

### check_argument_value
check_argument_value ()
{
    # Value can't be null, can't be another option.
    [ -n "${1}" ] && [ -z "`echo "${1}X" | grep '^-'`" ] && return $TRUE

    return $FALSE
}

### check_version_format
check_version_format ()
{
    # Format of the CDC_VER: x.x.x or x.x.x-xxx, x is a number.
    
    if [ -n "${1}" ]; then
        # For format: x.x.x
        echo "${1}" | grep '^[0-9]\.[0-9]\.[0-9]$' > /dev/null 2>&1 && return $TRUE
        
        # For format: x.x.x-xxx
        echo "${1}" | grep '^[0-9]\.[0-9]\.[0-9]-[0-9]\{1,3\}$' > /dev/null 2>&1 && return $TRUE
    fi

    return $FALSE
}

### prepare for the --force-da-global option
prepare_force_da_global ()
{
    if [ "${FORCE_DA_GLOBAL}" = "Y" ]; then
        if [ "${TARGET_OS}" = "solaris" -a \
            -f /var/sadm/install/gz-only-packages -a \
            -n "`echo ${ADD_ON_LIST} | grep cda`" ]; then
            ADD_ON_LIST=cda
        else
            echo "option --force-da-global is not supported on this platform ..."
            do_error
        fi

        if [ "${INSTALLED}" != "Y" ]; then
            echo "option --force-da-global is valid only if DirectControl is installed ..."
            do_error
        fi
    fi
}

### apply changes to force install DirectAudit
do_force_da_global ()
{
    if [ -f /var/sadm/install/gz-only-packages ]; then
        if [ "${INSTALLED_GZ_ONLY}" != "N" -a \
            "${FORCE_DA_GLOBAL}" = "Y" ]; then
            cat /var/sadm/install/gz-only-packages | grep -v '#' | grep -v CentrifyDC- | grep CentrifyDC > /dev/null
            if [ $? -eq 0 ]; then
                echo "Applying changes to force DirectAudit to be installed ..." | tee -a ${LOG_FILE}
                cp -pf /var/sadm/install/gz-only-packages \
                    /var/sadm/install/gz-only-packages.pre_cdc_cda >> ${LOG_FILE} 2>> ${LOG_FILE} \
                    || return ${FALSE}
                cp -pf /var/sadm/install/gz-only-packages \
                    /var/sadm/install/gz-only-packages.tmp >> ${LOG_FILE} 2>> ${LOG_FILE} \
                    || return ${FALSE} # preserve ownership and permissions
                sed '/^\s*CentrifyDC\s*$/d' /var/sadm/install/gz-only-packages > \
                    /var/sadm/install/gz-only-packages.tmp 2>> ${LOG_FILE} \
                    && mv -f /var/sadm/install/gz-only-packages.tmp \
                    /var/sadm/install/gz-only-packages >> ${LOG_FILE} 2>> ${LOG_FILE} \
                    || { echo "ERROR: Cannot modify /var/sadm/install/gz-only-packages"; return ${FALSE}; }
                REVERT_FORCE_DA_GLOBAL="Y"
            fi
        fi
    fi
    return ${TRUE}
}

### revert what was done in do_force_da_global
revert_force_da_global ()
{
    if [ "${REVERT_FORCE_DA_GLOBAL}" = "Y" ]; then
        if [ -f /var/sadm/install/gz-only-packages.pre_cdc_cda ]; then
            echo "Reverting changes made to force DirectAudit to be installed ..." | tee -a ${LOG_FILE}
            mv -f /var/sadm/install/gz-only-packages.pre_cdc_cda \
                /var/sadm/install/gz-only-packages >> ${LOG_FILE}
        fi
        REVERT_FORCE_DA_GLOBAL=
    fi
}


restart_mcafee_agent ()
{
    if [ "${TARGET_OS}" = "darwin" ]; then
        # SystemStarter Silently fails if McAfee is not installed
        /sbin/SystemStarter restart cma
# Uncomment for Linux and Solaris support
#    elif [ -x /etc/init.d/cma ]; then 
#        # Solaris and Linux
#        /etc/init.d/cma restart
    fi
}


###
### MAIN program
###
main () 
{
    logo
    uid_check
    detect_os		|| { echo "detecting platform failed ..."; do_error; }
    # detect_os sets ECHO_FLAG and LOG_FILE, so the first echo to the log-file should be after this point 
    find_pkg_dir
    detect_sparse
    if [ "${WPAR}" = "yes" ]; then fix_wpar; fi
    check_exceptions
    umask_check
    trap signal_handler ${SIGNAL_LIST}
    if [ "${SILENT}" = "Y" ]; then set_silent_cfg || do_error $CODE_ESU; fi
    if [ "${UNINSTALL}" = "Y" ] || [ "${SILENT}" = "Y" -a "${INSTALL}" = "E" -a "${UNINSTALL}" = "" ]; then 
        do_remove_main
        # do_remove_main() never returns
    fi
    is_supported         && { SUPPORTED="Y"; SUPPORTED_PL=$TRUE; }
    find_supported_addon && { SUPPORTED_PL=$TRUE; }
    is_installed         && { SUPPORTED_PL=$TRUE; }
    prepare_force_da_global
    if [ "${INSTALLED}" = "Y" ]; then
        is_addon_installed && { SUPPORTED_PL=$TRUE; }
        INSTALLED="Y" # core is installed so keep it set to "Y"
    elif [ "${SUPPORTED}" = "Y" ]; then
        # agent is not installed and available for install
        is_addon_installed && { missing_agent; }
    elif [ "${SUPPORTED}" = "N" ]; then
        SUPPORTED_PL=$FALSE
    fi
    if [ ${SUPPORTED_PL} -eq $FALSE ]; then
        echo Centrify DirectControl is not installed on this computer. | tee -a ${LOG_FILE}
        echo Could not find ${PKG_FILE} in ${PKG_DIR} directory. | tee -a ${LOG_FILE}
        echo Current platform ${PLATFORM} is not supported or package file is missing. | tee -a ${LOG_FILE}
        do_error $CODE_ESU
    else
        do_clean
        # echo Current platform ${PLATFORM} is supported. | tee -a ${LOG_FILE}; echo "" | tee -a ${LOG_FILE}

        search_adcheck
        if [ "${ADCHECK_FNAME}" != "" -a "${OS_CHECK}" != "skip" ]; then
            ### check OS patches only
            run_adcheck
            if [ "${ADCHECK_RC}" = "3" ]; then
                if [ "${SILENT}" = "NO" ]; then
                    QUESTION="\nDo you want to continue installation? (Q|Y|N) [Y]:\c"; do_ask_YorN
                    if [ "${ANSWER}" != "Y" ]; then do_quit; fi
                else
                    echo "WARNING: adcheck failed ..." | tee -a ${LOG_FILE}
                    do_error $CODE_ESU 
                fi
            fi
        fi

        debug_echo SUPPORTED=$SUPPORTED
        debug_echo INSTALLED=$INSTALLED
        if [ "${SILENT}" = "NO" ]; then
            case "${cda}" in
                S*)
                    ENTERPRISE_PL=$TRUE
                    ;;
            esac
            do_suite_prompt
            CONTINUE="N"
            if [ "${SUITE}" != "Custom" ]; then
                ### go through ENT or STD suite installation only once
                do_silent_prompt
                check_dependencies
                determine_license || do_prompt_license
                do_prompt_join  || { echo "do_prompt_join() failed ..."; do_error; }
                do_prompt_gz
                warnings
                do_verify       || { echo "do_verify() failed ..."; do_error; }
            fi
            while [ "${CONTINUE}" != "Y" ]
            do
                ### loop through custom prompt until confirmed or terminated
                do_prompt       || { echo "do_prompt() failed ..."; do_error; }
                check_dependencies
                determine_license || do_prompt_license
                do_prompt_join  || { echo "do_prompt_join() failed ..."; do_error; }
                do_prompt_gz
                warnings
                do_verify       || { echo "do_verify() failed ..."; do_error; }
            done
        else
            do_silent_prompt
            if [ "${INSTALLED}" = "Y" -a "${PKG_FILE_LIST}" != "" ]; then
                is_installed_gz_only
            fi
            check_dependencies || { do_error; }
            determine_license
            check_auditing
        fi
        if [ "${ADCHECK}" = "Y" -a "${DOMAIN}" != "" -a "${DOMAIN}" != "company.com" ]; then
            ### check AD environment, skip OS tests
            run_adcheck ${DOMAIN}
            if [ "${ADCHECK_RC}" = "3" ] && [ "${SILENT}" = "NO" ]; then
                QUESTION="\nDo you want to continue installation? (Q|Y|N) [Y]:\c"; do_ask_YorN
                if [ "${ANSWER}" != "Y" ]; then do_quit; fi
            fi
        fi
        fix_conflicts

        if [ "${PKG_E_LIST}" != "" ]; then
            echo ""
            for ADD_ON_PKG in ${PKG_E_LIST}; do
                do_preremove  ${ADD_ON_PKG}   || { echo "pre-uninstall script failed ...";    do_error $CODE_EUN; }
                do_remove     ${ADD_ON_PKG}   || { echo "uninstalling CentrifyDC failed ..."; do_error $CODE_EUN; }
                do_postremove ${ADD_ON_PKG}   || { echo "post-uninstall script failed ...";   do_error $CODE_EUN; }
            done
        fi
        if [ "${cda}" = "S+I+U" -o "${cda}" = "S=I+R" ]; then ### DA needs to check audit is not enabled before upgrade
            do_preupgrade CentrifyDA || { echo "CDA pre-upgrade failed ..."; do_error; }
        fi
        if [ "${INSTALL}" = "U" -o "${INSTALL}" = "R" ]; then ### core package only
            do_preupgrade       || { echo "Pre-upgrade failed ..."; do_error; }
        fi
        if [ "${cda}" = "S+Y" -o \
            "${cda}" = "S+I+U" -o "${cda}" = "S=I+R" ]; then
            do_preinstall CentrifyDA || { echo "CDA pre-install failed ..."; do_error; }
        fi
        if [ "${openssh}" = "S+Y" ]; then
            do_preinstall openssh || { echo "CDC-openssh pre-install failed ..."; do_error; }
        fi
        if [ "${INSTALL}" = "Y" -o "${INSTALL}" = "U" -o "${INSTALL}" = "R" ]; then ### core package only
            do_preinstall       || { echo "pre-install script failed ..."; do_error; }
        fi
        if [ "${PKG_FILE_LIST}" != "" ]; then
            do_install_main     || { echo "installation failed ..."; do_error; }
        fi
        if [ "${INSTALL}" = "Y" -o "${INSTALL}" = "U" -o "${INSTALL}" = "R" ]; then ### core package only
            do_postinstall      || { echo "post-install script failed ..."; do_error; }
        fi
        if [ "${cda}" = "S+Y" -o \
            "${cda}" = "S+I+U" -o "${cda}" = "S=I+R" ]; then
            do_postinstall CentrifyDA || { echo "CDA post-install failed ..."; do_error; }
        fi
        if [ "${INSTALL}" = "U" -o "${INSTALL}" = "R" ]; then ### core package only
            do_postupgrade      || { echo "Post-upgrade failed ..."; do_error; }
        fi
        set_license_mode
        copy_installer
        if [ "${ADJOIN}" = "Y" -o -n "${ADJOIN_CMD_OPTIONS}" ]; then
            if [ "${ADCHECK_RC}" = "3" ]; then
                echo "WARNING: adcheck failed, skipping adjoin ..." | tee -a ${LOG_FILE}
            else
                if [ "${ADJOIN}" = "Y" ]; then
                    do_join	|| { echo ""; do_error; } ### exit if do_join() failed
                else
                    /usr/sbin/adjoin ${ADJOIN_CMD_OPTIONS}
                fi
                if [ -s ${VAR}/centrifydc/kset.domain ]; then ADJOINED="Y"; fi
            fi
        fi
        if [ "${ADJOINED}" = "Y" -a "${DA_ENABLE}" = "Y" ]; then
            echo "Enabling DirectAudit for all shells ..." | tee -a ${LOG_FILE}
            /usr/sbin/dacontrol -e -a >> ${LOG_FILE} || { echo "ERROR: DirectAudit enabling failed ..."; do_error; }
            DA_ENABLE="enabled"
        fi
        if [ -x /usr/sbin/dastop ] && [ -x /usr/sbin/dad ]; then
            echo "Restarting DirectAudit daemon ..." | tee -a ${LOG_FILE}
            if [ "X${TARGET_OS}" = "Xaix" ]; then
                /usr/bin/stopsrc -s centrifyda >> ${LOG_FILE} 2>> ${LOG_FILE}
                #Max delay time
                SRCDELAY=10
                while [ "${SRCDELAY}" != "0" ]
                do
                    sleep 1
                    /usr/bin/lssrc -s centrifyda | grep inoperative >> ${LOG_FILE} 2>> ${LOG_FILE}
                    if [ $? -eq 0 ]; then break; fi
                    SRCDELAY=`expr ${SRCDELAY} - 1`
                done
 
                # Force to stop centrifyda anyway
                if [ "${SRCDELAY}" = "0" ]; then
                    /usr/bin/stopsrc -f -s centrifyda >> ${LOG_FILE} 2>> ${LOG_FILE}
                fi
                /usr/bin/startsrc -s centrifyda >> ${LOG_FILE} 2>> ${LOG_FILE}
            else
                /usr/sbin/dastop >> ${LOG_FILE} 2>> ${LOG_FILE}
                /usr/sbin/dad >> ${LOG_FILE} 2>> ${LOG_FILE}
            fi
        fi
        if [ "${REBOOT}" = "Y" ]; then
            do_reboot	|| { echo "rebooting failed ..."; do_error; }
        fi
        do_exit
    fi
}

### Parse argument list
echo $0 | grep "uninstall.sh" > /dev/null
if [ "$?" = "0" ]; then UNINSTALL="Y"; fi
echo $0 | grep "fix_wpar.sh" > /dev/null
if [ "$?" = "0" ]; then WPAR="yes"; fi

while [ $# -ge 1 ]; do
    case $1 in
    -V)    echo Centrify Express installer \(install-express.sh\) rev=${REV_YEAR}; exit 0 ;;
    -v)    shift; CDC_VER=$1 ;
           check_argument_value "$CDC_VER" || { echo "ERROR: invalid version."; do_error $CODE_ESU; };
           # Checking version format
           check_version_format "$CDC_VER" || { echo "ERROR: invalid version format."; do_error $CODE_ESU; };;
    -v*)   CDC_VER=`echo $1 | cut -c3-` ;
           check_argument_value "$CDC_VER" || { echo "ERROR: invalid version."; do_error $CODE_ESU; };
           # Checking version format
           check_version_format "$CDC_VER" || { echo "ERROR: invalid version format."; do_error $CODE_ESU; };;
    -h | --help)    usage; exit 0 ;;
    -e | --erase)   UNINSTALL="Y" ;;
    -l)    shift; LOG_FILE=$1 ;
           check_argument_value "$LOG_FILE" || { echo "ERROR: invalid log file."; LOG_FILE=""; do_error $CODE_ESU; };;
    -l*)   LOG_FILE=`echo $1 | cut -c3-` ;
           check_argument_value "$LOG_FILE" || { echo "ERROR: invalid log file."; LOG_FILE=""; do_error $CODE_ESU; };;
    -n)    SILENT="Y" ;;
    --ent-suite)    SUITE="Enterprise"; SILENT="Y"; EXPRESS="N" ;;
    --std-suite)    SUITE="Standard"; SILENT="Y"; EXPRESS="N" ;;
    --express)      SUITE="Standard"; SILENT="Y"; EXPRESS="Y" ;;
    --suite-config)  shift; CFG_FNAME_SUITE=$1;
  	       check_argument_value "$CFG_FNAME_SUITE" || { echo "ERROR: invalid suite config file."; do_error $CODE_ESU; };;
    --custom_rc)    set_custom_rc ;;
    --utest)        add_utest ;;
    --wpar)         WPAR="yes" ;;
    --force-da-global) FORCE_DA_GLOBAL="Y" ;;
    --no_os_check)  OS_CHECK="skip" ;;
    -x)    shift; validate_x_opt $1 ;;
    -x*)   validate_x_opt "`echo $1 | cut -c3-`" ;;
    --adjoin_opt=*) ADJOIN="N"; ADJOIN_CMD_OPTIONS="`echo $1 | cut -c14-`" ;;
    --enable-da)    DA_ENABLE="Y" ;;
    --debug)        DEBUG="on" ;;
    *)     echo $1: unknown option; usage; uid_check; do_error $CODE_ESU ;;
    esac
    shift
done

THIS_PRG="`echo $0`"

# Validate options

if [ "${DA_ENABLE}" != "" -a "${SILENT}" = "NO" ]; then
    echo "WARNING: Option --enable-da is ignored in interactive mode."
fi

main

